@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  * SPDX-FileCopyrightText: 2017      by Simon Frei <freisim93 at gmail dot com>
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -57,16 +57,11 @@ class Q_DECL_HIDDEN TableView::Private
 {
 public:
 
-    explicit Private()
-      : columnProfiles    (),
-        thumbnailSize     (),
-        imageViewUtilities(nullptr)
-    {
-    }
+    Private() = default;
 
     QList<TableViewColumnProfile> columnProfiles;
     ThumbnailSize                 thumbnailSize;
-    ItemViewUtilities*            imageViewUtilities;
+    ItemViewUtilities*            imageViewUtilities = nullptr;
 };
 
 TableView::TableView(QItemSelectionModel* const selectionModel,
@@ -74,7 +69,7 @@ TableView::TableView(QItemSelectionModel* const selectionModel,
                      QWidget* const parent)
     : QWidget(parent),
       StateSavingObject(this),
-      d                (new Private()),
+      d                (new Private),
       s                (new TableViewShared())
 {
     s->isActive                      = false;
@@ -237,7 +232,7 @@ void TableView::setThumbnailSize(const ThumbnailSize& size)
     d->thumbnailSize                            = size;
     const QList<TableViewColumn*> columnObjects = s->tableViewModel->getColumnObjects();
 
-    Q_FOREACH (TableViewColumn* const iColumn, columnObjects)
+    for (TableViewColumn* const iColumn : std::as_const(columnObjects))
     {
         iColumn->updateThumbnailSize();
     }
@@ -286,12 +281,12 @@ ItemInfoList TableView::allItemInfos(bool grouping) const
     return ItemInfoList(s->tableViewModel->allItemInfo());
 }
 
-bool TableView::allNeedGroupResolving(const ApplicationSettings::OperationType type) const
+bool TableView::allNeedGroupResolving(const OperationType type) const
 {
     return s->treeView->needGroupResolving(type, allItemInfos());
 }
 
-bool TableView::selectedNeedGroupResolving(const ApplicationSettings::OperationType type) const
+bool TableView::selectedNeedGroupResolving(const OperationType type) const
 {
     return s->treeView->needGroupResolving(type, selectedItemInfos());
 }
@@ -452,7 +447,9 @@ ItemInfo TableView::previousInfo() const
 
 void TableView::slotSetCurrentUrlWhenAvailable(const QUrl& url)
 {
-    Q_FOREACH (const ItemInfo& info, allItemInfos())
+    const auto infs = allItemInfos();
+
+    for (const ItemInfo& info : infs)
     {
         if (info.fileUrl() == url)
         {    // cppcheck-suppress useStlAlgorithm
@@ -572,7 +569,7 @@ void TableView::invertSelection()
 
     s->tableViewSelectionModel->clearSelection();
 
-    Q_FOREACH (const int i, rowsToSelect)
+    for (const int i : std::as_const(rowsToSelect))
     {
         const QModelIndex iIndex = s->tableViewModel->deepRowIndex(i);
         const QItemSelection is  = s->tableViewSelectionModelSyncer->targetIndexToRowItemSelection(iIndex);
@@ -637,7 +634,7 @@ void TableView::rename()
 {
     ItemInfoList infos = selectedItemInfos();
 
-    if (s->treeView->needGroupResolving(ApplicationSettings::Rename, infos))
+    if (s->treeView->needGroupResolving(RenameOps, infos))
     {
         infos = s->treeView->resolveGrouping(infos);
     }
