@@ -6,15 +6,14 @@
  * Date        : 2013-03-02
  * Description : Table view: Tree view subelement
  *
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TABLE_VIEW_TREEVIEW_H
-#define DIGIKAM_TABLE_VIEW_TREEVIEW_H
+#pragma once
 
 // Qt includes
 
@@ -91,11 +90,9 @@ Q_SIGNALS:
 private:
 
     class Private;
-
     const QScopedPointer<Private> d;
-    TableViewShared* const        s;
+
+    TableViewShared* const        s = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TABLE_VIEW_TREEVIEW_H
