@@ -6,23 +6,13 @@
  * Date        : 2010-02-23
  * Description : Black and White conversion batch tool.
  *
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_BW_CONVERT_H
-#define DIGIKAM_BQM_BW_CONVERT_H
+#pragma once
 
 // Local includes
 
@@ -41,7 +31,7 @@ class BWConvert : public BatchTool
 public:
 
     explicit BWConvert(QObject* const parent = nullptr);
-    ~BWConvert()                                            override;
+    ~BWConvert()                                            override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,7 +41,7 @@ public:
 
 public Q_SLOTS:
 
-    void slotResetSettingsToDefault();
+    void slotResetSettingsToDefault()                       override;
 
 private:
 
@@ -65,9 +55,7 @@ private Q_SLOTS:
 private:
 
     DImg             m_preview;
-    BWSepiaSettings* m_settingsView;
+    BWSepiaSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmBWConvertPlugin
-
-#endif // DIGIKAM_BQM_BW_CONVERT_H
