@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to reduce noise
  *
- * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_NOISE_REDUCTION_PLUGIN_H
-#define DIGIKAM_NOISE_REDUCTION_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class NoiseReductionPlugin : public DPluginBqm
 public:
 
     explicit NoiseReductionPlugin(QObject* const parent = nullptr);
-    ~NoiseReductionPlugin()              override;
+    ~NoiseReductionPlugin()              override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmNoiseReductionPlugin
-
-#endif // DIGIKAM_NOISE_REDUCTION_PLUGIN_H
