@@ -7,15 +7,14 @@
  * Description : A digital camera RAW files loader for DImg
  *               framework using an external dcraw instance.
  *
- * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2005-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_RAW_LOADER_H
-#define DIGIKAM_DIMG_RAW_LOADER_H
+#pragma once
 
 // Local includes
 
@@ -38,7 +37,7 @@ class DImgRAWLoader : public DRawDecoder,
 public:
 
     explicit DImgRAWLoader(DImg* const image, const DRawDecoding& rawDecodingSettings = DRawDecoding());
-    ~DImgRAWLoader()                                                                 override;
+    ~DImgRAWLoader()                                                                 override = default;
 
     bool load(const QString& filePath, DImgLoaderObserver* const observer = nullptr) override;
     bool save(const QString&, DImgLoaderObserver* const)                             override;
@@ -71,10 +70,8 @@ private:
 
 private:
 
-    DImgLoaderObserver*  m_observer;
-    RawProcessingFilter* m_filter;
+    DImgLoaderObserver*  m_observer = nullptr;
+    RawProcessingFilter* m_filter   = nullptr;
 };
 
 } // namespace DigikamRAWDImgPlugin
-
-#endif // DIGIKAM_DIMG_RAW_LOADER_H
