@@ -7,7 +7,7 @@
  * Description : a tool for color space conversion
  *
  * SPDX-FileCopyrightText: 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -49,20 +49,15 @@ class Q_DECL_HIDDEN ProfileConversionTool::Private
 {
 public:
 
-    explicit Private()
-      : profilesBox  (nullptr),
-        previewWidget(nullptr),
-        gboxSettings (nullptr)
-    {
-    }
+    Private() = default;
 
-    static const QString configGroupName;
-    static const QString configProfileEntry;
+    const QString configGroupName       = QLatin1String("Profile Conversion Tool");
+    const QString configProfileEntry    = QLatin1String("Profile");
 
-    IccProfilesSettings* profilesBox;
+    IccProfilesSettings* profilesBox    = nullptr;
 
-    ImageRegionWidget*   previewWidget;
-    EditorToolSettings*  gboxSettings;
+    ImageRegionWidget*   previewWidget  = nullptr;
+    EditorToolSettings*  gboxSettings   = nullptr;
 
     IccProfile           currentProfile;
 
@@ -73,9 +68,6 @@ public:
     static IccTransform getTransform(const IccProfile& in, const IccProfile& out);
 };
 
-const QString ProfileConversionTool::Private::configGroupName(QLatin1String("Profile Conversion Tool"));
-const QString ProfileConversionTool::Private::configProfileEntry(QLatin1String("Profile"));
-
 IccTransform ProfileConversionTool::Private::getTransform(const IccProfile& in, const IccProfile& out)
 {
     ICCSettingsContainer settings = IccSettings::instance()->settings();
@@ -103,7 +95,7 @@ ProfileConversionTool::ProfileConversionTool(QObject* const parent)
     ImageIface iface;
     d->currentProfile = iface.originalIccProfile();
 
-    d->gboxSettings = new EditorToolSettings(nullptr);
+    d->gboxSettings   = new EditorToolSettings(nullptr);
     d->gboxSettings->setButtons(EditorToolSettings::Ok|
                                 EditorToolSettings::Cancel);
 
