@@ -6,7 +6,7 @@
  * Date        : 2006-05-16
  * Description : A tool to edit geolocation
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
  * SPDX-FileCopyrightText: 2010      by Gabriel Voicu <ping dot gabi at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Justus Schwartz <justus at gmx dot li>
@@ -45,6 +45,7 @@
 #include <QApplication>
 #include <QComboBox>
 #include <QDialogButtonBox>
+#include <QActionGroup>
 
 // KDE includes
 
@@ -57,7 +58,6 @@
 #include "dlayoutbox.h"
 #include "digikam_config.h"
 #include "itemmarkertiler.h"
-#include "trackmanager.h"
 #include "gpscommon.h"
 #include "gpsitemmodel.h"
 #include "mapdragdrophandler.h"
@@ -70,7 +70,7 @@
 #include "rgwidget.h"
 #include "kmlwidget.h"
 #include "statusprogressbar.h"
-#include "searchwidget.h"
+#include "searchresultwidget.h"
 #include "backend-rg.h"
 #include "gpsitemdetails.h"
 #include "gpsgeoifacemodelhelper.h"
@@ -87,7 +87,7 @@ using namespace Digikam;
 namespace DigikamGenericGeolocationEditPlugin
 {
 
-struct SaveChangedImagesHelper
+class Q_DECL_HIDDEN SaveChangedImagesHelper
 {
 public:
 
@@ -111,12 +111,12 @@ public:
 public:
 
     typedef QPair<QUrl, QString> result_type;
-    GPSItemModel* const          imageModel;
+    GPSItemModel* const          imageModel = nullptr;
 };
 
 // ---------------------------------------------------------------------------------
 
-struct LoadFileMetadataHelper
+class Q_DECL_HIDDEN LoadFileMetadataHelper
 {
 public:
 
@@ -142,7 +142,7 @@ public:
 public:
 
     typedef QPair<QUrl, QString> result_type;
-    GPSItemModel* const          imageModel;
+    GPSItemModel* const          imageModel = nullptr;
 };
 
 // ---------------------------------------------------------------------------------
@@ -151,116 +151,75 @@ class Q_DECL_HIDDEN GeolocationEdit::Private
 {
 public:
 
-    explicit Private()
-    {
-        imageModel               = nullptr;
-        selectionModel           = nullptr;
-        uiEnabled                = true;
-        listViewContextMenu      = nullptr;
-        trackManager             = nullptr;
-        fileIOFutureWatcher      = nullptr;
-        fileIOCountDone          = 0;
-        fileIOCountTotal         = 0;
-        fileIOCloseAfterSaving   = false;
-        buttonBox                = nullptr;
-        VSplitter                = nullptr;
-        HSplitter                = nullptr;
-        treeView                 = nullptr;
-        stackedWidget            = nullptr;
-        tabBar                   = nullptr;
-        splitterSize             = 0;
-        undoStack                = nullptr;
-        undoView                 = nullptr;
-        progressBar              = nullptr;
-        progressCancelButton     = nullptr;
-        progressCancelObject     = nullptr;
-        detailsWidget            = nullptr;
-        correlatorWidget         = nullptr;
-        rgWidget                 = nullptr;
-        searchWidget             = nullptr;
-        kmlWidget                = nullptr;
-        mapSplitter              = nullptr;
-        mapWidget                = nullptr;
-        mapWidget2               = nullptr;
-        mapDragDropHandler       = nullptr;
-        mapModelHelper           = nullptr;
-        geoifaceMarkerModel      = nullptr;
-        sortActionOldestFirst    = nullptr;
-        sortActionYoungestFirst  = nullptr;
-        sortMenu                 = nullptr;
-        mapLayout                = MapLayoutOne;
-        cbMapLayout              = nullptr;
-        bookmarkOwner            = nullptr;
-        actionBookmarkVisibility = nullptr;
-        iface                    = nullptr;
-    }
+    Private() = default;
+
+public:
 
     // General things
-    GPSItemModel*                            imageModel;
-    QItemSelectionModel*                     selectionModel;
-    bool                                     uiEnabled;
-    GPSItemListContextMenu*                  listViewContextMenu;
-    TrackManager*                            trackManager;
+    GPSItemModel*                            imageModel             = nullptr;
+    QItemSelectionModel*                     selectionModel         = nullptr;
+    bool                                     uiEnabled              = true;
+    GPSItemListContextMenu*                  listViewContextMenu    = nullptr;
+    TrackManager*                            trackManager           = nullptr;
 
     // Loading and saving
     QFuture<QPair<QUrl,QString> >            fileIOFuture;
     QFutureWatcher<QPair<QUrl,QString> >*    fileIOFutureWatcher;
-    int                                      fileIOCountDone;
-    int                                      fileIOCountTotal;
-    bool                                     fileIOCloseAfterSaving;
+    int                                      fileIOCountDone        = 0;
+    int                                      fileIOCountTotal       = 0;
+    bool                                     fileIOCloseAfterSaving = false;
 
     // UI
-    QDialogButtonBox*                        buttonBox;
-    QSplitter*                               VSplitter;
-    QSplitter*                               HSplitter;
-    GPSItemList*                             treeView;
-    QStackedWidget*                          stackedWidget;
-    QTabBar*                                 tabBar;
-    int                                      splitterSize;
-    QUndoStack*                              undoStack;
-    QUndoView*                               undoView;
+    QDialogButtonBox*                        buttonBox                  = nullptr;
+    QSplitter*                               VSplitter                  = nullptr;
+    QSplitter*                               HSplitter                  = nullptr;
+    GPSItemList*                             treeView                   = nullptr;
+    QStackedWidget*                          stackedWidget              = nullptr;
+    QTabBar*                                 tabBar                     = nullptr;
+    int                                      splitterSize               = 0;
+    QUndoStack*                              undoStack                  = nullptr;
+    QUndoView*                               undoView                   = nullptr;
 
     // UI: progress
-    StatusProgressBar*                       progressBar;
-    QPushButton*                             progressCancelButton;
-    QObject*                                 progressCancelObject;
+    StatusProgressBar*                       progressBar                = nullptr;
+    QPushButton*                             progressCancelButton       = nullptr;
+    QObject*                                 progressCancelObject       = nullptr;
     QString                                  progressCancelSlot;
 
     // UI: tab widgets
-    GPSItemDetails*                          detailsWidget;
-    GPSCorrelatorWidget*                     correlatorWidget;
-    RGWidget*                                rgWidget;
-    SearchWidget*                            searchWidget;
-    KmlWidget*                               kmlWidget;
+    GPSItemDetails*                          detailsWidget              = nullptr;
+    GPSCorrelatorWidget*                     correlatorWidget           = nullptr;
+    RGWidget*                                rgWidget                   = nullptr;
+    SearchResultWidget*                      searchWidget               = nullptr;
+    KmlWidget*                               kmlWidget                  = nullptr;
 
     // map: UI
-    MapLayout                                mapLayout;
-    QSplitter*                               mapSplitter;
-    MapWidget*                               mapWidget;
-    MapWidget*                               mapWidget2;
+    MapLayout                                mapLayout                  = MapLayoutOne;
+    QSplitter*                               mapSplitter                = nullptr;
+    MapWidget*                               mapWidget                  = nullptr;
+    MapWidget*                               mapWidget2                 = nullptr;
 
     // map: helpers
-    MapDragDropHandler*                      mapDragDropHandler;
-    GPSGeoIfaceModelHelper*                  mapModelHelper;
-    ItemMarkerTiler*                         geoifaceMarkerModel;
+    MapDragDropHandler*                      mapDragDropHandler         = nullptr;
+    GPSGeoIfaceModelHelper*                  mapModelHelper             = nullptr;
+    ItemMarkerTiler*                         geoifaceMarkerModel        = nullptr;
 
     // map: actions
-    QAction*                                 sortActionOldestFirst;
-    QAction*                                 sortActionYoungestFirst;
-    QMenu*                                   sortMenu;
-    QComboBox*                               cbMapLayout;
+    QAction*                                 sortActionOldestFirst      = nullptr;
+    QAction*                                 sortActionYoungestFirst    = nullptr;
+    QMenu*                                   sortMenu                   = nullptr;
+    QComboBox*                               cbMapLayout                = nullptr;
 
-    GPSBookmarkOwner*                        bookmarkOwner;
-    QAction*                                 actionBookmarkVisibility;
+    GPSBookmarkOwner*                        bookmarkOwner              = nullptr;
+    QAction*                                 actionBookmarkVisibility   = nullptr;
 
-    DInfoInterface*                          iface;
+    DInfoInterface*                          iface                      = nullptr;
 };
 
 GeolocationEdit::GeolocationEdit(QWidget* const parent, DInfoInterface* const iface)
     : DPluginDialog(parent, QLatin1String("Geolocation Edit Settings")),
       d            (new Private)
 {
-    setAttribute(Qt::WA_DeleteOnClose, true);
     setWindowTitle(i18nc("@title:window", "Geolocation Editor"));
     setMinimumSize(300, 400);
     setModal(true);
@@ -279,10 +238,10 @@ GeolocationEdit::GeolocationEdit(QWidget* const parent, DInfoInterface* const if
     d->bookmarkOwner = new GPSBookmarkOwner(d->imageModel, this);
     d->undoStack     = new QUndoStack(this);
     d->stackedWidget = new QStackedWidget();
-    d->searchWidget  = new SearchWidget(d->bookmarkOwner,
-                                        d->imageModel,
-                                        d->selectionModel,
-                                        d->stackedWidget);
+    d->searchWidget  = new SearchResultWidget(d->bookmarkOwner,
+                                              d->imageModel,
+                                              d->selectionModel,
+                                              d->stackedWidget);
 
     GPSItemContainer::setHeaderData(d->imageModel);
     d->mapModelHelper      = new GPSGeoIfaceModelHelper(d->imageModel, d->selectionModel, this);
@@ -314,9 +273,9 @@ GeolocationEdit::GeolocationEdit(QWidget* const parent, DInfoInterface* const if
     DHBox* const hbox            = new DHBox(this);
     QLabel* const labelMapLayout = new QLabel(i18nc("@label", "Layout:"), hbox);
     d->cbMapLayout               = new QComboBox(hbox);
-    d->cbMapLayout->addItem(i18nc("@item", "One map"),               QVariant::fromValue(MapLayoutOne));
-    d->cbMapLayout->addItem(i18nc("@item", "Two maps - horizontal"), QVariant::fromValue(MapLayoutHorizontal));
-    d->cbMapLayout->addItem(i18nc("@item", "Two maps - vertical"),   QVariant::fromValue(MapLayoutVertical));
+    d->cbMapLayout->addItem(i18nc("@item", "One map"),                   QVariant::fromValue(MapLayoutOne));
+    d->cbMapLayout->addItem(i18nc("@item", "Two maps - left and right"), QVariant::fromValue(MapLayoutVertical));
+    d->cbMapLayout->addItem(i18nc("@item", "Two maps - top and bottom"), QVariant::fromValue(MapLayoutHorizontal));
     labelMapLayout->setBuddy(d->cbMapLayout);
 
     d->progressBar          = new StatusProgressBar(hbox);
@@ -332,10 +291,18 @@ GeolocationEdit::GeolocationEdit(QWidget* const parent, DInfoInterface* const if
     connect(d->progressCancelButton, SIGNAL(clicked()),
             this, SLOT(slotProgressCancelButtonClicked()));
 
+    m_buttons->addButton(QDialogButtonBox::Yes);
     m_buttons->addButton(QDialogButtonBox::Apply);
     m_buttons->addButton(QDialogButtonBox::Close);
+    m_buttons->button(QDialogButtonBox::Yes)->setText(i18n("OK"));
+    m_buttons->button(QDialogButtonBox::Yes)->setAutoDefault(false);
+    m_buttons->button(QDialogButtonBox::Apply)->setAutoDefault(false);
+    m_buttons->button(QDialogButtonBox::Close)->setAutoDefault(false);
     m_buttons->setParent(hbox);
 
+    connect(m_buttons->button(QDialogButtonBox::Yes), &QPushButton::clicked,
+            this, &GeolocationEdit::slotOkClicked);
+
     connect(m_buttons->button(QDialogButtonBox::Apply), &QPushButton::clicked,
             this, &GeolocationEdit::slotApplyClicked);
 
@@ -436,7 +403,7 @@ GeolocationEdit::GeolocationEdit(QWidget* const parent, DInfoInterface* const if
     connect(d->correlatorWidget, SIGNAL(signalSetUIEnabled(bool)),
             this, SLOT(slotSetUIEnabled(bool)));
 
-    connect(d->correlatorWidget, SIGNAL(signalSetUIEnabled(bool,QObject*const,QString)),
+    connect(d->correlatorWidget, SIGNAL(signalSetUIEnabledWithCancel(bool,QObject*const,QString)),
             this, SLOT(slotSetUIEnabled(bool,QObject*const,QString)));
 
     connect(d->correlatorWidget, SIGNAL(signalProgressSetup(int,QString)),
@@ -457,7 +424,7 @@ GeolocationEdit::GeolocationEdit(QWidget* const parent, DInfoInterface* const if
     connect(d->rgWidget, SIGNAL(signalSetUIEnabled(bool)),
             this, SLOT(slotSetUIEnabled(bool)));
 
-    connect(d->rgWidget, SIGNAL(signalSetUIEnabled(bool,QObject*const,QString)),
+    connect(d->rgWidget, SIGNAL(signalSetUIEnabledWithCancel(bool,QObject*const,QString)),
             this, SLOT(slotSetUIEnabled(bool,QObject*const,QString)));
 
     connect(d->rgWidget, SIGNAL(signalProgressSetup(int,QString)),
@@ -475,7 +442,7 @@ GeolocationEdit::GeolocationEdit(QWidget* const parent, DInfoInterface* const if
     connect(d->listViewContextMenu, SIGNAL(signalSetUIEnabled(bool)),
             this, SLOT(slotSetUIEnabled(bool)));
 
-    connect(d->listViewContextMenu, SIGNAL(signalSetUIEnabled(bool,QObject*const,QString)),
+    connect(d->listViewContextMenu, SIGNAL(signalSetUIEnabledWithCancel(bool,QObject*const,QString)),
             this, SLOT(slotSetUIEnabled(bool,QObject*const,QString)));
 
     connect(d->listViewContextMenu, SIGNAL(signalProgressSetup(int,QString)),
@@ -521,7 +488,19 @@ bool GeolocationEdit::eventFilter(QObject* const o, QEvent* const e)
     {
         QMouseEvent const* m = static_cast<QMouseEvent*>(e);
 
-        QPoint p (m->x(), m->y());
+        QPoint p(
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+                 m->position().toPoint()
+#else
+
+                 m->x(), m->y()
+
+#endif
+
+        );
+
         const int var = d->tabBar->tabAt(p);
 
         if (var < 0)
@@ -589,7 +568,7 @@ void GeolocationEdit::setImages(const QList<QUrl>& images)
 {
     QList<GPSItemContainer*> items;
 
-    Q_FOREACH (const QUrl& u, images)
+    for (const QUrl& u : std::as_const(images))
     {
         items << new GPSItemContainer(u);
     }
@@ -599,7 +578,7 @@ void GeolocationEdit::setImages(const QList<QUrl>& images)
 
 void GeolocationEdit::setItems(const QList<GPSItemContainer*>& items)
 {
-    Q_FOREACH (GPSItemContainer* const newItem, items)
+    for (GPSItemContainer* const newItem : items)
     {
         newItem->loadImageData();
         d->imageModel->addItem(newItem);
@@ -631,7 +610,7 @@ void GeolocationEdit::setItems(const QList<GPSItemContainer*>& items)
 void GeolocationEdit::slotFileMetadataLoaded(int beginIndex, int endIndex)
 {
     qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << beginIndex << endIndex;
-    d->fileIOCountDone += (endIndex-beginIndex);
+    d->fileIOCountDone += (endIndex - beginIndex);
     slotProgressChanged(d->fileIOCountDone);
 
     if (d->fileIOCountDone == d->fileIOCountTotal)
@@ -643,28 +622,28 @@ void GeolocationEdit::slotFileMetadataLoaded(int beginIndex, int endIndex)
 void GeolocationEdit::readSettings()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group        = config->group("Geolocation Edit Settings");
+    KConfigGroup group        = config->group(QLatin1String("Geolocation Edit Settings"));
 
     // --------------------------
 
     // TODO: sanely determine a default backend
 
-    const KConfigGroup groupMapWidget = KConfigGroup(&group, "Map Widget");
+    const KConfigGroup groupMapWidget = KConfigGroup(&group, QLatin1String("Map Widget"));
     d->mapWidget->readSettingsFromGroup(&groupMapWidget);
 
-    const KConfigGroup groupCorrelatorWidget = KConfigGroup(&group, "Correlator Widget");
+    const KConfigGroup groupCorrelatorWidget = KConfigGroup(&group, QLatin1String("Correlator Widget"));
     d->correlatorWidget->readSettingsFromGroup(&groupCorrelatorWidget);
 
-    const KConfigGroup groupTreeView = KConfigGroup(&group, "Tree View");
+    const KConfigGroup groupTreeView = KConfigGroup(&group, QLatin1String("Tree View"));
     d->treeView->readSettingsFromGroup(&groupTreeView);
 
-    const KConfigGroup groupSearchWidget = KConfigGroup(&group, "Search Widget");
-    d->searchWidget->readSettingsFromGroup(&groupSearchWidget);
+    const KConfigGroup groupSearchResultWidget = KConfigGroup(&group, QLatin1String("Search Widget"));
+    d->searchWidget->readSettingsFromGroup(&groupSearchResultWidget);
 
-    const KConfigGroup groupRGWidget = KConfigGroup(&group, "Reverse Geocoding Widget");
+    const KConfigGroup groupRGWidget = KConfigGroup(&group, QLatin1String("Reverse Geocoding Widget"));
     d->rgWidget->readSettingsFromGroup(&groupRGWidget);
 
-    const KConfigGroup groupDialog = KConfigGroup(&group, "Dialog");
+    const KConfigGroup groupDialog = KConfigGroup(&group, QLatin1String("Dialog"));
 
     // --------------------------
 
@@ -687,21 +666,23 @@ void GeolocationEdit::readSettings()
 
     if (group.hasKey("SplitterState V1"))
     {
-        const QByteArray splitterState = QByteArray::fromBase64(group.readEntry("SplitterState V1", QByteArray()));
+        QByteArray splitterState;
+        splitterState = group.readEntry("SplitterState V1", splitterState);
 
         if (!splitterState.isEmpty())
         {
-            d->VSplitter->restoreState(splitterState);
+            d->VSplitter->restoreState(QByteArray::fromBase64(splitterState));
         }
     }
 
     if (group.hasKey("SplitterState H1"))
     {
-        const QByteArray splitterState = QByteArray::fromBase64(group.readEntry("SplitterState H1", QByteArray()));
+        QByteArray splitterState;
+        splitterState = group.readEntry("SplitterState H1", splitterState);
 
         if (!splitterState.isEmpty())
         {
-            d->HSplitter->restoreState(splitterState);
+            d->HSplitter->restoreState(QByteArray::fromBase64(splitterState));
         }
     }
 
@@ -715,7 +696,7 @@ void GeolocationEdit::readSettings()
 
     if (d->mapWidget2)
     {
-        const KConfigGroup groupMapWidget2 = KConfigGroup(&group, "Map Widget 2");
+        const KConfigGroup groupMapWidget2 = KConfigGroup(&group, QLatin1String("Map Widget 2"));
         d->mapWidget2->readSettingsFromGroup(&groupMapWidget2);
 
         d->mapWidget2->setActive(true);
@@ -725,29 +706,29 @@ void GeolocationEdit::readSettings()
 void GeolocationEdit::saveSettings()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group = config->group("Geolocation Edit Settings");
+    KConfigGroup group        = config->group(QLatin1String("Geolocation Edit Settings"));
 
     // --------------------------
 
-    KConfigGroup groupMapWidget = KConfigGroup(&group, "Map Widget");
+    KConfigGroup groupMapWidget = KConfigGroup(&group, QLatin1String("Map Widget"));
     d->mapWidget->saveSettingsToGroup(&groupMapWidget);
 
     if (d->mapWidget2)
     {
-        KConfigGroup groupMapWidget2 = KConfigGroup(&group, "Map Widget 2");
+        KConfigGroup groupMapWidget2 = KConfigGroup(&group, QLatin1String("Map Widget 2"));
         d->mapWidget2->saveSettingsToGroup(&groupMapWidget2);
     }
 
-    KConfigGroup groupCorrelatorWidget = KConfigGroup(&group, "Correlator Widget");
+    KConfigGroup groupCorrelatorWidget = KConfigGroup(&group, QLatin1String("Correlator Widget"));
     d->correlatorWidget->saveSettingsToGroup(&groupCorrelatorWidget);
 
-    KConfigGroup groupTreeView = KConfigGroup(&group, "Tree View");
+    KConfigGroup groupTreeView = KConfigGroup(&group, QLatin1String("Tree View"));
     d->treeView->saveSettingsToGroup(&groupTreeView);
 
-    KConfigGroup groupSearchWidget = KConfigGroup(&group, "Search Widget");
-    d->searchWidget->saveSettingsToGroup(&groupSearchWidget);
+    KConfigGroup groupSearchResultWidget = KConfigGroup(&group, QLatin1String("Search Widget"));
+    d->searchWidget->saveSettingsToGroup(&groupSearchResultWidget);
 
-    KConfigGroup groupRGWidget = KConfigGroup(&group, "Reverse Geocoding Widget");
+    KConfigGroup groupRGWidget = KConfigGroup(&group, QLatin1String("Reverse Geocoding Widget"));
     d->rgWidget->saveSettingsToGroup(&groupRGWidget);
 
     // --------------------------
@@ -812,8 +793,7 @@ void GeolocationEdit::closeEvent(QCloseEvent *e)
         const int chosenAction = DMessageBox::showYesNo(QMessageBox::Warning,
                                                         this,
                                                         i18nc("@title:window", "Unsaved Changes"),
-                                                        i18nc("@info", "%1 Would you like to save the changes you made to them?", message)
-                                                       );
+                                                        i18nc("@info", "%1 Would you like to save the changes you made to them?", message));
 
         if (chosenAction == QMessageBox::No)
         {
@@ -948,7 +928,7 @@ void GeolocationEdit::slotFileChangesSaved(int beginIndex, int endIndex)
 {
     qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << beginIndex << endIndex;
 
-    d->fileIOCountDone += (endIndex-beginIndex);
+    d->fileIOCountDone += (endIndex - beginIndex);
     slotProgressChanged(d->fileIOCountDone);
 
     if (d->fileIOCountDone == d->fileIOCountTotal)
@@ -1001,6 +981,13 @@ void GeolocationEdit::slotFileChangesSaved(int beginIndex, int endIndex)
     }
 }
 
+void GeolocationEdit::slotOkClicked()
+{
+    // save the changes, and close afterwards
+
+    saveChanges(true);
+}
+
 void GeolocationEdit::slotApplyClicked()
 {
     // save the changes, but do not close afterwards
@@ -1115,8 +1102,8 @@ void GeolocationEdit::adjustMapLayout(const bool syncSettings)
             if (syncSettings)
             {
                 KSharedConfig::Ptr config         = KSharedConfig::openConfig();
-                KConfigGroup group                = config->group("Geolocation Edit Settings");
-                const KConfigGroup groupMapWidget = KConfigGroup(&group, "Map Widget");
+                KConfigGroup group                = config->group(QLatin1String("Geolocation Edit Settings"));
+                const KConfigGroup groupMapWidget = KConfigGroup(&group, QLatin1String("Map Widget"));
                 d->mapWidget2->readSettingsFromGroup(&groupMapWidget);
                 d->mapWidget2->setActive(true);
             }
@@ -1134,3 +1121,5 @@ void GeolocationEdit::adjustMapLayout(const bool syncSettings)
 }
 
 } // namespace DigikamGenericGeolocationEditPlugin
+
+#include "moc_geolocationedit.cpp"
