@@ -5,19 +5,11 @@
  *
  * Date        : 2007-10-24
  * Description : XMP credits settings page.
- * Modified    : 2014-04-22 Alan Pater
  *
- * Copyright (C) 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014      by Alan Pater <alan dot pater at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -39,7 +31,9 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "multistringsedit.h"
+#include "dtextedit.h"
 
 namespace DigikamGenericMetadataEditPlugin
 {
@@ -48,71 +42,43 @@ class Q_DECL_HIDDEN XMPCredits::Private
 {
 public:
 
-    explicit Private()
-      : syncEXIFArtistCheck(nullptr),
-        creatorTitleCheck  (nullptr),
-        creditCheck        (nullptr),
-        sourceCheck        (nullptr),
-        contactCheck       (nullptr),
-        emailCheck         (nullptr),
-        urlCheck           (nullptr),
-        phoneCheck         (nullptr),
-        addressCheck       (nullptr),
-        postalCodeCheck    (nullptr),
-        cityCheck          (nullptr),
-        regionCheck        (nullptr),
-        countryCheck       (nullptr),
-        creatorTitleEdit   (nullptr),
-        creditEdit         (nullptr),
-        sourceEdit         (nullptr),
-        emailEdit          (nullptr),
-        urlEdit            (nullptr),
-        phoneEdit          (nullptr),
-        addressEdit        (nullptr),
-        postalCodeEdit     (nullptr),
-        cityEdit           (nullptr),
-        regionEdit         (nullptr),
-        countryEdit        (nullptr),
-        creatorEdit        (nullptr)
-    {
-    }
+    Private() = default;
 
-    QCheckBox*        syncEXIFArtistCheck;
-    QCheckBox*        creatorTitleCheck;
-    QCheckBox*        creditCheck;
-    QCheckBox*        sourceCheck;
-    QCheckBox*        contactCheck;
-    QCheckBox*        emailCheck;
-    QCheckBox*        urlCheck;
-    QCheckBox*        phoneCheck;
-    QCheckBox*        addressCheck;
-    QCheckBox*        postalCodeCheck;
-    QCheckBox*        cityCheck;
-    QCheckBox*        regionCheck;
-    QCheckBox*        countryCheck;
+    QCheckBox*        syncEXIFArtistCheck   = nullptr;
+    QCheckBox*        creatorTitleCheck     = nullptr;
+    QCheckBox*        creditCheck           = nullptr;
+    QCheckBox*        sourceCheck           = nullptr;
+    QCheckBox*        contactCheck          = nullptr;
+    QCheckBox*        emailCheck            = nullptr;
+    QCheckBox*        urlCheck              = nullptr;
+    QCheckBox*        phoneCheck            = nullptr;
+    QCheckBox*        addressCheck          = nullptr;
+    QCheckBox*        postalCodeCheck       = nullptr;
+    QCheckBox*        cityCheck             = nullptr;
+    QCheckBox*        regionCheck           = nullptr;
+    QCheckBox*        countryCheck          = nullptr;
 
-    QLineEdit*        creatorTitleEdit;
-    QLineEdit*        creditEdit;
-    QLineEdit*        sourceEdit;
-    QLineEdit*        emailEdit;
-    QLineEdit*        urlEdit;
-    QLineEdit*        phoneEdit;
-    QLineEdit*        addressEdit;
-    QLineEdit*        postalCodeEdit;
-    QLineEdit*        cityEdit;
-    QLineEdit*        regionEdit;
-    QLineEdit*        countryEdit;
+    DTextEdit*        creatorTitleEdit      = nullptr;
+    DTextEdit*        creditEdit            = nullptr;
+    DTextEdit*        sourceEdit            = nullptr;
 
-    MultiStringsEdit* creatorEdit;
+    QLineEdit*        emailEdit             = nullptr;
+    QLineEdit*        urlEdit               = nullptr;
+    QLineEdit*        phoneEdit             = nullptr;
+    QLineEdit*        addressEdit           = nullptr;
+    QLineEdit*        postalCodeEdit        = nullptr;
+    QLineEdit*        cityEdit              = nullptr;
+    QLineEdit*        regionEdit            = nullptr;
+    QLineEdit*        countryEdit           = nullptr;
+
+    MultiStringsEdit* creatorEdit           = nullptr;
 };
 
 XMPCredits::XMPCredits(QWidget* const parent)
-    : QWidget(parent),
-      d      (new Private)
+    : MetadataEditPage(parent),
+      d               (new Private)
 {
-    const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
-
-    QGridLayout* const grid = new QGridLayout(this);
+    QGridLayout* const grid = new QGridLayout(widget());
 
     // --------------------------------------------------------
 
@@ -123,9 +89,8 @@ XMPCredits::XMPCredits(QWidget* const parent)
     // --------------------------------------------------------
 
     d->creatorTitleCheck = new QCheckBox(i18n("Creator Title:"), this);
-    d->creatorTitleEdit  = new QLineEdit(this);
-    d->creatorTitleEdit->setClearButtonEnabled(true);
-    d->creatorTitleEdit->setWhatsThis(i18n("Set here the title of content creator."));
+    d->creatorTitleEdit  = new DTextEdit(this);
+    d->creatorTitleEdit->setPlaceholderText(i18n("Set here the title of content creator."));
 
     // --------------------------------------------------------
 
@@ -135,42 +100,42 @@ XMPCredits::XMPCredits(QWidget* const parent)
     d->emailCheck = new QCheckBox(i18nc("contact email address", "E-mail:"), contactBox);
     d->emailEdit  = new QLineEdit(contactBox);
     d->emailEdit->setClearButtonEnabled(true);
-    d->emailEdit->setWhatsThis(i18n("Set here the contact e-mail."));
+    d->emailEdit->setPlaceholderText(i18n("Set here the contact e-mail."));
 
     d->urlCheck = new QCheckBox(i18n("URL:"), contactBox);
     d->urlEdit  = new QLineEdit(contactBox);
     d->urlEdit->setClearButtonEnabled(true);
-    d->urlEdit->setWhatsThis(i18n("Set here the contact URL."));
+    d->urlEdit->setPlaceholderText(i18n("Set here the contact URL."));
 
     d->phoneCheck = new QCheckBox(i18n("Phone:"), contactBox);
     d->phoneEdit  = new QLineEdit(contactBox);
     d->phoneEdit->setClearButtonEnabled(true);
-    d->phoneEdit->setWhatsThis(i18n("Set here the contact 'phone number."));
+    d->phoneEdit->setPlaceholderText(i18n("Set here the contact 'phone number."));
 
     d->addressCheck = new QCheckBox(i18nc("Street address", "Address:"), contactBox);
     d->addressEdit  = new QLineEdit(contactBox);
     d->addressEdit->setClearButtonEnabled(true);
-    d->addressEdit->setWhatsThis(i18n("Set here the contact address."));
+    d->addressEdit->setPlaceholderText(i18n("Set here the contact address."));
 
     d->postalCodeCheck = new QCheckBox(i18n("Postal code:"), contactBox);
     d->postalCodeEdit  = new QLineEdit(contactBox);
     d->postalCodeEdit->setClearButtonEnabled(true);
-    d->postalCodeEdit->setWhatsThis(i18n("Set here the contact postal code."));
+    d->postalCodeEdit->setPlaceholderText(i18n("Set here the contact postal code."));
 
     d->cityCheck = new QCheckBox(i18n("City:"), contactBox);
     d->cityEdit  = new QLineEdit(contactBox);
     d->cityEdit->setClearButtonEnabled(true);
-    d->cityEdit->setWhatsThis(i18n("Set here the contact city."));
+    d->cityEdit->setPlaceholderText(i18n("Set here the contact city."));
 
     d->regionCheck = new QCheckBox(i18n("State/Province:"), contactBox);
     d->regionEdit  = new QLineEdit(contactBox);
     d->regionEdit->setClearButtonEnabled(true);
-    d->regionEdit->setWhatsThis(i18n("Set here the contact state/province."));
+    d->regionEdit->setPlaceholderText(i18n("Set here the contact state/province."));
 
     d->countryCheck = new QCheckBox(i18n("Country:"), contactBox);
     d->countryEdit  = new QLineEdit(contactBox);
     d->countryEdit->setClearButtonEnabled(true);
-    d->countryEdit->setWhatsThis(i18n("Set here the contact country."));
+    d->countryEdit->setPlaceholderText(i18n("Set here the contact country."));
 
     grid2->addWidget(d->emailCheck,         0, 0, 1, 1);
     grid2->addWidget(d->emailEdit,          0, 1, 1, 2);
@@ -189,37 +154,38 @@ XMPCredits::XMPCredits(QWidget* const parent)
     grid2->addWidget(d->countryCheck,       7, 0, 1, 1);
     grid2->addWidget(d->countryEdit,        7, 1, 1, 2);
     grid2->setColumnStretch(2, 10);
+
+    int spacing = layoutSpacing();
+
     grid2->setContentsMargins(spacing, spacing, spacing, spacing);
     grid2->setSpacing(spacing);
 
     // --------------------------------------------------------
 
     d->creditCheck = new QCheckBox(i18n("Credit:"), this);
-    d->creditEdit  = new QLineEdit(this);
-    d->creditEdit->setClearButtonEnabled(true);
-    d->creditEdit->setWhatsThis(i18n("Set here the content provider."));
+    d->creditEdit  = new DTextEdit(this);
+    d->creditEdit->setPlaceholderText(i18n("Set here the content provider."));
 
     // --------------------------------------------------------
 
     d->sourceCheck = new QCheckBox(i18nc("original owner of content", "Source:"), this);
-    d->sourceEdit  = new QLineEdit(this);
-    d->sourceEdit->setClearButtonEnabled(true);
-    d->sourceEdit->setWhatsThis(i18n("Set here the original owner of content."));
+    d->sourceEdit  = new DTextEdit(this);
+    d->sourceEdit->setPlaceholderText(i18n("Set here the original owner of content."));
 
     // --------------------------------------------------------
 
     grid->addWidget(d->creatorEdit,         0, 0, 1, 3);
     grid->addWidget(d->syncEXIFArtistCheck, 1, 0, 1, 3);
-    grid->addWidget(d->creatorTitleCheck,   2, 0, 1, 1);
-    grid->addWidget(d->creatorTitleEdit,    2, 1, 1, 2);
-    grid->addWidget(contactBox,             3, 0, 1, 3);
-    grid->addWidget(d->creditCheck,         4, 0, 1, 1);
-    grid->addWidget(d->creditEdit,          4, 1, 1, 2);
-    grid->addWidget(d->sourceCheck,         5, 0, 1, 1);
-    grid->addWidget(d->sourceEdit,          5, 1, 1, 2);
-    grid->setRowStretch(6, 10);
+    grid->addWidget(d->creatorTitleCheck,   2, 0, 1, 3);
+    grid->addWidget(d->creatorTitleEdit,    3, 0, 1, 3);
+    grid->addWidget(contactBox,             4, 0, 1, 3);
+    grid->addWidget(d->creditCheck,         5, 0, 1, 3);
+    grid->addWidget(d->creditEdit,          6, 0, 1, 3);
+    grid->addWidget(d->sourceCheck,         7, 0, 1, 3);
+    grid->addWidget(d->sourceEdit,          8, 0, 1, 3);
+    grid->setRowStretch(9, 10);
     grid->setColumnStretch(2, 10);
-    grid->setContentsMargins(QMargins());
+    grid->setContentsMargins(spacing, spacing, spacing, spacing);
     grid->setSpacing(spacing);
 
     // --------------------------------------------------------
@@ -297,7 +263,7 @@ XMPCredits::XMPCredits(QWidget* const parent)
 
     // --------------------------------------------------------
 
-    connect(d->creatorTitleEdit, SIGNAL(textChanged(QString)),
+    connect(d->creatorTitleEdit, SIGNAL(textChanged()),
             this, SIGNAL(signalModified()));
 
     connect(d->emailEdit, SIGNAL(textChanged(QString)),
@@ -324,10 +290,10 @@ XMPCredits::XMPCredits(QWidget* const parent)
     connect(d->countryEdit, SIGNAL(textChanged(QString)),
             this, SIGNAL(signalModified()));
 
-    connect(d->creditEdit, SIGNAL(textChanged(QString)),
+    connect(d->creditEdit, SIGNAL(textChanged()),
             this, SIGNAL(signalModified()));
 
-    connect(d->sourceEdit, SIGNAL(textChanged(QString)),
+    connect(d->sourceEdit, SIGNAL(textChanged()),
             this, SIGNAL(signalModified()));
 }
 
@@ -384,7 +350,9 @@ void XMPCredits::readMetadata(const DMetadata& meta)
     data = meta.getXmpTagString("Xmp.iptc.CreatorContactInfo/Iptc4xmpCore:CiEmailWork", false);
 
     if (data.isNull())
+    {
         data = meta.getXmpTagString("Xmp.iptc.CiEmailWork", false);
+    }
 
     if (!data.isNull())
     {
@@ -401,7 +369,9 @@ void XMPCredits::readMetadata(const DMetadata& meta)
     data = meta.getXmpTagString("Xmp.iptc.CreatorContactInfo/Iptc4xmpCore:CiUrlWork", false);
 
     if (data.isNull())
+    {
         data = meta.getXmpTagString("Xmp.iptc.CiUrlWork", false);
+    }
 
     if (!data.isNull())
     {
@@ -418,7 +388,9 @@ void XMPCredits::readMetadata(const DMetadata& meta)
     data = meta.getXmpTagString("Xmp.iptc.CreatorContactInfo/Iptc4xmpCore:CiTelWork", false);
 
     if (data.isNull())
+    {
         data = meta.getXmpTagString("Xmp.iptc.CiTelWork", false);
+    }
 
     if (!data.isNull())
     {
@@ -435,7 +407,9 @@ void XMPCredits::readMetadata(const DMetadata& meta)
     data = meta.getXmpTagString("Xmp.iptc.CreatorContactInfo/Iptc4xmpCore:CiAdrExtadr", false);
 
     if (data.isNull())
+    {
         data = meta.getXmpTagString("Xmp.iptc.CiAdrExtadr", false);
+    }
 
     if (!data.isNull())
     {
@@ -452,7 +426,9 @@ void XMPCredits::readMetadata(const DMetadata& meta)
     data = meta.getXmpTagString("Xmp.iptc.CreatorContactInfo/Iptc4xmpCore:CiAdrPcode", false);
 
     if (data.isNull())
+    {
         data = meta.getXmpTagString("Xmp.iptc.CiAdrPcode", false);
+    }
 
     if (!data.isNull())
     {
@@ -469,7 +445,9 @@ void XMPCredits::readMetadata(const DMetadata& meta)
     data = meta.getXmpTagString("Xmp.iptc.CreatorContactInfo/Iptc4xmpCore:CiAdrCity", false);
 
     if (data.isNull())
+    {
         data = meta.getXmpTagString("Xmp.iptc.CiAdrCity", false);
+    }
 
     if (!data.isNull())
     {
@@ -695,3 +673,5 @@ void XMPCredits::applyMetadata(const DMetadata& meta)
 }
 
 } // namespace DigikamGenericMetadataEditPlugin
+
+#include "moc_xmpcredits.cpp"
