@@ -6,7 +6,7 @@
  * Date        : 2006-04-04
  * Description : a tool to generate HTML image galleries
  *
- * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -31,6 +31,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "htmlwizard.h"
 #include "galleryinfo.h"
 #include "abstractthemeparameter.h"
@@ -44,13 +45,10 @@ class Q_DECL_HIDDEN HTMLParametersPage::Private
 {
 public:
 
-    explicit Private()
-      : content(nullptr)
-    {
-    }
+    Private() = default;
 
     QMap<QByteArray, QWidget*> themePrmWdgtList;
-    QWidget*                   content;
+    QWidget*                   content = nullptr;
 };
 
 HTMLParametersPage::HTMLParametersPage(QWizard* const dialog, const QString& title)
@@ -86,8 +84,7 @@ HTMLParametersPage::HTMLParametersPage(QWizard* const dialog, const QString& tit
     mScrollArea->setWidget(d->content);
 
     vbox->setContentsMargins(QMargins());
-    vbox->setSpacing(qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing)));
+    vbox->setSpacing(layoutSpacing());
 
     setPageWidget(vbox);
     setLeftBottomPix(QIcon::fromTheme(QLatin1String("text-css")));
@@ -122,8 +119,7 @@ void HTMLParametersPage::initializePage()
 
     QGridLayout* const layout = new QGridLayout(d->content);
     layout->setContentsMargins(QMargins());
-    layout->setSpacing(qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing)));
+    layout->setSpacing(layoutSpacing());
 
     // Create widgets
 
