@@ -6,7 +6,7 @@
  * Date        : 2017-06-27
  * Description : a tool to export items by email.
  *
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -53,11 +53,6 @@ class Q_DECL_HIDDEN MailIntroPage::Private
 public:
 
     explicit Private(QWizard* const dialog)
-      : imageGetOption(nullptr),
-        hbox(nullptr),
-        wizard(nullptr),
-        iface(nullptr),
-        binSearch(nullptr)
     {
         wizard = dynamic_cast<MailWizard*>(dialog);
 
@@ -67,11 +62,13 @@ public:
         }
     }
 
-    QComboBox*        imageGetOption;
-    DHBox*            hbox;
-    MailWizard*       wizard;
-    DInfoInterface*   iface;
-    DBinarySearch*    binSearch;
+public:
+
+    QComboBox*        imageGetOption    = nullptr;
+    DHBox*            hbox              = nullptr;
+    MailWizard*       wizard            = nullptr;
+    DInfoInterface*   iface             = nullptr;
+    DBinarySearch*    binSearch         = nullptr;
     BalsaBinary       balsaBin;
     ClawsMailBinary   clawsBin;
     EvolutionBinary   evoluBin;
@@ -84,7 +81,7 @@ public:
 
 MailIntroPage::MailIntroPage(QWizard* const dialog, const QString& title)
     : DWizardPage(dialog, title),
-      d(new Private(dialog))
+      d          (new Private(dialog))
 {
     DVBox* const vbox  = new DVBox(this);
     QLabel* const desc = new QLabel(vbox);
@@ -218,7 +215,8 @@ void MailIntroPage::slotBinariesFound()
 
 bool MailIntroPage::isComplete() const
 {
-    QString val = d->wizard->settings()->binPaths.values().join(QString());
+    const auto vals = d->wizard->settings()->binPaths.values();
+    QString val     = vals.join(QString());
     qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << val;
 
     return (!val.isEmpty());
