@@ -6,14 +6,13 @@
  * Date        : 2017-06-27
  * Description : a tool to export items by email.
  *
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_MAIL_INTRO_PAGE_H
-#define DIGIKAM_MAIL_INTRO_PAGE_H
+#pragma once
 
 // Qt includes
 
@@ -35,10 +34,10 @@ class MailIntroPage : public DWizardPage
 public:
 
     explicit MailIntroPage(QWizard* const dialog, const QString& title);
-    ~MailIntroPage() override;
+    ~MailIntroPage()        override;
 
-    void initializePage() override;
-    bool validatePage() override;
+    void initializePage()   override;
+    bool validatePage()     override;
     bool isComplete() const override;
 
 private Q_SLOTS:
@@ -48,9 +47,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericSendByMailPlugin
-
-#endif // DIGIKAM_MAIL_INTRO_PAGE_H
