@@ -7,14 +7,13 @@
  * Description : a presentation tool.
  *
  * SPDX-FileCopyrightText: 2008      by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
- * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_PRESENTATION_ADV_PAGE_H
-#define DIGIKAM_PRESENTATION_ADV_PAGE_H
+#pragma once
 
 // Local includes
 
@@ -34,7 +33,7 @@ public:
 
     explicit PresentationAdvPage(QWidget* const parent,
                                  PresentationContainer* const sharedData);
-    ~PresentationAdvPage() override;
+    ~PresentationAdvPage() override = default;
 
     void readSettings();
     void saveSettings();
@@ -53,5 +52,3 @@ private:
 };
 
 } // namespace DigikamGenericPresentationPlugin
-
-#endif // DIGIKAM_PRESENTATION_ADV_PAGE_H
