@@ -6,7 +6,7 @@
  * Date        : 2019-09-18
  * Description : DarkTable raw import plugin.
  *
- * SPDX-FileCopyrightText: 2019-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2019-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * Lua script inspired from Darktable Gimp plugin by Tobias Ellinghaus
  *
@@ -18,14 +18,14 @@
 
 // Qt includes
 
-#include <QMessageBox>
-#include <QApplication>
+#include <QDir>
 #include <QPointer>
-#include <QByteArray>
-#include <QTextStream>
 #include <QFileInfo>
 #include <QSettings>
-#include <QTemporaryFile>
+#include <QByteArray>
+#include <QMessageBox>
+#include <QTextStream>
+#include <QApplication>
 
 // KDE includes
 
@@ -38,6 +38,7 @@
 #include "dimg.h"
 #include "filteraction.h"
 #include "dfileoperations.h"
+#include "filereadwritelock.h"
 #include "loadingdescription.h"
 
 namespace DigikamRawImportDarkTablePlugin
@@ -49,14 +50,15 @@ public:
 
     Private() = default;
 
+public:
 
-    QProcess*            darktable  = nullptr;
+    QProcess*            darktable     = nullptr;
     DImg                 decoded;
     LoadingDescription   props;
     QString              tempName;
-    QTemporaryFile       luaFile;
+    SafeTemporaryFile*   luaTempFile   = nullptr;
 
-    const QString luaScriptData     = QLatin1String
+    const QString        luaScriptData = QLatin1String
     (
         "\n"                                                                                                    \
         "local dt = require \"darktable\"\n"                                                                    \
@@ -105,14 +107,19 @@ DarkTableRawImportPlugin::DarkTableRawImportPlugin(QObject* const parent)
     : DPluginRawImport(parent),
       d               (new Private)
 {
-    d->luaFile.open();
-    QTextStream stream(&d->luaFile);
+    d->luaTempFile = new SafeTemporaryFile(QDir::tempPath() +
+                                           QLatin1String("/LuaScript-XXXXXX"));
+    d->luaTempFile->setAutoRemove(true);
+    d->luaTempFile->open();
+
+    QTextStream stream(d->luaTempFile);
     stream << d->luaScriptData;
     stream.flush();
 }
 
 DarkTableRawImportPlugin::~DarkTableRawImportPlugin()
 {
+    delete d->luaTempFile;
     delete d;
 }
 
@@ -163,7 +170,7 @@ QList<DPluginAuthor> DarkTableRawImportPlugin::authors() const
     return QList<DPluginAuthor>()
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2019-2024"))
+                             QString::fromUtf8("(C) 2019-2025"))
             ;
 }
 
@@ -174,18 +181,30 @@ void DarkTableRawImportPlugin::setup(QObject* const /*parent*/)
 
 QString DarkTableRawImportPlugin::getRawProgram() const
 {
-    return DFileOperations::findExecutable(QLatin1String("darktable"));
+    QStringList hints;
+
+#ifdef Q_OS_MACOS
+
+    hints << QLatin1String("/Applications/darktable.app/Contents/MacOS");
+
+#endif
+
+    return DFileOperations::findExecutable(QLatin1String("darktable"), hints);
 }
 
 bool DarkTableRawImportPlugin::run(const QString& filePath, const DRawDecoding& /*def*/)
 {
     QFileInfo fileInfo(filePath);
-    d->props     = LoadingDescription(fileInfo.filePath(), LoadingDescription::ConvertForEditor);
-    d->decoded   = DImg();
+    d->props    = LoadingDescription(fileInfo.filePath(),
+                                    LoadingDescription::ConvertForEditor);
+    d->decoded  = DImg();
 
-    QTemporaryFile tempFile;
-    tempFile.open();
-    d->tempName  = tempFile.fileName();
+    SafeTemporaryFile* const temp = new SafeTemporaryFile(QDir::tempPath() +
+                                                          QLatin1String("/Darktable-XXXXXX"));
+    temp->setAutoRemove(false);
+    temp->open();
+    d->tempName = temp->safeFilePath();
+    delete temp;
 
     d->darktable = new QProcess(this);
     d->darktable->setProcessChannelMode(QProcess::MergedChannels);
@@ -208,9 +227,9 @@ bool DarkTableRawImportPlugin::run(const QString& filePath, const DRawDecoding&
                                              << QLatin1String(":memory:")                                  // Run DarkTable to process only one file
                                              << QLatin1String("--luacmd")
                                              << QString::fromUtf8("dofile('%1')")
-                                                .arg(d->luaFile.fileName())                                // LUA script to run in DarkTable
+                                                .arg(d->luaTempFile->safeFilePath())                       // LUA script to run in DarkTable
                                              << QLatin1String("--conf")
-                                             << QLatin1String("plugins/lighttable/export/icctype=3")       // Output color-space
+                                             << QLatin1String("plugins/lighttable/export/icctype=-1")      // Output color-space
                                              << QLatin1String("--conf")
                                              << QString::fromUtf8("lua/export_on_exit/export_filename=%1")
                                                 .arg(d->tempName)                                          // Output file
@@ -267,14 +286,16 @@ void DarkTableRawImportPlugin::slotErrorOccurred(QProcess::ProcessError error)
 
 void DarkTableRawImportPlugin::slotProcessFinished(int code, QProcess::ExitStatus status)
 {
-    qCDebug(DIGIKAM_DPLUGIN_RAWIMPORT_LOG) << "DarkTable :: return code:" << code << ":: Exit status:" << status;
+    qCDebug(DIGIKAM_DPLUGIN_RAWIMPORT_LOG) << "DarkTable :: return code:"
+                                           << code << ":: Exit status:" << status;
 
     d->decoded = DImg(d->tempName);
     d->decoded.setAttribute(QLatin1String("isReadOnly"), true);
 
     if (d->decoded.isNull())
     {
-        QString message = i18n("Error to import RAW image with DarkTable\nClose this dialog to load RAW image with native import tool");
+        QString message = i18n("Error to import RAW image with DarkTable\n"
+                               "Close this dialog to load RAW image with native import tool");
         QMessageBox::information(nullptr, qApp->applicationName(), message);
 
         qCDebug(DIGIKAM_DPLUGIN_RAWIMPORT_LOG) << "Decoded image is null! Load with Native tool...";
@@ -306,7 +327,7 @@ void DarkTableRawImportPlugin::slotProcessReadyRead()
     QByteArray data   = d->darktable->readAllStandardError();
     QStringList lines = QString::fromUtf8(data).split(QLatin1Char('\n'), Qt::SkipEmptyParts);
 
-    Q_FOREACH (const QString& one, lines)
+    for (const QString& one : std::as_const(lines))
     {
         qCDebug(DIGIKAM_DPLUGIN_RAWIMPORT_LOG) << "DarkTable ::" << one;
     }
