@@ -11,7 +11,7 @@
  *               https://grail.cs.washington.edu/wp-content/uploads/2015/08/jacobs-1995.pdf
  *
  * SPDX-FileCopyrightText: 2003      by Ricardo Niederberger Cabral <nieder at mail dot ru>
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2008-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -51,19 +51,17 @@ class Q_DECL_HIDDEN valStruct
 
 public:
 
-    valStruct()
-      : d(0.0),
-        i(0)
-    {
-    }
-
-    Unit d;   ///< [f]abs(a[i])
-    int  i;   ///< index i of a[i]
+    valStruct() = default;
 
     bool operator< (const valStruct& right) const
     {
         return (d > right.d);
     }
+
+public:
+
+    Unit d = 0.0;   ///< [f]abs(a[i])
+    int  i = 0;     ///< index i of a[i]
 };
 
 typedef std::priority_queue<valStruct> valqueue;
@@ -161,14 +159,6 @@ WeightBin::WeightBin()
 
 // --------------------------------------------------------------------
 
-Calculator::Calculator()
-{
-}
-
-Calculator::~Calculator()
-{
-}
-
 /**
  * Do the Haar tensorial 2d transform itself.
  * Here input is RGB data [0..255] in Unit arrays
