@@ -12,10 +12,10 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_HISTORY_GRAPH_BOOST_H
-#define DIGIKAM_ITEM_HISTORY_GRAPH_BOOST_H
+#pragma once
 
 // To include pragma directives for MSVC
+
 #include "digikam_config.h"
 
 #ifdef Q_CC_MSVC
@@ -32,10 +32,12 @@
 #if defined(Q_CC_CLANG)
 #   pragma clang diagnostic push
 #   pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#   pragma clang diagnostic ignored "-Wdeprecated-builtins"
 #   pragma clang diagnostic ignored "-Wundef"
 #   pragma clang diagnostic ignored "-Wunused-parameter"
 #   pragma clang diagnostic ignored "-Wcast-align"
 #   pragma clang diagnostic ignored "-Wunused-local-typedef"
+#   pragma clang diagnostic ignored "-Wambiguous-reversed-operator"
 #endif
 
 // C++ includes
@@ -44,10 +46,12 @@
 #include <algorithm>
 #include <vector>
 #include <stdbool.h>
+#include <functional>
 
 // Boost includes
 
-// Prohibit boost using deprecated header files
+// Prohibit boost using deprecated header files.
+
 #define BOOST_NO_HASH
 #define BOOST_BIND_GLOBAL_PLACEHOLDERS
 #define BOOST_ALLOW_DEPRECATED_HEADERS
@@ -69,8 +73,10 @@
 #include "digikam_debug.h"
 #include "digikam_export.h"
 
+// clazy:excludeall=missing-typeinfo,copyable-polymorphic,explicit
+
 /**
- * Install custom property ids, out-of-namespace
+ * Install custom property ids, out-of-namespace.
  */
 enum vertex_properties_t { vertex_properties };
 enum edge_properties_t   { edge_properties   };
@@ -86,7 +92,7 @@ namespace Digikam
 
 /**
  * Adds the necessary typedefs so that associative_property_map
- * accepts a QMap, and it can be used as a Boost Property Map
+ * accepts a QMap, and it can be used as a Boost Property Map.
  */
 template <typename Key, typename Value>
 class QMapForAdaptors : public QMap<Key, Value>
@@ -97,9 +103,9 @@ public:
     typedef Value                                data_type;
     typedef typename std::pair<const Key, Value> value_type;
 
-    QMapForAdaptors()
-    {
-    }
+public:
+
+    QMapForAdaptors() = default;
 };
 
 /**
@@ -109,29 +115,29 @@ public:
  */
 enum MeaningOfDirection
 {
-    ParentToChild,          ///< Edges are directed from a parent to its child
-    ChildToParent           ///< Edges are direct from a child to its parent
+    ParentToChild,          ///< Edges are directed from a parent to its child.
+    ChildToParent           ///< Edges are direct from a child to its parent.
 };
 
 /**
- * The graph base class template
+ * The graph base class template.
  */
 template <class VertexProperties, class EdgeProperties>
-class DIGIKAM_DATABASE_EXPORT Graph                                     // clazy:exclude=missing-typeinfo,copyable-polymorphic
+class DIGIKAM_DATABASE_EXPORT Graph
 {
 public:
 
     typedef boost::adjacency_list<
-          boost::vecS,                                                  ///< Standard storage. listS was desirable, but many algorithms work only with vecS
+          boost::vecS,                                                  ///< Standard storage. listS was desirable, but many algorithms work only with vecS.
           boost::vecS,
-          boost::bidirectionalS,                                        ///< directed graph
+          boost::bidirectionalS,                                        ///< Directed graph.
           boost::property<boost::vertex_index_t, int,
           boost::property<vertex_properties_t, VertexProperties> >,
-          boost::property<edge_properties_t, EdgeProperties>            ///< One property for each edge: EdgeProperties
+          boost::property<edge_properties_t, EdgeProperties>            ///< One property for each edge: EdgeProperties.
     > GraphContainer;
 
     /**
-     * a bunch of graph-specific typedefs that make the long boost types manageable
+     * a bunch of graph-specific typedefs that make the long boost types manageable.
      */
     typedef typename boost::graph_traits<GraphContainer>                                    graph_traits;
 
@@ -166,7 +172,7 @@ public:
      * These two classes provide source-compatible wrappers for the vertex and edge descriptors,
      * providing default construction to null and the isNull() method.
      */
-    class DIGIKAM_DATABASE_EXPORT Vertex                                // clazy:exclude=missing-typeinfo
+    class DIGIKAM_DATABASE_EXPORT Vertex
     {
     public:
 
@@ -176,8 +182,8 @@ public:
         }
 
         // cppcheck-suppress noExplicitConstructor
-        Vertex(const vertex_t& v)    // krazy:exclude=explicit
-            : v(v)
+        Vertex(const vertex_t& vv)       // krazy:exclude=explicit
+            : v(vv)
         {
         }
 
@@ -203,6 +209,11 @@ public:
             return (v == other);
         }
 
+        bool operator!=(const vertex_t& other) const
+        {
+            return (v != other);
+        }
+
         bool isNull() const
         {
             return (v == graph_traits::null_vertex());
@@ -213,14 +224,11 @@ public:
         vertex_t v;
     };
 
-    class DIGIKAM_DATABASE_EXPORT Edge                                  // clazy:exclude=missing-typeinfo
+    class DIGIKAM_DATABASE_EXPORT Edge
     {
     public:
 
-        Edge()
-            : null(true)
-        {
-        }
+        Edge() = default;
 
         // cppcheck-suppress noExplicitConstructor
         Edge(const edge_t& e)    // krazy:exclude=explicit
@@ -271,8 +279,9 @@ public:
 
         edge_t e;
 
-        /// there is not null_edge, we must emulate it
-        bool   null;
+        // NOTE: there is not null_edge, we must emulate it.
+
+        bool   null = true;
     };
 
 public:
@@ -288,8 +297,8 @@ public:
 
 public:
 
-    explicit Graph(MeaningOfDirection direction = ParentToChild)
-        : direction(direction)
+    explicit Graph(MeaningOfDirection dir = ParentToChild)
+        : direction(dir)
     {
     }
 
@@ -299,9 +308,7 @@ public:
     {
     }
 
-    virtual ~Graph()
-    {
-    }
+    virtual ~Graph() = default;
 
     Graph& operator=(const Graph& other)
     {
@@ -376,7 +383,8 @@ public:
         return boost::edge(v1, v2, graph).second;
     }
 
-    /// Does not care for direction
+    // NOTE: Does not care for direction.
+
     bool isConnected(const Vertex& v1, const Vertex& v2) const
     {
         if (boost::edge(v1, v2, graph).second)
@@ -421,7 +429,7 @@ public:
         {
             const VertexProperties& props = properties(*it);
 
-            // must implement operator==(const T&)
+            // Must implement operator==(const T&).
 
             if (props == value)
             {
@@ -455,7 +463,7 @@ public:
     }
 
     /**
-     * Accessing vertices and edges
+     * Accessing vertices and edges.
      */
     const GraphContainer& getGraph() const
     {
@@ -472,7 +480,8 @@ public:
         OutboundEdges = 1 << 0,
         InboundEdges  = 1 << 1,
 
-        /// These resolve to one of the flags above, depending on MeaningOfDirection
+        /// These resolve to one of the flags above, depending on MeaningOfDirection.
+
         EdgesToLeaf   = 1 << 2,
         EdgesToRoot   = 1 << 3,
         AllEdges      = InboundEdges | OutboundEdges
@@ -507,7 +516,8 @@ public:
         return verticesLst;
     }
 
-    /// NOTE: for "hasAdjacentVertices", simply use hasEdges(v, flags)
+    /// @note for "hasAdjacentVertices", simply use hasEdges(v, flags).
+
     int vertexCount() const
     {
         return (int)boost::num_vertices(graph);
@@ -671,13 +681,13 @@ public:
     };
 
     /**
-     * Returns a copy of this graph with all edges added to form the transitive closure
+     * Returns a copy of this graph with all edges added to form the transitive closure.
      */
     Graph transitiveClosure(GraphCopyFlags flags = CopyAllProperties) const
     {
         // make_iterator_property_map:
-        // 1. The second parameter, our verteX_index map, converts the key (Vertex) into an index
-        // 2. The index is used to store the value (Vertex) in the first argument, which is our vector
+        // 1. The second parameter, our verteX_index map, converts the key (Vertex) into an index.
+        // 2. The index is used to store the value (Vertex) in the first argument, which is our vector.
 
         std::vector<vertex_t> copiedVertices(vertexCount(), Vertex());
         Graph closure;
@@ -712,7 +722,7 @@ public:
         std::vector<vertex_t> copiedVertices(vertexCount(), Vertex());
         Graph reduction;
 
-        // NOTE: named parameters is not implemented
+        // NOTE: named parameters is not implemented.
 
         try
         {
@@ -855,7 +865,7 @@ public:
         }
         else
         {
-            // assume inverted parameters
+            // Assume inverted parameters.
 
             path.shortestPath(graph, v2);
 
@@ -886,7 +896,7 @@ public:
             path.shortestPath(boost::make_reverse_graph(graph), v);
         }
 
-        // Change 2147483647 to -1
+        // Change 2147483647 to -1.
 
         typename QMap<Vertex, int>::iterator it;
 
@@ -953,7 +963,7 @@ public:
      * all vertices dominated by v starting from root.
      * The order is the same as in the given, sorted list of all vertices in this graph
      * (or all vertices expected to be returned. The returned list is the intersection
-     *  of the dominated vertices and presortedVertices, in order of presortedVertices)
+     * of the dominated vertices and presortedVertices, in order of presortedVertices).
      */
     QList<Vertex> verticesDominatedBy(const Vertex& v,
                                       const Vertex& root,
@@ -969,11 +979,11 @@ public:
 
         QList<Vertex> dominatedTree = treeFromPredecessors(v, tree.predecessors);
 
-        /// remove all vertices from the DFS of v that are not in the dominated tree
+        /// Remove all vertices from the DFS of v that are not in the dominated tree.
 
         QList<Vertex> orderedTree;
 
-        Q_FOREACH (const Vertex& vv, presortedVertices)
+        for (const Vertex& vv : std::as_const(presortedVertices))
         {
             if (dominatedTree.contains(vv))
             {
@@ -1015,7 +1025,7 @@ public:
         search.breadthFirstSearch(graph, verticesLst.first(), direction == ChildToParent);
         QList<Vertex> bfs = search.verticesLst;
 
-        Q_FOREACH (const Vertex& v, verticesLst)
+        for (const Vertex& v : std::as_const(verticesLst))
         {
             bfs.removeOne(v);
         }
@@ -1027,7 +1037,7 @@ public:
             return verticesLst;
         }
 
-        // Sort in any so far unreachable nodes
+        // Sort in any so far unreachable nodes.
 
         vertex_range_t range = boost::vertices(graph);
 
@@ -1040,11 +1050,11 @@ public:
                 QList<Vertex> childBfs = childSearch.vertices;
                 QList<Vertex> toInsert;
 
-                // Any item reachable from *it should come after it
+                // Any item reachable from *it should come after it.
 
                 int minIndex = verticesLst.size();
 
-                Q_FOREACH (const Vertex& c, childBfs)
+                for (const Vertex& c : std::as_const(childBfs))
                 {
                     int foundAt = verticesLst.indexOf(c);
 
@@ -1058,7 +1068,7 @@ public:
                     }
                 }
 
-                Q_FOREACH (const Vertex& c, toInsert)
+                for (const Vertex& c : std::as_const(toInsert))
                 {
                     verticesLst.insert(minIndex++, c);
                 }
@@ -1101,7 +1111,7 @@ public:
         search.depthFirstSearchSorted(graph, verticesLst.first(), direction == ChildToParent, lessThan);
         QList<Vertex> dfs = search.vertices;
 
-        Q_FOREACH (const Vertex& v, verticesLst)
+        for (const Vertex& v : std::as_const(verticesLst))
         {
             dfs.removeOne(v);
         }
@@ -1129,14 +1139,14 @@ protected:
         QList<Vertex> children = predecessors.keys(v);
         vertices << children;
 
-        Q_FOREACH (const Vertex& child, children)
+        for (const Vertex& child : std::as_const(children))
         {
             treeFromPredecessorsRecursive(child, vertices, predecessors);
         }
     }
 
     /**
-     * Returns a list of vertex ids of vertices in the given range
+     * Returns a list of vertex ids of vertices in the given range.
      */
     template <typename Value, typename range_t>
     static QList<Value> toList(const range_t& range)
@@ -1170,7 +1180,7 @@ protected:
 
     /**
      * According to the given flags and based on the map,
-     * copies vertex and edge properties from this to the other graph
+     * copies vertex and edge properties from this to the other graph.
      */
     void copyProperties(Graph& other, GraphCopyFlags flags, const std::vector<vertex_t>& copiedVertices) const
     {
@@ -1288,7 +1298,7 @@ protected:
 
         QList<Vertex> verticesLst;
 
-        Q_FOREACH (const Vertex& candidate, search.vertices)
+        for (const Vertex& candidate : std::as_const(search.vertices))
         {
             if ((inOrOut ? in_degree(candidate, graph)
                          : out_degree(candidate, graph)) == 0)
@@ -1315,11 +1325,15 @@ protected:
 
             try
             {
-                boost::dag_shortest_paths(graph, v,
-                                          /// we provide a constant weight of 1
+                boost::dag_shortest_paths(
+                                          graph, v,
+
+                                          /// we provide a constant weight of 1.
+
                                           weight_map(boost::ref_property_map<typename boost::graph_traits<GraphType>::edge_descriptor,int>(weight)).
 
-                                          /// Store distance and predecessors in QMaps, wrapped to serve as property maps
+                                          /// Store distance and predecessors in QMaps, wrapped to serve as property maps.
+
                                           distance_map(VertexIntMapAdaptor(distances)).
                                           predecessor_map(VertexVertexMapAdaptor(predecessors))
                                          );
@@ -1337,17 +1351,23 @@ protected:
 
             try
             {
-                boost::dag_shortest_paths(graph, v,
-                                          /// we provide a constant weight of 1
+                boost::dag_shortest_paths(
+                                          graph, v,
+
+                                          /// We provide a constant weight of 1.
+
                                           weight_map(boost::ref_property_map<typename boost::graph_traits<GraphType>::edge_descriptor,int>(weight)).
 
-                                          /// Invert the default compare method: With greater, we get the longest path
+                                          /// Invert the default compare method: With greater, we get the longest path.
+
                                           distance_compare(std::greater<int>()).
 
-                                          /// will be returned if a node is unreachable
+                                          /// Will be returned if a node is unreachable.
+
                                           distance_inf(-1).
 
-                                          /// Store distance and predecessors in QMaps, wrapped to serve as property maps
+                                          /// Store distance and predecessors in QMaps, wrapped to serve as property maps.
+
                                           distance_map(VertexIntMapAdaptor(distances)).
                                           predecessor_map(VertexVertexMapAdaptor(predecessors))
                                          );
@@ -1402,7 +1422,7 @@ protected:
         template <class GraphType>
         void depthFirstSearch(const GraphType& graph, const Vertex& v, bool invertGraph)
         {
-            // remember that the visitor is passed by value
+            // Remember that the visitor is passed by value.
 
             DepthFirstSearchVisitor vis(this);
 
@@ -1426,7 +1446,7 @@ protected:
         template <class GraphType, typename LessThan>
         void depthFirstSearchSorted(const GraphType& graph, const Vertex& v, bool invertGraph, LessThan lessThan)
         {
-            // Remember that the visitor is passed by value
+            // Remember that the visitor is passed by value.
 
             DepthFirstSearchVisitor vis(this);
             std::vector<boost::default_color_type> color_vec(boost::num_vertices(graph), boost::white_color);
@@ -1476,8 +1496,8 @@ protected:
         {
         protected:
 
-            explicit CommonVisitor(GraphSearch* const q)
-                : q(q)
+            explicit CommonVisitor(GraphSearch* const qq)
+                : q(qq)
             {
             }
 
@@ -1486,7 +1506,7 @@ protected:
                 q->vertices << v;
             }
 
-            GraphSearch* const q;
+            GraphSearch* const q = nullptr;
         };
 
         class DepthFirstSearchVisitor : public boost::default_dfs_visitor,
@@ -1534,8 +1554,8 @@ protected:
 
         public:
 
-            lessThanMapEdgeToTarget(const GraphType& g, VertexLessThan vertexLessThan)
-              : g             (g),
+            lessThanMapEdgeToTarget(const GraphType& gg, VertexLessThan vertexLessThan)
+              : g             (gg),
                 vertexLessThan(vertexLessThan)
             {
             }
@@ -1551,7 +1571,9 @@ protected:
             VertexLessThan   vertexLessThan;
         };
 
-        /// This is boost's simple, old, recursive DFS algorithm adapted with lessThan
+        /**
+         * This is boost's simple, old, recursive DFS algorithm adapted with lessThan.
+         */
         template <class IncidenceGraph, class DFSVisitor, class ColorMap, typename LessThan>
         void depth_first_search_sorted(const IncidenceGraph& g,
                                        Vertex u,
@@ -1559,8 +1581,9 @@ protected:
                                        ColorMap color,
                                        LessThan lessThan)
         {
-            //typedef std::pair<Vertex, QList<Edge> > VertexInfo;
-
+/*
+            typedef std::pair<Vertex, QList<Edge> > VertexInfo;
+*/
             typedef typename boost::graph_traits<IncidenceGraph>::edge_descriptor edge_descriptor;
             QList<edge_descriptor> outEdges;
 /*
@@ -1579,7 +1602,7 @@ protected:
                       outEdges.end(),
                       lessThanMapEdgeToTarget<IncidenceGraph, LessThan>(g, lessThan));
 
-            Q_FOREACH (const edge_descriptor& e, outEdges)
+            for (const edge_descriptor& e : std::as_const(outEdges))
             {
                 Vertex v                          = boost::target(e, g);
                 vis.examine_edge(e, g);
@@ -1606,7 +1629,7 @@ protected:
     };
 
     /**
-     * Get the list of vertices with the largest value in the given distance map
+     * Get the list of vertices with the largest value in the given distance map.
      */
     QList<Vertex> mostRemoteNodes(const VertexIntMap& distances) const
     {
@@ -1619,16 +1642,17 @@ protected:
             if (it.value() > maxDist)
             {
                 maxDist = it.value();
-
-                //qDebug() << "Increasing maxDist to" << maxDist;
-
+/*
+                qDebug() << "Increasing maxDist to" << maxDist;
+*/
                 candidates.clear();
             }
 
             if (it.value() >= maxDist)
             {
-                //qDebug() << "Adding candidate" << id(it.key()) <<  "at distance" << maxDist;
-
+/*
+                qDebug() << "Adding candidate" << id(it.key()) <<  "at distance" << maxDist;
+*/
                 candidates << it.key();
             }
 
@@ -1660,8 +1684,9 @@ protected:
 
         for (Vertex v = root ; v != target ; v = predecessors.value(v))
         {
-            //qDebug() << "Adding waypoint" << id(v);
-
+/*
+            qDebug() << "Adding waypoint" << id(v);
+*/
             if (dir == ParentToChild)
             {
                 verticesLst.append(v);
@@ -1671,8 +1696,8 @@ protected:
                 verticesLst.prepend(v);
             }
 
-            // If a node is not reachable, it seems its entry in the predecessors map is itself
-            // Avoid endless loop
+            // If a node is not reachable, it seems its entry in the predecessors map is itself.
+            // Avoid endless loop.
 
             if (predecessors.value(v) == v)
             {
@@ -1686,12 +1711,13 @@ protected:
 protected:
 
     GraphContainer     graph;
-    MeaningOfDirection direction;
+    MeaningOfDirection direction = ParentToChild;
 };
 
 } // namespace Digikam
 
-// Restore warnings
+// Restore warnings.
+
 #if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
 #   pragma GCC diagnostic pop
 #endif
@@ -1699,5 +1725,3 @@ protected:
 #if defined(Q_CC_CLANG)
 #   pragma clang diagnostic pop
 #endif
-
-#endif // DIGIKAM_ITEM_HISTORY_GRAPH_BOOST_H
