@@ -7,14 +7,13 @@
  * Description : ItemInfo common data
  *
  * SPDX-FileCopyrightText: 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_INFO_CACHE_H
-#define DIGIKAM_ITEM_INFO_CACHE_H
+#pragma once
 
 // Qt includes
 
@@ -34,6 +33,7 @@ class AlbumShortInfo;
 class ItemInfoData;
 
 // NOTE: No need to EXPORT this class
+
 class ItemInfoCache : public QObject
 {
     Q_OBJECT
@@ -41,7 +41,7 @@ class ItemInfoCache : public QObject
 public:
 
     ItemInfoCache();
-    ~ItemInfoCache() override;
+    ~ItemInfoCache() override = default;
 
     /**
      * Return an ItemInfoData object for the given image id.
@@ -106,12 +106,10 @@ private:
     QMultiHash<QString, QExplicitlySharedDataPointer<ItemInfoData> > m_nameHash;
     QHash<qlonglong, QExplicitlySharedDataPointer<ItemInfoData> >    m_infoHash;
     QHash<qlonglong, QString>                                        m_dataHash;
-    volatile bool                                                    m_needUpdateAlbums;
-    volatile bool                                                    m_needUpdateGrouped;
+    volatile bool                                                    m_needUpdateAlbums     = true;
+    volatile bool                                                    m_needUpdateGrouped    = true;
     QList<qlonglong>                                                 m_grouped;
     QList<AlbumShortInfo>                                            m_albums;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ITEM_INFO_CACHE_H
