@@ -7,7 +7,7 @@
  * Description : Qt item model for database entries
  *
  * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -93,6 +93,7 @@ public:
         else if (index.row() >= extraValues.size())
         {
             qCDebug(DIGIKAM_GENERAL_LOG) << "Invalid index for extraData" << index;
+
             return false;
         }
 
@@ -133,14 +134,17 @@ ItemModel::ItemModel(QObject* const parent)
       d                 (new Private)
 {
     // --- NOTE: use dynamic binding as slotAlbumChange() is a virtual slot which can be re-implemented in derived classes.
+
     connect(CoreDbAccess::databaseWatch(), static_cast<void (CoreDbWatch::*)(const AlbumChangeset&)>(&CoreDbWatch::albumChange),
             this, &ItemModel::slotAlbumChange);
 
     // --- NOTE: use dynamic binding as slotImageChange() is a virtual slot which can be re-implemented in derived classes.
+
     connect(CoreDbAccess::databaseWatch(), static_cast<void (CoreDbWatch::*)(const ImageChangeset&)>(&CoreDbWatch::imageChange),
             this, &ItemModel::slotImageChange);
 
     // --- NOTE: use dynamic binding as slotImageTagChange() is a virtual slot which can be re-implemented in derived classes.
+
     connect(CoreDbAccess::databaseWatch(), static_cast<void (CoreDbWatch::*)(const ImageTagChangeset&)>(&CoreDbWatch::imageTagChange),
             this, &ItemModel::slotImageTagChange);
 }
@@ -212,7 +216,7 @@ QList<ItemInfo> ItemModel::imageInfos(const QList<QModelIndex>& indexes) const
 {
     QList<ItemInfo> infos;
 
-    Q_FOREACH (const QModelIndex& index, indexes)
+    for (const QModelIndex& index : std::as_const(indexes))
     {
         infos << imageInfo(index);
     }
@@ -224,7 +228,7 @@ QList<qlonglong> ItemModel::imageIds(const QList<QModelIndex>& indexes) const
 {
     QList<qlonglong> ids;
 
-    Q_FOREACH (const QModelIndex& index, indexes)
+    for (const QModelIndex& index : std::as_const(indexes))
     {
         ids << imageId(index);
     }
@@ -337,7 +341,7 @@ int ItemModel::numberOfIndexesForImageId(qlonglong id) const
     int count = 0;
     QMultiHash<qlonglong, int>::const_iterator it;
 
-    for (it = d->idHash.constFind(id) ; it != d->idHash.constEnd() && it.key() == id ; ++it)
+    for (it = d->idHash.constFind(id) ; (it != d->idHash.constEnd()) && (it.key() == id) ; ++it)
     {
         ++count;
     }
@@ -346,6 +350,7 @@ int ItemModel::numberOfIndexesForImageId(qlonglong id) const
 }
 
 // static method
+
 ItemInfo ItemModel::retrieveItemInfo(const QModelIndex& index)
 {
     if (!index.isValid())
@@ -365,6 +370,7 @@ ItemInfo ItemModel::retrieveItemInfo(const QModelIndex& index)
 }
 
 // static method
+
 qlonglong ItemModel::retrieveImageId(const QModelIndex& index)
 {
     if (!index.isValid())
@@ -446,7 +452,7 @@ ItemInfo ItemModel::imageInfo(const QString& filePath) const
     }
     else
     {
-        Q_FOREACH (const ItemInfo& info, d->infos)
+        for (const ItemInfo& info : std::as_const(d->infos))
         {
             if (info.filePath() == filePath)
             {    // cppcheck-suppress useStlAlgorithm
@@ -468,7 +474,9 @@ QList<ItemInfo> ItemModel::imageInfos(const QString& filePath) const
 
         if (id != -1)
         {
-            Q_FOREACH (int index, d->idHash.values(id))
+            const auto ids = d->idHash.values(id);
+
+            for (int index : ids)
             {
                 infos << d->infos.at(index);
             }
@@ -476,7 +484,7 @@ QList<ItemInfo> ItemModel::imageInfos(const QString& filePath) const
     }
     else
     {
-        Q_FOREACH (const ItemInfo& info, d->infos)
+        for (const ItemInfo& info : std::as_const(d->infos))
         {
             if (info.filePath() == filePath)
             {
@@ -533,6 +541,7 @@ void ItemModel::addItemInfosSynchronously(const QList<ItemInfo>& infos, const QL
     }
 
     publiciseInfos(infos, extraValues);
+
     Q_EMIT processAdded(infos, extraValues);
 }
 
@@ -632,7 +641,7 @@ bool ItemModel::hasImage(qlonglong id, const QVariant& extraValue) const
 
     QMultiHash<qlonglong, int>::const_iterator it;
 
-    for (it = d->idHash.constFind(id) ; it != d->idHash.constEnd() && it.key() == id ; ++it)
+    for (it = d->idHash.constFind(id) ; (it != d->idHash.constEnd()) && (it.key() == id) ; ++it)
     {
         if (d->extraValues.at(it.value()) == extraValue)
         {
@@ -675,6 +684,7 @@ void ItemModel::emitDataChangedForAll()
 
     QModelIndex first = createIndex(0, 0);
     QModelIndex last  = createIndex(d->infos.size() - 1, 0);
+
     Q_EMIT dataChanged(first, last);
 }
 
@@ -682,7 +692,7 @@ void ItemModel::emitDataChangedForSelection(const QItemSelection& selection)
 {
     if (!selection.isEmpty())
     {
-        Q_FOREACH (const QItemSelectionRange& range, selection)
+        for (const QItemSelectionRange& range : std::as_const(selection))
         {
             Q_EMIT dataChanged(range.topLeft(), range.bottomRight());
         }
@@ -727,6 +737,7 @@ void ItemModel::appendInfos(const QList<ItemInfo>& infos, const QList<QVariant>&
     if (d->preprocessor)
     {
         d->reAdding = true;
+
         Q_EMIT preprocess(infos, extraValues);
     }
     else
@@ -737,13 +748,14 @@ void ItemModel::appendInfos(const QList<ItemInfo>& infos, const QList<QVariant>&
 
 void ItemModel::appendInfosChecked(const QList<ItemInfo>& infos, const QList<QVariant>& extraValues)
 {
-    // This method does deduplication. It is private because in context of readding or refreshing it is of no use.
+    // This method does deduplication. It is private because in context of
+    // readding or refreshing it is of no use.
 
     if (extraValues.isEmpty())
     {
         QList<ItemInfo> checkedInfos;
 
-        Q_FOREACH (const ItemInfo& info, infos)
+        for (const ItemInfo& info : std::as_const(infos))
         {
             if (!hasImage(info))
             {
@@ -924,7 +936,7 @@ void ItemModel::removeIndexes(const QList<QModelIndex>& indexes)
 {
     QList<int> listIndexes;
 
-    Q_FOREACH (const QModelIndex& index, indexes)
+    for (const QModelIndex& index : std::as_const(indexes))
     {
         if (d->isValid(index))
         {
@@ -949,7 +961,7 @@ void ItemModel::removeItemInfos(const QList<ItemInfo>& infos)
 {
     QList<int> listIndexes;
 
-    Q_FOREACH (const ItemInfo& info, infos)
+    for (const ItemInfo& info : std::as_const(infos))
     {
         QModelIndex index = indexForImageId(info.id());
 
@@ -1048,7 +1060,7 @@ void ItemModel::removeRowPairs(const QList<QPair<int, int> >& toRemove)
     QList<qlonglong>        removeFilePaths;
     typedef QPair<int, int> IntPair;            // to make foreach macro happy
 
-    Q_FOREACH (const IntPair& pair, toRemove)
+    for (const IntPair& pair : std::as_const(toRemove))
     {
         const int begin = pair.first  - offset;
         const int end   = pair.second - offset; // inclusive
@@ -1068,7 +1080,7 @@ void ItemModel::removeRowPairs(const QList<QPair<int, int> >& toRemove)
             Q_EMIT imageInfosAboutToBeRemoved(removedInfos);
         }
 
-        imageInfosAboutToBeRemoved(begin, end);
+        prepareImageInfosAboutToBeRemoved(begin, end);
         beginRemoveRows(QModelIndex(), begin, end);
 
         // update idHash - which points to indexes of d->infos, and these change now!
@@ -1148,7 +1160,7 @@ void ItemModelIncrementalUpdater::appendInfos(const QList<ItemInfo>& infos, cons
 {
     if (extraValues.isEmpty())
     {
-        Q_FOREACH (const ItemInfo& info, infos)
+        for (const ItemInfo& info : std::as_const(infos))
         {
             QMultiHash<qlonglong, int>::iterator it = oldIds.find(info.id());
 
@@ -1170,11 +1182,14 @@ void ItemModelIncrementalUpdater::appendInfos(const QList<ItemInfo>& infos, cons
             bool found           = false;
             QMultiHash<qlonglong, int>::iterator it;
 
-            for (it = oldIds.find(info.id()) ; it != oldIds.end() && it.key() == info.id() ; ++it)
+            for (it = oldIds.find(info.id()) ; (it != oldIds.end()) && (it.key() == info.id()) ; ++it)
             {
                 // first check is for bug #262596. Not sure if needed.
 
-                if (it.value() < oldExtraValues.size() && extraValues.at(i) == oldExtraValues.at(it.value()))
+                if (
+                    (it.value() < oldExtraValues.size()) &&
+                    (extraValues.at(i) == oldExtraValues.at(it.value()))
+                   )
                 {
                     found = true;
                     break;
@@ -1206,14 +1221,14 @@ QList<QPair<int, int> > ItemModelIncrementalUpdater::oldIndexes()
     // first, apply all changes to indexes by direct removal in model
     // while the updater was active
 
-    Q_FOREACH (const IntPairList& list, modelRemovals)
+    for (const IntPairList& list : std::as_const(modelRemovals))
     {
         int removedRows = 0;
         int offset      = 0;
 
-        Q_FOREACH (const IntPair& pair, list)
+        for (const IntPair& pair : std::as_const(list))
         {
-            const int begin = pair.first - offset;
+            const int begin = pair.first  - offset;
             const int end   = pair.second - offset; // inclusive
             removedRows     = end - begin + 1;
 
@@ -1398,7 +1413,7 @@ void ItemModel::slotAlbumChange(const AlbumChangeset& changeset)
 
     if (changeset.operation() & AlbumChangeset::Renamed)
     {
-        Q_FOREACH (const ItemInfo& info, d->infos)
+        for (const ItemInfo& info : std::as_const(d->infos))
         {
             if (changeset.albumId() == info.albumId())
             {
@@ -1422,14 +1437,16 @@ void ItemModel::slotImageChange(const ImageChangeset& changeset)
         {
             if (d->keepFilePathCache)
             {
-                Q_FOREACH (const qlonglong& id, changeset.ids())
+                const auto ids = changeset.ids();
+
+                for (const qlonglong& id : ids)
                 {
                     d->filePathHash.remove(d->filePathHash.key(id));
                     int index = d->idHash.value(id, -1);
 
                     if (index != -1)
                     {
-                        const ItemInfo& info = d->infos.at(index);
+                        const ItemInfo& info             = d->infos.at(index);
                         d->filePathHash[info.filePath()] = id;
                     }
                 }
@@ -1439,8 +1456,9 @@ void ItemModel::slotImageChange(const ImageChangeset& changeset)
         }
 
         QItemSelection items;
+        const auto ids = changeset.ids();
 
-        Q_FOREACH (const qlonglong& id, changeset.ids())
+        for (const qlonglong& id : ids)
         {
             QModelIndex index = indexForImageId(id);
 
@@ -1453,6 +1471,7 @@ void ItemModel::slotImageChange(const ImageChangeset& changeset)
         if (!items.isEmpty())
         {
             emitDataChangedForSelection(items);
+
             Q_EMIT imageChange(changeset, items);
         }
     }
@@ -1466,8 +1485,9 @@ void ItemModel::slotImageTagChange(const ImageTagChangeset& changeset)
     }
 
     QItemSelection items;
+    const auto ids = changeset.ids();
 
-    Q_FOREACH (const qlonglong& id, changeset.ids())
+    for (const qlonglong& id : ids)
     {
         QModelIndex index = indexForImageId(id);
 
