@@ -6,21 +6,12 @@
  * Date        : 2017-07-08
  * Description : Similarity database interface.
  *
- * Copyright (C)      2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C)      2017 by Swati Lodha    <swatilodha27 at gmail dot com>
- * Copyright (C)      2018 by Mario Frank    <mario dot frank at uni minus potsdam dot de>
+ * SPDX-FileCopyrightText:      2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText:      2017 by Swati Lodha    <swatilodha27 at gmail dot com>
+ * SPDX-FileCopyrightText:      2018 by Mario Frank    <mario dot frank at uni minus potsdam dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -29,6 +20,7 @@
 // Local includes
 
 #include "digikam_debug.h"
+#include "digikam_globals.h"
 
 namespace Digikam
 {
@@ -38,12 +30,9 @@ class Q_DECL_HIDDEN SimilarityDb::Private
 
 public:
 
-    explicit Private() :
-        db(nullptr)
-    {
-    }
+    Private() = default;
 
-    SimilarityDbBackend* db;
+    SimilarityDbBackend* db = nullptr;
 };
 
 SimilarityDb::SimilarityDb(SimilarityDbBackend* const backend)
@@ -77,6 +66,7 @@ QString SimilarityDb::getSetting(const QString& keyword)
     QList<QVariant> values;
 
     // TODO Should really check return status here
+
     BdEngineBackend::QueryState queryStateResult =
             d->db->execDBAction(d->db->getDBAction(QString::fromUtf8("SelectSimilaritySetting")),
                                                    parameters, &values);
@@ -98,9 +88,11 @@ QString SimilarityDb::getLegacySetting(const QString& keyword)
     QList<QVariant> values;
 
     // TODO Should really check return status here
+
     BdEngineBackend::QueryState queryStateResult =
             d->db->execDBAction(d->db->getDBAction(QString::fromUtf8("SelectSimilarityLegacySetting")),
                                                    parameters, &values);
+
     qCDebug(DIGIKAM_SIMILARITYDB_LOG) << "SimilarityDb SelectSimilaritySetting val ret = "
                                       << (BdEngineBackend::QueryStateEnum)queryStateResult;
 
@@ -120,7 +112,8 @@ QSet<qlonglong> SimilarityDb::registeredImageIds() const
     QList<QVariant> values;
 
     // Get all image ids from the first and second imageid column of the ImageSimilarity table.
-    d->db->execSql(QString::fromUtf8("SELECT imageid1, imageId2 FROM ImageSimilarity;"),
+
+    d->db->execSql(QString::fromUtf8("SELECT imageid1, imageid2 FROM ImageSimilarity;"),
                    &values);
 
     for (QList<QVariant>::const_iterator it = values.constBegin() ; it != values.constEnd() ; )
@@ -134,10 +127,11 @@ QSet<qlonglong> SimilarityDb::registeredImageIds() const
     values.clear();
 
     // get all image ids from the ImageHaarMatrix table.
+
     d->db->execSql(QString::fromUtf8("SELECT imageid FROM ImageHaarMatrix;"),
                    &values);
 
-    foreach (const QVariant& var, values)
+    for (const QVariant& var : std::as_const(values))
     {
         imageIds << var.toLongLong();
     }
@@ -158,6 +152,7 @@ bool SimilarityDb::hasFingerprint(qlonglong imageId, FuzzyAlgorithm algorithm) c
                        imageId, &values);
 
         // return true if there is at least one fingerprint
+
         return !values.isEmpty();
     }
 
@@ -181,6 +176,7 @@ bool SimilarityDb::hasFingerprints(FuzzyAlgorithm algorithm) const
                        &values);
 
         // return true if there is at least one fingerprint
+
         return !values.isEmpty();
     }
 
@@ -200,15 +196,21 @@ bool SimilarityDb::hasDirtyOrMissingFingerprint(const ItemInfo& imageInfo, Fuzzy
         if (values.isEmpty())
         {
             // The image id does not exist -> missing fingerprint
+
             return true;
         }
         else
         {
             // The image id exists -> if uniqueHash or modificationDate differ, we need a new fingerprint.
+
             if (values.size() == 2)
             {
-                if ((values.at(0).toDateTime() != imageInfo.modDateTime()) ||
-                    (values.at(1).toString()   != imageInfo.uniqueHash()))
+                QDateTime modDateTime = asDateTimeUTC(values.at(0).toDateTime());
+
+                if (
+                    (modDateTime             != imageInfo.modDateTime()) ||
+                    (values.at(1).toString() != imageInfo.uniqueHash())
+                   )
                 {
                     return true;
                 }
@@ -226,7 +228,7 @@ QList<qlonglong> SimilarityDb::getDirtyOrMissingFingerprints(const QList<ItemInf
 
     if (algorithm == FuzzyAlgorithm::Haar)
     {
-        foreach (const ItemInfo& info, imageInfos)
+        for (const ItemInfo& info : std::as_const(imageInfos))
         {
             QList<QVariant> values;
 
@@ -237,15 +239,21 @@ QList<qlonglong> SimilarityDb::getDirtyOrMissingFingerprints(const QList<ItemInf
             if (values.isEmpty())
             {
                 // The image id does not exist -> missing fingerprint
+
                 itemIDs << info.id();
             }
             else
             {
                 // The image id exists -> if uniqueHash or modificationDate differ, we need a new fingerprint.
+
                 if (values.size() == 2)
                 {
-                    if ((values.at(0).toDateTime() != info.modDateTime()) ||
-                        (values.at(1).toString()   != info.uniqueHash()))
+                    QDateTime modDateTime = asDateTimeUTC(values.at(0).toDateTime());
+
+                    if (
+                        (modDateTime             != info.modDateTime()) ||
+                        (values.at(1).toString() != info.uniqueHash())
+                       )
                     {
                         itemIDs << info.id();
                     }
@@ -264,7 +272,7 @@ QStringList SimilarityDb::getDirtyOrMissingFingerprintURLs(const QList<ItemInfo>
 
     if (algorithm == FuzzyAlgorithm::Haar)
     {
-        foreach (const ItemInfo& info, imageInfos)
+        for (const ItemInfo& info : std::as_const(imageInfos))
         {
             QList<QVariant> values;
 
@@ -275,15 +283,21 @@ QStringList SimilarityDb::getDirtyOrMissingFingerprintURLs(const QList<ItemInfo>
             if (values.isEmpty())
             {
                 // The image id does not exist -> missing fingerprint
+
                 urls << info.filePath();
             }
             else
             {
                 // The image id exists -> if uniqueHash or modificationDate differ, we need a new fingerprint.
+
                 if (values.size() == 2)
                 {
-                    if ((values.at(0).toDateTime() != info.modDateTime()) ||
-                        (values.at(1).toString()   != info.uniqueHash()))
+                    QDateTime modDateTime = asDateTimeUTC(values.at(0).toDateTime());
+
+                    if (
+                        (modDateTime             != info.modDateTime()) ||
+                        (values.at(1).toString() != info.uniqueHash())
+                       )
                     {
                         urls << info.filePath();
                     }
@@ -310,7 +324,7 @@ void SimilarityDb::copySimilarityAttributes(qlonglong srcId, qlonglong dstId)
 void SimilarityDb::removeImageFingerprint(qlonglong imageID,
                                           FuzzyAlgorithm algorithm)
 {
-    if (algorithm == FuzzyAlgorithm::Haar)
+    if      (algorithm == FuzzyAlgorithm::Haar)
     {
         d->db->execSql(QString::fromUtf8("DELETE FROM ImageHaarMatrix WHERE imageid=?;"),
                        imageID);
@@ -321,6 +335,7 @@ void SimilarityDb::removeImageFingerprint(qlonglong imageID,
     }
 
     // Also, remove all similarities for the image and algorithm if the backend is a MySQL DB.
+
     if (d->db->databaseType() == BdEngineBackend::DbType::MySQL)
     {
         removeImageSimilarity(imageID, algorithm);
@@ -331,7 +346,7 @@ void SimilarityDb::removeImageFingerprint(qlonglong imageID,
 
 double SimilarityDb::getImageSimilarity(qlonglong imageID1, qlonglong imageID2, FuzzyAlgorithm algorithm)
 {
-    if (imageID1 < 0 || imageID2 < 0)
+    if ((imageID1 < 0) || (imageID2 < 0))
     {
         return -1;
     }
@@ -339,6 +354,7 @@ double SimilarityDb::getImageSimilarity(qlonglong imageID1, qlonglong imageID2,
     // If the image ids are the same, we return 1 which is equivalent to 100%.
     // We do not have to access the database here as the same image id implies
     // the same image and thus identity.
+
     if (imageID1 == imageID2)
     {
         return 1;
@@ -350,10 +366,10 @@ double SimilarityDb::getImageSimilarity(qlonglong imageID1, qlonglong imageID2,
     // Also, no disjunction is necessary in the query.
 
     QPair<qlonglong, qlonglong> orderedIds = orderIds(imageID1, imageID2);
-
-    QString similarityValueString = getImageSimilarityOrdered(orderedIds.first, orderedIds.second, algorithm);
+    QString similarityValueString          = getImageSimilarityOrdered(orderedIds.first, orderedIds.second, algorithm);
 
     // If the similarity is non-null
+
     if (!similarityValueString.isEmpty())
     {
         bool ok;
@@ -372,7 +388,8 @@ double SimilarityDb::getImageSimilarity(qlonglong imageID1, qlonglong imageID2,
     }
 
     // Return the info that there is no value.
-    return -1;
+
+    return (-1);
 }
 
 void SimilarityDb::setImageSimilarity(qlonglong imageID1, qlonglong imageID2, double value, FuzzyAlgorithm algorithm)
@@ -409,9 +426,9 @@ void SimilarityDb::setImageSimilarity(qlonglong imageID1, qlonglong imageID2, do
     }
 
     d->db->execSql(QString::fromUtf8("REPLACE INTO ImageSimilarity "
-                                     "(imageid1, imageid2, value, algorithm) "
+                                     "(imageid1, imageid2, algorithm, value) "
                                      " VALUES(?, ?, ?, ?);"),
-                   orderedIds.first, orderedIds.second, value, (int)algorithm);
+                   orderedIds.first, orderedIds.second, (int)algorithm, value);
 }
 
 void SimilarityDb::removeImageSimilarity(qlonglong imageID, FuzzyAlgorithm algorithm)
@@ -450,11 +467,11 @@ QList<FuzzyAlgorithm> SimilarityDb::getImageSimilarityAlgorithms(qlonglong image
 
     QList<FuzzyAlgorithm> algorithms;
 
-    foreach (const QVariant& var, values)
+    for (const QVariant& var : std::as_const(values))
     {
         int algorithmId = var.toInt();
 
-        if (algorithmId == 1)
+        if      (algorithmId == 1)
         {
             algorithms << FuzzyAlgorithm::Haar;
         }
@@ -477,13 +494,29 @@ bool SimilarityDb::integrityCheck()
     switch (d->db->databaseType())
     {
         case BdEngineBackend::DbType::SQLite:
+        {
             // For SQLite the integrity check returns a single row with one string column "ok" on success and multiple rows on error.
-            return values.size() == 1 && values.first().toString().toLower().compare(QLatin1String("ok")) == 0;
+
+            bool result = (
+                           (values.size() == 1) &&
+                           (values.first().toString().toLower().compare(QLatin1String("ok")) == 0)
+                          );
+
+            if (!result && !values.isEmpty())
+            {
+                qCWarning(DIGIKAM_DATABASE_LOG) << "Failed integrity check for SQLite similarity database:"
+                                                << values.first().toString();
+            }
+
+            return result;
+        }
 
         case BdEngineBackend::DbType::MySQL:
+        {
             // For MySQL, for every checked table, the table name, operation (check), message type (status) and the message text (ok on success)
             // are returned. So we check if there are four elements and if yes, whether the fourth element is "ok".
             //qCDebug(DIGIKAM_DATABASE_LOG) << "MySQL check returned " << values.size() << " rows";
+
             if ((values.size() % 4) != 0)
             {
                 return false;
@@ -500,11 +533,23 @@ bool SimilarityDb::integrityCheck()
                 QString messageText = (*it).toString();
                 ++it;
 
-                if (messageText.toLower().compare(QLatin1String("ok")) != 0)
+                Q_UNUSED(operation);
+
+                if (!messageText.isEmpty())
                 {
-                    qCDebug(DIGIKAM_DATABASE_LOG) << "Failed integrity check for table "
-                                                  << tableName << ". Reason:" << messageText;
-                    return false;
+                    if ((messageType.toLower().compare(QLatin1String("note")) == 0))
+                    {
+                        qCWarning(DIGIKAM_DATABASE_LOG) << "Failed integrity check for table "
+                                                        << tableName << ". Reason:" << messageText;
+                    }
+
+                    if (
+                        (messageType.toLower().compare(QLatin1String("status")) == 0) &&
+                        (messageText.toLower().compare(QLatin1String("ok"))     != 0)
+                       )
+                    {
+                        return false;
+                    }
                 }
                 else
                 {
@@ -516,10 +561,14 @@ bool SimilarityDb::integrityCheck()
             }
 
             // No error conditions. Db passed the integrity check.
+
             return true;
+        }
 
         default:
+        {
             return false;
+        }
     }
 }
 
@@ -536,7 +585,8 @@ QPair<qlonglong, qlonglong> SimilarityDb::orderIds(qlonglong id1, qlonglong id2)
 
     if (id1 <= id2)
     {
-        // If the first id is smaller or equal to the second, set it as fst.
+        // If the first id is smaller or equal to the second, set it as first.
+
         ordered.first  = id1;
         ordered.second = id2;
     }
@@ -555,8 +605,7 @@ QString SimilarityDb::getImageSimilarityOrdered(qlonglong imageID1, qlonglong im
 
     d->db->execSql(QString::fromUtf8("SELECT value FROM ImageSimilarity "
                                      "WHERE ( imageid1=? OR imageid2=? ) AND algorithm=?;"),
-                   imageID1, imageID2, (int)algorithm,
-                   &values);
+                   imageID1, imageID2, (int)algorithm, &values);
 
     if (values.isEmpty())
     {
