@@ -7,7 +7,7 @@
  * Description : digiKam 8/16 bits image management API
  *               Files input output
  *
- * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -222,6 +222,12 @@ QString DImg::formatToMimeType(FORMAT frm)
             break;
         }
 
+        case (HEIF):
+        {
+            format = QLatin1String("HEIC");
+            break;
+        }
+
         default:
         {
             // For QImage or ImageMagick based.
@@ -323,27 +329,20 @@ QDateTime DImg::creationDateFromFilesystem(const QFileInfo& fileInfo) const
 {
     // creation date is not what it seems on Unix
 
-    QDateTime ctime = fileInfo.birthTime();
-    QDateTime mtime = fileInfo.lastModified();
+    QDateTime ctime = asDateTimeUTC(fileInfo.birthTime());
+    QDateTime mtime = asDateTimeUTC(fileInfo.lastModified());
 
     if (ctime.isValid())
     {
-        ctime.setTimeSpec(Qt::UTC);
-
         return ctime;
     }
 
     if (mtime.isValid())
     {
-        mtime.setTimeSpec(Qt::UTC);
-
         return mtime;
     }
 
-    QDateTime dateTime = QDateTime::currentDateTime();
-    dateTime.setTimeSpec(Qt::UTC);
-
-    return dateTime;
+    return asDateTimeUTC(QDateTime::currentDateTime());
 }
 
 } // namespace Digikam
