@@ -7,7 +7,7 @@
  * Description : digiKam 8/16 bits image management API.
  *               Metadata operations.
  *
- * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -261,19 +261,24 @@ void DImg::prepareMetadataToSave(const QString& intendedDestPath, const QString&
             // a thumbnail at a special location. See bug #211758
 
             meta->setTiffThumbnail(thumb);
+
+            // Update Exif Image dimensions.
+            // Disable Exif.Photo.PixelX(Y)Dimension in TIFF files.
+
+            meta->setItemDimensions(size(), false);
         }
         else
         {
             // Update Exif thumbnail.
 
             meta->setExifThumbnail(thumb);
+
+            // Update Exif Image dimensions.
+
+            meta->setItemDimensions(size());
         }
     }
 
-    // Update Exif Image dimensions.
-
-    meta->setItemDimensions(size());
-
     // Update Exif Document Name tag with the original file name.
 
     if (!originalFileName.isEmpty())
@@ -563,7 +568,7 @@ QByteArray DImg::createUniqueHashV2(const QString& filePath)
 
     if (size)
     {
-        QScopedArrayPointer<char> databuf(new char[size]);
+        QScopedArrayPointer<char> databuf(new char[size] { 0 });
         int read;
 
         // Read first 100 kB
@@ -579,7 +584,17 @@ QByteArray DImg::createUniqueHashV2(const QString& filePath)
 
         if ((read = file.read(databuf.data(), size)) > 0)
         {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 3, 0))
+
+            md5.addData(QByteArrayView(databuf.data(), read));
+
+#else
+
             md5.addData(databuf.data(), read);
+
+#endif
+
         }
     }
 
@@ -605,28 +620,36 @@ QByteArray DImg::createUniqueHashV3(const QString& filePath)
     const qint64 firstSize = 100 * 1024;         // 100 kB
     const qint64 nextSize  = 25  * 1024;         //  25 kB
     const qint64 fsize     = qMin(file.size(), firstSize);
-    const qint64 bsize     = file.size() - fsize;
 
-    const qint64 block     = (bsize < nextSize) ? bsize
-                                                : nextSize;
-    const qint64 step      = qMax(bsize - block, (qint64)5) / 5;
+    const qint64 bsize     = file.size() - fsize;
+    const qint64 block     = qMin(bsize, nextSize);
+    const qint64 step      = (bsize - block) / 5 + 1;
 
     if (fsize)
     {
-        QScopedArrayPointer<char> databuf(new char[fsize]);
+        QScopedArrayPointer<char> databuf(new char[fsize] { 0 });
         qint64 read;
 
-        for (int i = 0 ; i < 6 ; ++i)
+        for (int sp = 0 ; sp < 6 ; ++sp)
         {
-            qint64 rsize = (i == 0) ? fsize : block;
-            qint64 rstep = (i == 5) ? file.size() - rsize
-                                    : step * i + firstSize;
+            qint64 rsize = !sp ? fsize : block;
+            qint64 rstep = !sp ? 0 : step * sp + fsize;
 
-            file.seek(qMin((i == 0) ? 0 : rstep, file.size() - rsize));
+            file.seek(qMin(rstep, file.size() - rsize));
 
             if ((read = file.read(databuf.data(), rsize)) > 0)
             {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 3, 0))
+
+                md5.addData(QByteArrayView(databuf.data(), read));
+
+#else
+
                 md5.addData(databuf.data(), read);
+
+#endif
+
             }
 
             if (file.atEnd())
