@@ -7,23 +7,13 @@
  * Description : Local Contrast settings view.
  *               LDR ToneMapper zynaddsubfx.sourceforge.net/other/tonemapping
  *
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_LOCAL_CONTRAST_SETTINGS_H
-#define DIGIKAM_LOCAL_CONTRAST_SETTINGS_H
+#pragma once
 
 // Local includes
 
@@ -71,9 +61,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_LOCAL_CONTRAST_SETTINGS_H
