@@ -6,15 +6,14 @@
  * Date        : 2010-12-15
  * Description : Red Eyes auto correction settings container.
  *
- * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2016      by Omar Amin <Omar dot moh dot amin at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_RED_EYE_CORRECTION_CONTAINER_H
-#define DIGIKAM_RED_EYE_CORRECTION_CONTAINER_H
+#pragma once
 
 // Qt includes
 
@@ -34,7 +33,7 @@ class DIGIKAM_EXPORT RedEyeCorrectionContainer
 
 public:
 
-    explicit RedEyeCorrectionContainer();
+    RedEyeCorrectionContainer() = default;
 
     bool isDefault()                                            const;
     bool operator==(const RedEyeCorrectionContainer& other)     const;
@@ -47,9 +46,7 @@ public:
 
 public:
 
-    double m_redToAvgRatio;
+    double m_redToAvgRatio = 2.1;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_RED_EYE_CORRECTION_CONTAINER_H
