@@ -4,17 +4,16 @@
  * https://www.digikam.org
  *
  * Date        : 28/08/2021
- * Description : Image Quality Parser - Compression basic factor detection
+ * Description : Image Quality Parser - Compression detection basic factor
  *
- * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2021-2022 by Phuoc Khanh Le <phuockhanhnk94 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_COMPRESSION_DETECTOR_H
-#define DIGIKAM_COMPRESSION_DETECTOR_H
+#pragma once
 
 // Local includes
 
@@ -30,7 +29,7 @@ class CompressionDetector : public AbstractDetector
 public:
 
     explicit CompressionDetector();
-    ~CompressionDetector();
+    ~CompressionDetector()                                        override;
 
     float detect(const cv::Mat& image)                      const override;
 
@@ -50,9 +49,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_COMPRESSION_DETECTOR_H
