@@ -6,7 +6,7 @@
  * Date        : 2006-02-23
  * Description : item metadata interface - tags helpers.
  *
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2011      by Leif Huhn <leif at dkstat dot com>
  *
@@ -304,7 +304,7 @@ bool DMetadata::setItemTagsPath(const QStringList& tagsPath, const DMetadataSett
                     if      (writeWithExifTool() && !newList.isEmpty())
                     {
                         QString xpKeywords = newList.join(entry.separator);
-                        QByteArray xpData  = QByteArray((char*)xpKeywords.utf16(), xpKeywords.size() * 2);
+                        QByteArray xpData  = QByteArray(reinterpret_cast<const char*>(xpKeywords.utf16()), xpKeywords.size() * 2);
                         xpData.append("\x00\x00");
 
                         if (!setExifTagData(nameSpace, xpData))
