@@ -6,8 +6,8 @@
  * Date        : 28/08/2021
  * Description : Extraction of focus points by exiftool data
  *
- * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * SPDX-FileCopyrightText: 2021 by Phuoc Khanh Le <phuockhanhnk94 at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021      by Phuoc Khanh Le <phuockhanhnk94 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -28,21 +28,16 @@ class Q_DECL_HIDDEN FocusPointsExtractor::Private
 
 public:
 
-    explicit Private()
-        : exifToolAvailable(false),
-          afPointsReadOnly (true),
-          orientation      (MetaEngine::ORIENTATION_UNSPECIFIED)
-    {
-    }
+    Private() = default;
 
-    ListAFPoints                    af_points;          ///< List of AF points extracted from metadata.
-    bool                            exifToolAvailable;  ///< True if ExifTool binary is available.
-    ExifToolParser::ExifToolData    metadata;           ///< List of tags parsed by ExifTool.
-    bool                            afPointsReadOnly;   ///< True if AF points are read-only in metadata.
-    QString                         make;               ///< Camera Manufacturer Name
-    QString                         model;              ///< Camera Model Name.
-    QSize                           originalSize;       ///< Original size of image taken by camera
-    MetaEngine::ImageOrientation    orientation;        ///< Image orientation set by camera.
+    ListAFPoints                    af_points;                                                  ///< List of AF points extracted from metadata.
+    bool                            exifToolAvailable = false;                                  ///< True if ExifTool binary is available.
+    ExifToolParser::ExifToolData    metadata;                                                   ///< List of tags parsed by ExifTool.
+    bool                            afPointsReadOnly  = true;                                   ///< True if AF points are read-only in metadata.
+    QString                         make;                                                       ///< Camera Manufacturer Name
+    QString                         model;                                                      ///< Camera Model Name.
+    QSize                           originalSize;                                               ///< Original size of image taken by camera
+    MetaEngine::ImageOrientation    orientation       = MetaEngine::ORIENTATION_UNSPECIFIED;    ///< Image orientation set by camera.
 };
 
 FocusPointsExtractor::FocusPointsExtractor(QObject* const parent,const QString& image_path)
@@ -130,7 +125,7 @@ QVariant FocusPointsExtractor::findValue(const QString& tagNameRoot, const QStri
 
 QVariant FocusPointsExtractor::findValueFirstMatch(const QStringList& listTagNames, bool isList) const
 {
-    for (const QString& tagName : listTagNames)
+    for (const QString& tagName : EXIV2_AS_CONST(listTagNames))
     {
         QVariant tmp = findValue(tagName, isList);
 
@@ -145,7 +140,7 @@ QVariant FocusPointsExtractor::findValueFirstMatch(const QStringList& listTagNam
 
 QVariant FocusPointsExtractor::findValueFirstMatch(const QString& tagNameRoot, const QStringList& keys, bool isList) const
 {
-    for (const QString& key : keys)
+    for (const QString& key : EXIV2_AS_CONST(keys))
     {
         QVariant tmp = findValue(tagNameRoot, key, isList);
 
@@ -212,7 +207,7 @@ FocusPointsExtractor::ListAFPoints FocusPointsExtractor::get_af_points(FocusPoin
 {
     ListAFPoints points;
 
-    for (const auto& point : d->af_points)
+    for (const auto& point : EXIV2_AS_CONST(d->af_points))
     {
         if (type == FocusPoint::TypePoint::Inactive)
         {
