@@ -7,7 +7,7 @@
  * Description : image file IO threaded interface.
  *
  * SPDX-FileCopyrightText: 2005-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -28,13 +28,9 @@ SharedLoadSaveThread::SharedLoadSaveThread(QObject* const parent)
 {
 }
 
-SharedLoadSaveThread::~SharedLoadSaveThread()
-{
-}
-
-void SharedLoadSaveThread::load(const LoadingDescription& description,
-                                AccessMode mode,
-                                LoadingPolicy policy)
+void SharedLoadSaveThread::loadShared(const LoadingDescription& description,
+                                      AccessMode mode,
+                                      LoadingPolicy policy)
 {
     ManagedLoadSaveThread::load(description, LoadingModeShared, policy, mode);
 }
