@@ -6,14 +6,13 @@
  * Date        : 2006-01-20
  * Description : action categorized view
  *
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ACTION_CATEGORIZED_VIEW_H
-#define DIGIKAM_ACTION_CATEGORIZED_VIEW_H
+#pragma once
 
 // Local includes
 
@@ -36,7 +35,7 @@ class DIGIKAM_EXPORT ActionCategorizedView : public DCategorizedView
 public:
 
     explicit ActionCategorizedView(QWidget* const parent = nullptr, bool autoScroll = false);
-    ~ActionCategorizedView()            override;
+    ~ActionCategorizedView()            override = default;
 
     void setupIconMode();
     void adjustGridSize();
@@ -50,11 +49,9 @@ protected:
 
 protected:
 
-    QPropertyAnimation* m_verticalScrollAnimation;
-    QPropertyAnimation* m_horizontalScrollAnimation;
-    bool                m_autoScroll;
+    QPropertyAnimation* m_verticalScrollAnimation   = nullptr;
+    QPropertyAnimation* m_horizontalScrollAnimation = nullptr;
+    bool                m_autoScroll                = false;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ACTION_CATEGORIZED_VIEW_H
