@@ -6,7 +6,7 @@
  * Date        : 2006-02-22
  * Description : a generic widget to display metadata
  *
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -363,9 +363,9 @@ QString MetadataWidget::metadataToText() const
 
                     if (lvItem2)
                     {
-                        textmetadata.append(lvItem2->text(0));
+                        textmetadata.append(lvItem2->getTitle());
                         textmetadata.append(QLatin1String(" : "));
-                        textmetadata.append(lvItem2->text(1));
+                        textmetadata.append(lvItem2->getFullValue());
                         textmetadata.append(QLatin1Char('\n'));
                     }
                 }
