@@ -6,14 +6,13 @@
  * Date        : 2007-07-19
  * Description : A widget to display XMP metadata
  *
- * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_XMP_WIDGET_H
-#define DIGIKAM_XMP_WIDGET_H
+#pragma once
 
 // Local includes
 
@@ -31,7 +30,7 @@ public:
 
     explicit XmpWidget(QWidget* const parent,
                        const QString& name = QString());
-    ~XmpWidget()                                    override;
+    ~XmpWidget()                                    override = default;
 
     bool loadFromURL(const QUrl& url)               override;
 
@@ -55,5 +54,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_XMP_WIDGET_H
