@@ -6,14 +6,13 @@
  * Date        : 2023-08-16
  * Description : Spell-check Config widget.
  *
- * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SPELL_CHECK_CONFIG_H
-#define DIGIKAM_SPELL_CHECK_CONFIG_H
+#pragma once
 
 // Qt includes
 
@@ -49,9 +48,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_SPELL_CHECK_CONFIG_H
