@@ -6,14 +6,13 @@
  * Date        : 2021-08-27
  * Description : Showfoto folder view bookmark places
  *
- * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef SHOWFOTO_FOLDER_VIEW_BOOKMARKS_H
-#define SHOWFOTO_FOLDER_VIEW_BOOKMARKS_H
+#pragma once
 
 // Qt includes
 
@@ -54,7 +53,7 @@ Q_SIGNALS:
 private Q_SLOTS:
 
     void slotLoadContents(const QString& path);
-    void slotBookmarkDoubleClicked(QTreeWidgetItem*);
+    void slotBookmarkActivated(QTreeWidgetItem*);
     void slotBookmarkSelectionChanged();
     void slotAddBookmark(const QString&);
     void slotAddBookmark();
@@ -68,9 +67,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace ShowFoto
-
-#endif // SHOWFOTO_FOLDER_VIEW_BOOKMARKS_H
