@@ -6,7 +6,7 @@
  * Date        : 2021-08-27
  * Description : Showfoto folder view undo command.
  *
- * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -27,12 +27,9 @@ class Q_DECL_HIDDEN ShowfotoFolderViewUndo::Private
 
 public:
 
-    explicit Private()
-      : view(nullptr)
-    {
-    }
+    Private() = default;
 
-    ShowfotoFolderViewSideBar* view;
+    ShowfotoFolderViewSideBar* view     = nullptr;
     QString                    oldPath;
     QString                    newPath;
 };
