@@ -7,14 +7,13 @@
  * Description : Qt model view for Showfoto item - the delegate Private
  *
  * SPDX-FileCopyrightText: 2013      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * SPDX-FileCopyrightText: 2013-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef SHOW_FOTO_DELEGATE_P_H
-#define SHOW_FOTO_DELEGATE_P_H
+#pragma once
 
 #include "showfotodelegate.h"
 
@@ -48,17 +47,11 @@ class Q_DECL_HIDDEN ShowfotoDelegate::ShowfotoDelegatePrivate : public ShowfotoI
 public:
 
     ShowfotoDelegatePrivate()
-      : contentWidth       (0),
-        drawImageFormat    (true),
-        drawFocusFrame     (true),
-        drawMouseOverFrame (true),
-        currentView        (nullptr),
-        currentModel       (nullptr)
     {
         actualPixmapRectCache.setMaxCost(250);
     }
 
-    int                    contentWidth;
+    int                    contentWidth             = 0;
 
     QRect                  dateRect;
     QRect                  pixmapRect;
@@ -69,14 +62,14 @@ public:
     QRect                  groupRect;
     QRect                  coordinatesRect;
 
-    bool                   drawImageFormat;
-    bool                   drawFocusFrame;
-    bool                   drawMouseOverFrame;
+    bool                   drawImageFormat          = true;
+    bool                   drawFocusFrame           = true;
+    bool                   drawMouseOverFrame       = true;
 
     QCache<int, QRect>     actualPixmapRectCache;
 
-    ShowfotoThumbnailBar*  currentView;
-    QAbstractItemModel*    currentModel;
+    ShowfotoThumbnailBar*  currentView              = nullptr;
+    QAbstractItemModel*    currentModel             = nullptr;
 
 public:
 
@@ -90,7 +83,6 @@ class Q_DECL_HIDDEN ShowfotoThumbnailDelegatePrivate : public ShowfotoDelegate::
 public:
 
     ShowfotoThumbnailDelegatePrivate()
-      : flow              (QListView::LeftToRight)
     {
         // switch off drawing of frames
 
@@ -102,7 +94,7 @@ public:
 
 public:
 
-    QListView::Flow flow;
+    QListView::Flow flow        = QListView::LeftToRight;
     QRect           viewSize;
 };
 
@@ -112,13 +104,9 @@ class Q_DECL_HIDDEN ShowfotoNormalDelegatePrivate : public ShowfotoDelegate::Sho
 {
 public:
 
-    ShowfotoNormalDelegatePrivate()
-    {
-    }
+    ShowfotoNormalDelegatePrivate() = default;
 
     void init(ShowfotoNormalDelegate* const q, ShowfotoThumbnailBar* const parent);
 };
 
 } // namespace Showfoto
-
-#endif // SHOW_FOTO_DELEGATE_P_H
