@@ -7,7 +7,7 @@
  * Description : Thumbnail bar for Showfoto
  *
  * SPDX-FileCopyrightText: 2013      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -47,7 +47,7 @@ public:
 
 ShowfotoThumbnailBar::ShowfotoThumbnailBar(QWidget* const parent)
     : ShowfotoCategorizedView(parent),
-      d                      (new Private())
+      d                      (new Private)
 {
     setItemDelegate(new ShowfotoThumbnailDelegate(this));
     setSpacing(3);
@@ -173,11 +173,6 @@ void ShowfotoThumbnailBar::setFlow(QListView::Flow flow)
     setScrollBarPolicy(d->scrollPolicy);
 }
 
-void ShowfotoThumbnailBar::slotSetupChanged()
-{
-    ShowfotoCategorizedView::slotSetupChanged();
-}
-
 bool ShowfotoThumbnailBar::event(QEvent* e)
 {
     // reset widget max/min sizes
