@@ -47,48 +47,48 @@ class Q_DECL_HIDDEN FunnelReal::Private
 public:
 
     explicit Private()
-        : isLoaded          (false),
-          numParams         (4),          // similarity transforms - x translation, y translation, rotation, uniform scaling
-          windowSize        (4),
-          maxProcessAtOnce  (600),        // set based on memory limitations,
-          outerDimW         (150),
-          outerDimH         (150),
-          innerDimW         (100),
-          innerDimH         (100),
-          siftHistDim       (4),
-          siftBucketsDim    (8),
-          siftDescDim       ((4*windowSize*windowSize*siftBucketsDim) / (siftHistDim*siftHistDim)),
-          numRandPxls       (0),
+        : isLoaded(false),
+          numParams(4),                   // similarity transforms - x translation, y translation, rotation, uniform scaling
+          windowSize(4),
+          maxProcessAtOnce(600),          // set based on memory limitations,
+          outerDimW(150),
+          outerDimH(150),
+          innerDimW(100),
+          innerDimH(100),
+          siftHistDim(4),
+          siftBucketsDim(8),
+          siftDescDim((4 * windowSize * windowSize * siftBucketsDim) / (siftHistDim * siftHistDim)),
+          numRandPxls(0),
           numFeatureClusters(0),
-          edgeDescDim       (0)
+          edgeDescDim(0)
     {
-/*
-        if (outerDimW - innerDimW < 2*windowSize)
-        {
-            qCDebug(DIGIKAM_FACESENGINE_LOG) << "difference between outerDimW and innerDimW is not greater than window size for SIFT descriptor)";
-            return -1;
-        }
+        /*
+                if (outerDimW - innerDimW < 2*windowSize)
+                {
+                    qCDebug(DIGIKAM_DETECTOR_LOG) << "difference between outerDimW and innerDimW is not greater than window size for SIFT descriptor)";
+                    return -1;
+                }
 
-        if ((outerDimW - innerDimW) % 2 != 0)
-        {
-            qCDebug(DIGIKAM_FACESENGINE_LOG) << "shrinking innerDimW by 1 so outerDimW - innerDimW is divisible by 2";
-            --innerDimW;
-        }
+                if ((outerDimW - innerDimW) % 2 != 0)
+                {
+                    qCDebug(DIGIKAM_DETECTOR_LOG) << "shrinking innerDimW by 1 so outerDimW - innerDimW is divisible by 2";
+                    --innerDimW;
+                }
 
-        if (outerDimH - innerDimH < 2*windowSize)
-        {
-            qCDebug(DIGIKAM_FACESENGINE_LOG) << "difference between outerDimH and innerDimH is not greater than window size for SIFT descriptor)";
-            return -1;
-        }
+                if (outerDimH - innerDimH < 2*windowSize)
+                {
+                    qCDebug(DIGIKAM_DETECTOR_LOG) << "difference between outerDimH and innerDimH is not greater than window size for SIFT descriptor)";
+                    return -1;
+                }
 
-        if ((outerDimH - innerDimH) % 2 != 0)
-        {
-            qCDebug(DIGIKAM_FACESENGINE_LOG) << "shrinking innerDimH by 1 so outerDimH - innerDimH is divisible by 2";
-            --innerDimH;
-        }
-*/
-        paddingW = ((outerDimW - innerDimW) - 2*windowSize) / 2;
-        paddingH = ((outerDimH - innerDimH) - 2*windowSize) / 2;
+                if ((outerDimH - innerDimH) % 2 != 0)
+                {
+                    qCDebug(DIGIKAM_DETECTOR_LOG) << "shrinking innerDimH by 1 so outerDimH - innerDimH is divisible by 2";
+                    --innerDimH;
+                }
+        */
+        paddingW = ((outerDimW - innerDimW) - 2 * windowSize) / 2;
+        paddingH = ((outerDimH - innerDimH) - 2 * windowSize) / 2;
     }
 
     void loadTrainingData(const QString& path);
@@ -107,27 +107,27 @@ public:
                                         const int height)                           const;
 
     /// Part 3: Applies the transformation (v, form computeTransform) to the given image, returns the result.
-    cv::Mat applyTransform      (const cv::Mat& image,
-                                 const std::vector<float>& v,
-                                 int h,
-                                 int w)                                             const;
+    cv::Mat applyTransform(const cv::Mat& image,
+                           const std::vector<float>& v,
+                           int h,
+                           int w)                                             const;
 
     // Utilities
-    void getSIFTdescripter      (std::vector<float>& descripter,
-                                 const std::vector<std::vector<float> >& m,
-                                 const std::vector<std::vector<float> >& theta,
-                                 int x, int y, int windowSize, int histDim, int bucketsDim,
-                                 const std::vector<std::vector<float> >& Gaussian)  const;
+    void getSIFTdescripter(std::vector<float>& descripter,
+                           const std::vector<std::vector<float> >& m,
+                           const std::vector<std::vector<float> >& theta,
+                           int x, int y, int windowSize, int histDim, int bucketsDim,
+                           const std::vector<std::vector<float> >& Gaussian)  const;
 
-    float computeLogLikelihood  (const std::vector<std::vector<float> >& logDistField,
-                                 const std::vector<std::vector<float> >& fids,
-                                 int numFeatureClusters) const;
+    float computeLogLikelihood(const std::vector<std::vector<float> >& logDistField,
+                               const std::vector<std::vector<float> >& fids,
+                               int numFeatureClusters) const;
 
-    void  getNewFeatsInvT       (std::vector<std::vector<float> >& newFIDs,
-                                 const std::vector<std::vector<std::vector<float> > >& originalFeats,
-                                 const std::vector<float>& vparams,
-                                 float centerX,
-                                 float centerY)                                     const;
+    void  getNewFeatsInvT(std::vector<std::vector<float> >& newFIDs,
+                          const std::vector<std::vector<std::vector<float> > >& originalFeats,
+                          const std::vector<float>& vparams,
+                          float centerX,
+                          float centerY)                                     const;
 
 public:
 
@@ -165,14 +165,14 @@ FunnelReal::FunnelReal()
     : d(new Private)
 {
     QString filesPath = DTestDataDir::TestData(QString::fromUtf8("core/tests/faceengine/alignment"))
-                           .root().path() + QLatin1Char('/');
+                        .root().path() + QLatin1Char('/');
     qCDebug(DIGIKAM_TESTS_LOG) << "Test Data Dir:" << filesPath;
 
     QString trainingFile = filesPath + QLatin1String("face-funnel.data"); ///< data model file
 
     if (!QFileInfo::exists(trainingFile))
     {
-        qCritical(DIGIKAM_FACESENGINE_LOG) << "Training data for Congealing/Funnel not found. Should be at" << trainingFile;
+        qCritical(DIGIKAM_DETECTOR_LOG) << "Training data for Congealing/Funnel not found. Should be at" << trainingFile;
 
         return;
     }
@@ -198,7 +198,7 @@ cv::Mat FunnelReal::align(const cv::Mat& inputImage)
 
     cv::resize(inputImage, scaled, cv::Size(d->outerDimW, d->outerDimH), 0, 0,
                ((d->outerDimW < inputImage.cols) ? cv::INTER_AREA
-                                                 : cv::INTER_CUBIC));
+                : cv::INTER_CUBIC));
 
     // ensure it's grayscale
 
@@ -206,6 +206,7 @@ cv::Mat FunnelReal::align(const cv::Mat& inputImage)
     {
         cvtColor(scaled, grey, CV_RGB2GRAY);
     }
+
     else
     {
         grey = scaled;
@@ -215,8 +216,8 @@ cv::Mat FunnelReal::align(const cv::Mat& inputImage)
 
     grey.convertTo(image, CV_32F);
 
-    const int height     = image.rows - 2*d->windowSize;
-    const int width      = image.cols - 2*d->windowSize;
+    const int height     = image.rows - 2 * d->windowSize;
+    const int width      = image.cols - 2 * d->windowSize;
 
     std::vector<std::vector<std::vector<float> > > originalFeatures;
 
@@ -283,13 +284,15 @@ void FunnelReal::Private::loadTrainingData(const QString& path)
             logDFSeq.push_back(logDistField);
         }
     }
+
     catch (const std::ifstream::failure& e)
     {
-        qCritical(DIGIKAM_FACESENGINE_LOG) << "Error loading Congealing/Funnel training data:" << e.what();
+        qCritical(DIGIKAM_DETECTOR_LOG) << "Error loading Congealing/Funnel training data:" << e.what();
     }
+
     catch (...)
     {
-        qCritical(DIGIKAM_FACESENGINE_LOG) << "Default exception";
+        qCritical(DIGIKAM_DETECTOR_LOG) << "Default exception";
     }
 
     computeGaussian(Gaussian, windowSize);
@@ -299,15 +302,15 @@ void FunnelReal::Private::loadTrainingData(const QString& path)
 
 void FunnelReal::Private::computeGaussian(std::vector<std::vector<float> >& gaussian, int windowSize) const
 {
-    for (int i = 0 ; i < 2*windowSize ; ++i)
+    for (int i = 0 ; i < 2 * windowSize ; ++i)
     {
-        std::vector<float> grow(2*windowSize);
+        std::vector<float> grow(2 * windowSize);
 
-        for (int j = 0 ; j < 2*windowSize ; ++j)
+        for (int j = 0 ; j < 2 * windowSize ; ++j)
         {
-            float ii = i-(windowSize-0.5f);
-            float jj = j-(windowSize-0.5f);
-            grow[j]  = exp(-(ii*ii + jj*jj) / (2*windowSize*windowSize));
+            float ii = i - (windowSize - 0.5f);
+            float jj = j - (windowSize - 0.5f);
+            grow[j]  = exp(-(ii * ii + jj * jj) / (2 * windowSize * windowSize));
         }
 
         gaussian.push_back(grow);
@@ -320,7 +323,7 @@ static float dist(const std::vector<float>& a, const std::vector<float>& b)
 
     for (int i = 0 ; i < (signed)a.size() ; ++i)
     {
-        r += (a[i]-b[i])*(a[i]-b[i]);
+        r += (a[i] - b[i]) * (a[i] - b[i]);
     }
 
     return r;
@@ -353,41 +356,45 @@ void FunnelReal::Private::computeOriginalFeatures(std::vector<std::vector<std::v
         const float* row;
         row = image.ptr<float>(j);
 
-        if      (j == 0)
+        if (j == 0)
         {
-            greaterRow = image.ptr<float>(j+1);
+            greaterRow = image.ptr<float>(j + 1);
             lesserRow  = row;
         }
-        else if (j == image.rows-1)
+
+        else if (j == image.rows - 1)
         {
             greaterRow = row;
-            lesserRow  = image.ptr<float>(j-1);
+            lesserRow  = image.ptr<float>(j - 1);
         }
+
         else
         {
-            greaterRow = image.ptr<float>(j+1);
-            lesserRow  = image.ptr<float>(j-1);
+            greaterRow = image.ptr<float>(j + 1);
+            lesserRow  = image.ptr<float>(j - 1);
         }
 
         for (int k = 0 ; k < image.cols ; ++k)
         {
             dy = greaterRow[k] - lesserRow[k];
 
-            if      (k == 0)
+            if (k == 0)
             {
-                dx = row[k+1] - row[k];
-            }
-            else if (k == image.cols-1)
-            {
-                dx = row[k] - row[k-1];
-            }
-            else
-            {
-                dx = row[k+1] - row[k-1];
+                dx = row[k + 1] - row[k];
             }
 
-            m[j][k]     = (float)sqrt(dx*dx+dy*dy);
-            theta[j][k] = (float)atan2(dy,dx) * 180.0f/M_PI;
+            else if (k == image.cols - 1)
+            {
+                dx = row[k] - row[k - 1];
+            }
+
+            else
+            {
+                dx = row[k + 1] - row[k - 1];
+            }
+
+            m[j][k]     = (float)sqrt(dx * dx + dy * dy);
+            theta[j][k] = (float)atan2(dy, dx) * 180.0f / M_PI;
 
             if (theta[j][k] < 0)
             {
@@ -403,8 +410,8 @@ void FunnelReal::Private::computeOriginalFeatures(std::vector<std::vector<std::v
             getSIFTdescripter(SiftDesc,
                               m,
                               theta,
-                              j+windowSize,
-                              k+windowSize,
+                              j + windowSize,
+                              k + windowSize,
                               windowSize,
                               siftHistDim,
                               siftBucketsDim,
@@ -416,7 +423,7 @@ void FunnelReal::Private::computeOriginalFeatures(std::vector<std::vector<std::v
 
     for (int j = 0 ; j < height ; ++j)
     {
-        for(int k = 0 ; k < width ; ++k)
+        for (int k = 0 ; k < width ; ++k)
         {
             std::vector<float> distances(numFeatureClusters);
             float sum = 0;
@@ -424,7 +431,7 @@ void FunnelReal::Private::computeOriginalFeatures(std::vector<std::vector<std::v
             for (int ii = 0 ; ii < numFeatureClusters ; ++ii)
             {
                 distances[ii] = exp(-dist(originalFeatures[j][k], centroids[ii]) /
-                                (2*sigmaSq[ii])) / sqrt(sigmaSq[ii]);
+                                    (2 * sigmaSq[ii])) / sqrt(sigmaSq[ii]);
 
                 sum          += distances[ii];
             }
@@ -453,15 +460,16 @@ std::vector<float> FunnelReal::Private::computeTransform(const std::vector<std::
 
     std::vector<float>               nfEntry(numFeatureClusters, 0);
     std::vector<std::vector<float> > newFIDs(numRandPxls, nfEntry);
-    float centerX = width/2.0f;
-    float centerY = height/2.0f;
+    float centerX = width / 2.0f;
+    float centerY = height / 2.0f;
 
-    float d[] = {
-                    1.0f,
-                    1.0f,
-                    (float)M_PI / 180.0f,
-                    0.02f
-                };
+    float d[] =
+    {
+        1.0f,
+        1.0f,
+        (float)M_PI / 180.0f,
+        0.02f
+    };
 
     getNewFeatsInvT(featureIDs, originalFeatures, v, centerX, centerY);
 
@@ -471,7 +479,7 @@ std::vector<float> FunnelReal::Private::computeTransform(const std::vector<std::
 
         for (int k = 0 ; k < numParams ; ++k)
         {
-            float dn = QRandomGenerator::global()->bounded(-80, 80)/100.0f;
+            float dn = QRandomGenerator::global()->bounded(-80, 80) / 100.0f;
 
             if (k > 1)
             {
@@ -488,9 +496,10 @@ std::vector<float> FunnelReal::Private::computeTransform(const std::vector<std::
                 featureIDs = newFIDs;
                 oldL       = newL;
             }
+
             else
             {
-                v[k] -= (2*(d[k] + dn));
+                v[k] -= (2 * (d[k] + dn));
                 getNewFeatsInvT(newFIDs, originalFeatures, v, centerX, centerY);
                 newL  = computeLogLikelihood(logDFSeq[iter], newFIDs, numFeatureClusters);
 
@@ -499,9 +508,10 @@ std::vector<float> FunnelReal::Private::computeTransform(const std::vector<std::
                     oldL       = newL;
                     featureIDs = newFIDs;
                 }
+
                 else
                 {
-                    v[k] += (d[k]+dn);
+                    v[k] += (d[k] + dn);
                 }
             }
         }
@@ -515,15 +525,15 @@ cv::Mat FunnelReal::Private::applyTransform(const cv::Mat& image,
                                             int h,
                                             int w) const
 {
-    float cropT1inv[2][3] = {{1 , 0, image.cols/2.0f}, {0, 1, image.rows/2.0f}};
-    float cropS1inv[3][3] = {{image.cols/(float)w, 0, 0}, {0, image.rows/(float)h, 0}, {0, 0, 1}};
-    float cropS2inv[3][3] = {{w/(float)image.cols, 0, 0}, {0, h/(float)image.rows, 0}, {0, 0, 1}};
-    float cropT2inv[3][3] = {{1, 0, -image.cols/2.0f}, {0, 1, -image.rows/2.0f}, {0, 0, 1}};
+    float cropT1inv[2][3] = {{1, 0, image.cols / 2.0f}, {0, 1, image.rows / 2.0f}};
+    float cropS1inv[3][3] = {{image.cols / (float)w, 0, 0}, {0, image.rows / (float)h, 0}, {0, 0, 1}};
+    float cropS2inv[3][3] = {{w / (float)image.cols, 0, 0}, {0, h / (float)image.rows, 0}, {0, 0, 1}};
+    float cropT2inv[3][3] = {{1, 0, -image.cols / 2.0f}, {0, 1, -image.rows / 2.0f}, {0, 0, 1}};
 
-    float postM[3][3]     = {{1, 0,  w/2.0f}, {0, 1,  h/2.0f}, {0, 0, 1}};
-    float preM[3][3]      = {{1, 0, -w/2.0f}, {0, 1, -h/2.0f}, {0, 0, 1}};
+    float postM[3][3]     = {{1, 0,  w / 2.0f}, {0, 1,  h / 2.0f}, {0, 0, 1}};
+    float preM[3][3]      = {{1, 0, -w / 2.0f}, {0, 1, -h / 2.0f}, {0, 0, 1}};
 
-    float tM[3][3]        = {{1, 0, v[0]}, {0, 1, v[1]}, {0,0,1}};
+    float tM[3][3]        = {{1, 0, v[0]}, {0, 1, v[1]}, {0, 0, 1}};
     float rM[3][3]        = {{cosf(v[2]), -sinf(v[2]), 0}, {sinf(v[2]), cosf(v[2]), 0}, {0, 0, 1}};
     float sM[3][3]        = {{expf(v[3]), 0, 0}, {0, expf(v[3]), 0}, {0, 0, 1}};
 
@@ -534,10 +544,10 @@ cv::Mat FunnelReal::Private::applyTransform(const cv::Mat& image,
     cv::Mat postCVM(3, 3, CV_32FC1, postM);
     cv::Mat preCVM(3, 3, CV_32FC1, preM);
 
-    cv::Mat cropT1invCVM(2,3, CV_32FC1, cropT1inv);
-    cv::Mat cropS1invCVM(3,3, CV_32FC1, cropS1inv);
-    cv::Mat cropS2invCVM(3,3, CV_32FC1, cropS2inv);
-    cv::Mat cropT2invCVM(3,3, CV_32FC1, cropT2inv);
+    cv::Mat cropT1invCVM(2, 3, CV_32FC1, cropT1inv);
+    cv::Mat cropS1invCVM(3, 3, CV_32FC1, cropS1inv);
+    cv::Mat cropS2invCVM(3, 3, CV_32FC1, cropS2inv);
+    cv::Mat cropT2invCVM(3, 3, CV_32FC1, cropT2inv);
 
     cv::Mat xform(2, 3, CV_32FC1);
 
@@ -574,15 +584,15 @@ void FunnelReal::Private::getSIFTdescripter(std::vector<float>& descripter,
 
     // weight magnitudes by Gaussian with sigma equal to half window
 
-    std::vector<float> mtimesGRow(2*windowSize);
-    std::vector<std::vector<float> > mtimesG(2*windowSize, mtimesGRow);
+    std::vector<float> mtimesGRow(2 * windowSize);
+    std::vector<std::vector<float> > mtimesG(2 * windowSize, mtimesGRow);
 
-    for (int i = 0 ; i < 2*windowSize ; ++i)
+    for (int i = 0 ; i < 2 * windowSize ; ++i)
     {
-        for (int j = 0 ; j < 2*windowSize ; ++j)
+        for (int j = 0 ; j < 2 * windowSize ; ++j)
         {
-            int xx        = x+i-(windowSize-1);
-            int yy        = y+j-(windowSize-1);
+            int xx        = x + i - (windowSize - 1);
+            int yy        = y + j - (windowSize - 1);
             mtimesG[i][j] = m[xx][yy] * Gaussian[i][j];
         }
     }
@@ -593,40 +603,40 @@ void FunnelReal::Private::getSIFTdescripter(std::vector<float>& descripter,
     int histBin[2], histX[2], histY[2];
     float dX[2], dY[2], dBin[2];
 
-    for (int i = 0; i < 2*windowSize ; ++i)
+    for (int i = 0; i < 2 * windowSize ; ++i)
     {
-        for (int j = 0 ; j < 2*windowSize ; ++j)
+        for (int j = 0 ; j < 2 * windowSize ; ++j)
         {
-            histX[0]      = i/histDim;
-            histX[1]      = i/histDim;
-            histY[0]      = j/histDim;
-            histY[1]      = j/histDim;
+            histX[0]      = i / histDim;
+            histX[1]      = i / histDim;
+            histY[0]      = j / histDim;
+            histY[1]      = j / histDim;
             dX[1]         = 0;
             dY[1]         = 0;
 
             int iModHD    = i % histDim;
             int jModHD    = j % histDim;
-            int histDimD2 = histDim/2;
+            int histDimD2 = histDim / 2;
 
-            if ( iModHD >= histDimD2 && i < 2*windowSize - histDimD2 )
+            if (iModHD >= histDimD2 && i < 2 * windowSize - histDimD2)
             {
                 histX[1] = histX[0] + 1;
                 dX[1]    = (iModHD + 0.5f - histDimD2) / histDim;
             }
 
-            if ( iModHD < histDimD2 && i >= histDimD2 )
+            if (iModHD < histDimD2 && i >= histDimD2)
             {
                 histX[1] = histX[0] - 1;
                 dX[1]    = (histDimD2 + 0.5f - iModHD) / histDim;
             }
 
-            if ( jModHD >= histDimD2 && j < 2*windowSize - histDimD2 )
+            if (jModHD >= histDimD2 && j < 2 * windowSize - histDimD2)
             {
                 histY[1] = histY[0] + 1;
                 dY[1]    = (jModHD + 0.5f - histDimD2) / histDim;
             }
 
-            if ( jModHD < histDimD2 && j >= histDimD2)
+            if (jModHD < histDimD2 && j >= histDimD2)
             {
                 histY[1] = histY[0] - 1;
                 dY[1]    = (histDimD2 + 0.5f - jModHD) / histDim;
@@ -635,12 +645,12 @@ void FunnelReal::Private::getSIFTdescripter(std::vector<float>& descripter,
             dX[0]           = 1.0f - dX[1];
             dY[0]           = 1.0f - dY[1];
 
-            float histAngle = theta[x+i-(windowSize-1)][y+j-(windowSize-1)];
+            float histAngle = theta[x + i - (windowSize - 1)][y + j - (windowSize - 1)];
 
             histBin[0]      = (int)(histAngle / degPerBin);
-            histBin[1]      = (histBin[0]+1) % bucketsDim;
-            dBin[1]         = (histAngle - histBin[0]*degPerBin) / degPerBin;
-            dBin[0]         = 1.0f-dBin[1];
+            histBin[1]      = (histBin[0] + 1) % bucketsDim;
+            dBin[1]         = (histAngle - histBin[0] * degPerBin) / degPerBin;
+            dBin[0]         = 1.0f - dBin[1];
 
             for (int histBinIndex = 0 ; histBinIndex < 2 ; ++histBinIndex)
             {
@@ -648,9 +658,9 @@ void FunnelReal::Private::getSIFTdescripter(std::vector<float>& descripter,
                 {
                     for (int histYIndex = 0; histYIndex < 2 ; ++histYIndex)
                     {
-                        int histNum                           = histX[histXIndex]*histDimWidth + histY[histYIndex];
+                        int histNum                           = histX[histXIndex] * histDimWidth + histY[histYIndex];
                         int bin                               = histBin[histBinIndex];
-                        descripter[histNum*bucketsDim + bin] += (mtimesG[i][j] * dX[histXIndex] * dY[histYIndex] * dBin[histBinIndex]);
+                        descripter[histNum * bucketsDim + bin] += (mtimesG[i][j] * dX[histXIndex] * dY[histYIndex] * dBin[histBinIndex]);
                     }
                 }
             }
@@ -669,9 +679,9 @@ void FunnelReal::Private::getSIFTdescripter(std::vector<float>& descripter,
 
     if (sum < .0000001f)
     {
-/*
-        float dn = 1.0f / (signed)descripter.size(); // is unused, don't know
-*/
+        /*
+                float dn = 1.0f / (signed)descripter.size(); // is unused, don't know
+        */
         for (int i = 0 ; i < (signed)descripter.size() ; ++i)
         {
             descripter[i] = 0;
@@ -710,7 +720,7 @@ void FunnelReal::Private::getNewFeatsInvT(std::vector<std::vector<float> >& newF
                                           float centerY) const
 {
     int numFeats      = (int)newFIDs[0].size();
-    std::vector<float> uniformDist(numFeats, 1.0f/numFeats);
+    std::vector<float> uniformDist(numFeats, 1.0f / numFeats);
 
     float postM[2][3] = {{1, 0,  centerX}, {0, 1, centerY}};
     float preM[3][3]  = {{1, 0, -centerX}, {0, 1, -centerY}, {0, 0, 1}};
@@ -739,13 +749,14 @@ void FunnelReal::Private::getNewFeatsInvT(std::vector<std::vector<float> >& newF
     {
         int j  = randPxls[i].first;
         int k  = randPxls[i].second;
-        int nx = (int)(xform.at<float>(0)*k + xform.at<float>(1)*j + xform.at<float>(2) + 0.5f);
-        int ny = (int)(xform.at<float>(3)*k + xform.at<float>(4)*j + xform.at<float>(5) + 0.5f);
+        int nx = (int)(xform.at<float>(0) * k + xform.at<float>(1) * j + xform.at<float>(2) + 0.5f);
+        int ny = (int)(xform.at<float>(3) * k + xform.at<float>(4) * j + xform.at<float>(5) + 0.5f);
 
         if (!(ny >= 0 && ny < height && nx >= 0 && nx < width))
         {
             newFIDs[i] = uniformDist;
         }
+
         else
         {
             newFIDs[i] = originalFeats[ny][nx];
