@@ -6,15 +6,14 @@
  * Date        : 28/08/2021
  * Description : an unit-test to detect image quality level
  *
- * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2021-2022 by Phuoc Khanh Le <phuockhanhnk94 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DETECT_EXPOSURE_UTEST_H
-#define DIGIKAM_DETECT_EXPOSURE_UTEST_H
+#pragma once
 
 // Qt includes
 
@@ -68,5 +67,3 @@ DataTestCases const dataTestCases =
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DETECT_EXPOSURE_UTEST_H
