@@ -6,19 +6,10 @@
  * Date        : 28/08/2021
  * Description : an unit-test to detect image quality level
  *
- * Copyright (C) 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2021 by Phuoc Khanh Le <phuockhanhnk94 at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2022 by Phuoc Khanh Le <phuockhanhnk94 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -35,7 +26,6 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "imgqsorttest.h"
 
 using namespace Digikam;
 
@@ -92,3 +82,5 @@ void ImgQSortTestDetectNoise::testParseTestImagesForVariousTypeNoiseFailCase()
         QVERIFY(results.value(test_case));
     }
 }
+
+#include "moc_detectnoise_utest.cpp"
