@@ -6,7 +6,7 @@
  * Date        : 2009-02-04
  * Description : an unit-test to detect image quality level - shared code
  *
- * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2021-2022 by Phuoc Khanh Le <phuockhanhnk94 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -24,19 +24,19 @@
 #include "dimg.h"
 #include "previewloadthread.h"
 #include "imagequalityparser.h"
-#include "imagequalitycontainer.h"
+#include "imagequalitysettings.h"
 #include "dpluginloader.h"
 
 namespace Digikam
 {
 
-ImageQualityContainer ImgQSortTest_ArrangeSettings (DetectionType type)
+ImageQualitySettings ImgQSortTest_ArrangeSettings (DetectionType type)
 {
     qCDebug(DIGIKAM_TESTS_LOG) << "Process images for detection type "<<type;
 
     qCInfo(DIGIKAM_TESTS_LOG)  << "Detection type (0:Blur, 1:Noise, 2:Compression, 3:Exposure, 4: General)";
 
-    ImageQualityContainer settings;
+    ImageQualitySettings settings;
 
     settings.detectBlur         = false;
     settings.detectNoise        = false;
@@ -78,14 +78,14 @@ ImageQualityContainer ImgQSortTest_ArrangeSettings (DetectionType type)
     return settings;
 }
 
-ImageQualityContainer ImgQSortTest_ArrangeCustomSettings(const CustomDetection& customSetting)
+ImageQualitySettings ImgQSortTest_ArrangeCustomSettings(const CustomDetection& customSetting)
 {
     qCInfo(DIGIKAM_TESTS_LOG)  << "Detection type activate Blur "<< customSetting.detectBlur
                                << "Noise "      << customSetting.detectNoise
                                << "Compression "<< customSetting.detectCompression
                                << "Exposure "   << customSetting.detectExposure;
 
-    ImageQualityContainer settings;
+    ImageQualitySettings settings;
 
     settings.detectBlur         = customSetting.detectBlur;
     settings.detectCompression  = customSetting.detectCompression;
@@ -96,13 +96,13 @@ ImageQualityContainer ImgQSortTest_ArrangeCustomSettings(const CustomDetection&
     return settings;
 }
 
-QHash<QString, int> ImgQSortTest_ParseTestImagesCore(const ImageQualityContainer& settings, const QFileInfoList& list)
+QHash<QString, int> ImgQSortTest_ParseTestImagesCore(const ImageQualitySettings& settings, const QFileInfoList& list)
 {
     qCDebug(DIGIKAM_TESTS_LOG) << "Quality Detection Settings:" << settings;
 
     QHash<QString, int> results;
 
-    Q_FOREACH (const QFileInfo& inf, list)
+    for (const QFileInfo& inf : std::as_const(list))
     {
         QString path = inf.filePath();
         qCDebug(DIGIKAM_TESTS_LOG) << path;
@@ -122,7 +122,9 @@ QHash<QString, int> ImgQSortTest_ParseTestImagesCore(const ImageQualityContainer
 
     qCInfo(DIGIKAM_TESTS_LOG) << "Quality Results (0:None, 1:Rejected, 2:Pending, 3:Accepted):";
 
-    for (const auto& image_name: results.keys())
+    const auto keys = results.keys();
+
+    for (const auto& image_name : keys)
     {
         qCInfo(DIGIKAM_TESTS_LOG) << "==>" << image_name << ":" << results.value(image_name);
     }
@@ -132,14 +134,14 @@ QHash<QString, int> ImgQSortTest_ParseTestImagesCore(const ImageQualityContainer
 
 QHash<QString, int> ImgQSortTest_ParseTestImagesDefautDetection(DetectionType type, const QFileInfoList& list)
 {
-    ImageQualityContainer settings = ImgQSortTest_ArrangeSettings(type);
+    ImageQualitySettings settings = ImgQSortTest_ArrangeSettings(type);
 
     return ImgQSortTest_ParseTestImagesCore(settings, list);
 }
 
 QHash<QString, int> ImgQSortTest_ParseTestImagesCustomDetection(const CustomDetection& customSetting, const QFileInfoList& list)
 {
-    ImageQualityContainer settings = ImgQSortTest_ArrangeCustomSettings(customSetting);
+    ImageQualitySettings settings = ImgQSortTest_ArrangeCustomSettings(customSetting);
 
     return ImgQSortTest_ParseTestImagesCore(settings, list);
 }
