@@ -6,14 +6,13 @@
  * Date        : 2009-06-11
  * Description : an unit-test tool to erase metadata tag from photo with DMetadata
  *
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ERASE_METADATA_TAG_UTEST_H
-#define DIGIKAM_ERASE_METADATA_TAG_UTEST_H
+#pragma once
 
 // Local includes
 
@@ -41,5 +40,3 @@ private Q_SLOTS:
 
     void testEraseMetadataTag();
 };
-
-#endif // DIGIKAM_ERASE_METADATA_TAG_UTEST_H
