@@ -5,9 +5,10 @@
  *
  * Date        : 2023-05-15
  * Description : geolocation engine based on Marble.
+ *               (c) 2007-2022 Marble Team
+ *               https://invent.kde.org/education/marble/-/raw/master/data/credits_authors.html
  *
- * SPDX-FileCopyrightText: 2007-2022 Marble Team
- * SPDX-FileCopyrightText: 2023-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2023-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
@@ -83,7 +84,7 @@ GeoDataCoordinates::~GeoDataCoordinates()
     }
 
 #ifdef DEBUG_GEODATA
-    //    qCDebug(DIGIKAM_MARBLE_LOG) << "delete coordinates";
+    //    qCDebug(DIGIKAM_GEOENGINE_LOG) << "delete coordinates";
 #endif
 }
 
@@ -641,7 +642,7 @@ QString GeoDataCoordinates::lonToString(qreal lon, GeoDataCoordinates::Notation
             // Includes -1 case!
             if (precision < 5)
             {
-                lonString += QString::fromUtf8(" %3\"").arg(lonSec, 2, 'f', 0, QLatin1Char('0'));
+                lonString += QString::fromUtf8(" %3\"").arg((double)lonSec, 2, 'f', 0, QLatin1Char('0'));
                 return lonString + weString;
             }
 
@@ -724,7 +725,7 @@ QString GeoDataCoordinates::lonToString(qreal lon, GeoDataCoordinates::Notation
         // Includes -1 case!
         if (precision < 5)
         {
-            lonString += QString::fromUtf8(" %3\"").arg(lonSec, 2, 'f', 0, QLatin1Char('0'));
+            lonString += QString::fromUtf8(" %3\"").arg((double)lonSec, 2, 'f', 0, QLatin1Char('0'));
             return lonString;
         }
 
@@ -861,7 +862,7 @@ QString GeoDataCoordinates::latToString(qreal lat, GeoDataCoordinates::Notation
             // Includes -1 case!
             if (precision < 5)
             {
-                latString += QString::fromUtf8(" %3\"").arg(latSec, 2, 'f', 0, QLatin1Char('0'));
+                latString += QString::fromUtf8(" %3\"").arg((double)latSec, 2, 'f', 0, QLatin1Char('0'));
                 return latString + nsString;
             }
 
@@ -1071,7 +1072,7 @@ bool GeoDataCoordinates::isPole(Pole pole) const
             // FIXME: Should we just normalize latitude and longitude and be done?
             //        While this might work well for persistent data it would create some
             //        possible overhead for temporary data, so this needs careful thinking.
-            qCDebug(DIGIKAM_MARBLE_LOG) << "GeoDataCoordinates not normalized!";
+            qCDebug(DIGIKAM_GEOENGINE_LOG) << "GeoDataCoordinates not normalized!";
 
             // Only as a last resort we cover the unlikely case where
             // the latitude is not normalized to the range of
