@@ -6,7 +6,7 @@
  * Date        : 2017-05-15
  * Description : Managemenet dialogs for bookmarks
  *
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -57,21 +57,14 @@ class Q_DECL_HIDDEN AddBookmarkDialog::Private
 {
 public:
 
-    explicit Private()
-      : manager     (nullptr),
-        proxyModel  (nullptr),
-        location    (nullptr),
-        title       (nullptr),
-        desc        (nullptr)
-    {
-    }
+    Private() = default;
 
     QString                url;
-    BookmarksManager*      manager;
-    AddBookmarkProxyModel* proxyModel;
-    QComboBox*             location;
-    DTextEdit*             title;
-    DTextEdit*             desc;
+    BookmarksManager*      manager      = nullptr;
+    AddBookmarkProxyModel* proxyModel   = nullptr;
+    QComboBox*             location     = nullptr;
+    DTextEdit*             title        = nullptr;
+    DTextEdit*             desc         = nullptr;
 };
 
 AddBookmarkDialog::AddBookmarkDialog(const QString& url,
@@ -84,7 +77,13 @@ AddBookmarkDialog::AddBookmarkDialog(const QString& url,
     d->url     = url;
     d->manager = mngr;
 
-    setWindowFlags(Qt::Sheet);
+    setWindowFlags((windowFlags() & ~Qt::Dialog) |
+                   Qt::Window                    |
+                   Qt::WindowCloseButtonHint     |
+                   Qt::WindowMinMaxButtonsHint);
+
+    setModal(true);
+
     setWindowTitle(i18nc("@title:window", "Add Bookmark"));
     setObjectName(QLatin1String("AddBookmarkDialog"));
     resize(350, 300);
@@ -180,22 +179,14 @@ class Q_DECL_HIDDEN BookmarksDialog::Private
 {
 public:
 
-    explicit Private()
-      : manager         (nullptr),
-        bookmarksModel  (nullptr),
-        proxyModel      (nullptr),
-        search          (nullptr),
-        tree            (nullptr),
-        mapView         (nullptr)
-    {
-    }
+    Private() = default;
 
-    BookmarksManager*      manager;
-    BookmarksModel*        bookmarksModel;
-    TreeProxyModel*        proxyModel;
-    SearchTextBar*         search;
-    QTreeView*             tree;
-    ItemPropertiesGPSTab*  mapView;
+    BookmarksManager*      manager          = nullptr;
+    BookmarksModel*        bookmarksModel   = nullptr;
+    TreeProxyModel*        proxyModel       = nullptr;
+    SearchTextBar*         search           = nullptr;
+    QTreeView*             tree             = nullptr;
+    ItemPropertiesGPSTab*  mapView          = nullptr;
 };
 
 BookmarksDialog::BookmarksDialog(QWidget* const parent, BookmarksManager* const mngr)
@@ -297,6 +288,18 @@ void BookmarksDialog::accept()
     QDialog::accept();
 }
 
+void BookmarksDialog::showEvent(QShowEvent* e)
+{
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup group        = config->group(objectName());
+    KConfigGroup groupDialog  = KConfigGroup(&group, QLatin1String("Dialog"));
+
+    DXmlGuiWindow::restoreWindowSize(windowHandle(), groupDialog);
+    resize(windowHandle()->size());
+
+    QDialog::showEvent(e);
+}
+
 void BookmarksDialog::closeEvent(QCloseEvent* e)
 {
     if (!e)
@@ -382,7 +385,7 @@ void BookmarksDialog::slotOpenInMap(const QModelIndex& index)
     QModelIndexList list = d->tree->selectionModel()->selectedIndexes();
     GPSItemInfo::List ilst;
 
-    Q_FOREACH (const QModelIndex& item, list)
+    for (const QModelIndex& item : std::as_const(list))
     {
         QUrl url                  = item.sibling(index.row(), 1)
                                         .data(BookmarksModel::UrlRole).toUrl();
@@ -463,11 +466,6 @@ void BookmarksDialog::readSettings()
     KConfigGroup group        = config->group(objectName());
     KConfigGroup groupGPSTab  = KConfigGroup(&group, QLatin1String("GPS Properties Tab"));
     d->mapView->readSettings(groupGPSTab);
-
-    KConfigGroup groupDialog  = KConfigGroup(&group, QLatin1String("Dialog"));
-    winId();
-    DXmlGuiWindow::restoreWindowSize(windowHandle(), groupDialog);
-    resize(windowHandle()->size());
 }
 
 void BookmarksDialog::saveSettings()
