@@ -6,7 +6,7 @@
  * Date        : 2006-09-19
  * Description : Thread for correlator for tracks and images
  *
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2010      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -28,13 +28,7 @@ bool TrackCorrelationLessThan(const TrackCorrelator::Correlation& a, const Track
 }
 
 TrackCorrelatorThread::TrackCorrelatorThread(QObject* const parent)
-    : QThread (parent),
-      doCancel(false),
-      canceled(false)
-{
-}
-
-TrackCorrelatorThread::~TrackCorrelatorThread()
+    : QThread (parent)
 {
 }
 
