@@ -7,14 +7,13 @@
  * Description : a list of selectable options with preview
  *               effects as thumbnails.
  *
- * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_PREVIEW_LIST_H
-#define DIGIKAM_PREVIEW_LIST_H
+#pragma once
 
 // Qt includes
 
@@ -60,7 +59,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 // -------------------------------------------------------------------
@@ -84,7 +83,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 
 private:
 
@@ -123,9 +122,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_PREVIEW_LIST_H
