@@ -7,7 +7,7 @@
  * Description : Gphoto2 camera interface
  *
  * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -53,6 +53,7 @@ extern "C"
 
 #include "digikam_debug.h"
 #include "digikam_config.h"
+#include "digikam_globals.h"
 #include "dfileoperations.h"
 #include "dmetadata.h"
 
@@ -157,6 +158,11 @@ public:
 
 #endif // HAVE_GPHOTO2
 
+private:
+
+    // Disable
+    GPStatus(const GPStatus&)            = delete;
+    GPStatus& operator=(const GPStatus&) = delete;
 };
 
 bool GPStatus::cancel = false;
@@ -276,8 +282,8 @@ bool GPCamera::doConnect()
     gp_port_info_list_new(&infoList);
     gp_port_info_list_load(infoList);
 
-    int modelNum = gp_abilities_list_lookup_model(abilList, m_model.toLatin1().constData());
-    int portNum  = gp_port_info_list_lookup_path(infoList, m_port.toLatin1().constData());
+    int modelNum = gp_abilities_list_lookup_model(abilList, model().toLatin1().constData());
+    int portNum  = gp_port_info_list_lookup_path(infoList, port().toLatin1().constData());
 
     gp_abilities_list_get_abilities(abilList, modelNum, &d->cameraAbilities);
 
@@ -608,7 +614,7 @@ bool GPCamera::getPreview(QImage& preview)
         return false;
     }
 
-    preview.loadFromData((const uchar*)data, (uint)size);
+    preview.loadFromData(reinterpret_cast<const unsigned char*>(data), (uint)size);
 
     gp_file_unref(cfile);
 
@@ -1022,14 +1028,12 @@ void GPCamera::getItemInfoInternal(const QString& folder, const QString& itemNam
             {
                 if (cfinfo.file.fields & GP_FILE_INFO_MTIME)
                 {
-                    info.ctime = QDateTime::fromSecsSinceEpoch(cfinfo.file.mtime);
+                    info.ctime = asDateTimeUTC(QDateTime::fromSecsSinceEpoch(cfinfo.file.mtime));
                 }
                 else
                 {
-                    info.ctime = QDateTime::currentDateTime();
+                    info.ctime = asDateTimeUTC(QDateTime::currentDateTime());
                 }
-
-                info.ctime.setTimeSpec(Qt::UTC);
             }
         }
         else
@@ -1038,15 +1042,13 @@ void GPCamera::getItemInfoInternal(const QString& folder, const QString& itemNam
 
             if (cfinfo.file.fields & GP_FILE_INFO_MTIME)
             {
-                info.ctime = QDateTime::fromSecsSinceEpoch(cfinfo.file.mtime);
+                info.ctime = asDateTimeUTC(QDateTime::fromSecsSinceEpoch(cfinfo.file.mtime));
             }
             else
             {
-                info.ctime = QDateTime::currentDateTime();
+                info.ctime = asDateTimeUTC(QDateTime::currentDateTime());
             }
 
-            info.ctime.setTimeSpec(Qt::UTC);
-
             if (cfinfo.file.fields & GP_FILE_INFO_WIDTH)
             {
                 info.width = cfinfo.file.width;
@@ -1108,7 +1110,7 @@ bool GPCamera::getThumbnail(const QString& folder, const QString& itemName, QIma
         return false;
     }
 
-    thumbnail.loadFromData((const uchar*) data, (uint) size);
+    thumbnail.loadFromData(reinterpret_cast<const unsigned char*>(data), (uint) size);
 
     gp_file_unref(cfile);
 
@@ -1392,8 +1394,7 @@ bool GPCamera::deleteAllItems(const QString& folder)
 
 #ifdef HAVE_GPHOTO2
 
-    int         errorCode;
-    QStringList folderList;
+    int errorCode;
 
     d->status->cancel = false;
     errorCode         = gp_camera_folder_delete_all(d->camera, QFile::encodeName(folder).constData(),
