@@ -6,7 +6,8 @@
  * Date        : 2012-01-30
  * Description : maintenance dialog
  *
- * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2025      by Michael Miller <michael underscore miller at msn dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -14,6 +15,15 @@
 
 #include "maintenancedlg_p.h"
 
+// Qt includes
+
+#include <QMessageBox>
+
+// local includes
+
+#include "autotagsscansettings.h"
+#include "systemsettings.h"
+
 namespace Digikam
 {
 
@@ -50,45 +60,85 @@ MaintenanceDlg::MaintenanceDlg(QWidget* const parent)
     d->albumSelectors          = new AlbumSelectors(i18nc("@label", "Process items from:"),
                                                     d->configGroupName, options, AlbumSelectors::AlbumType::All, true);
     d->useLastSettings         = new QCheckBox(i18nc("@option:check", "Use the last saved active tools and settings"), options);
-    d->useMutiCoreCPU          = new QCheckBox(i18nc("@option:check", "Work on all processor cores (when it's possible)"), options);
-    d->expanderBox->insertItem(Private::Options, options, QIcon::fromTheme(QLatin1String("configure")), i18n("Common Options"), QLatin1String("Options"), true);
+    d->useMutiCoreCPU          = new QCheckBox(i18nc("@option:check", "Work on all processor cores (when it is possible)"), options);
+
+    d->expanderBox->insertItem(
+                               Private::Options,
+                               options,
+                               QIcon::fromTheme(QLatin1String("configure")),
+                               i18n("Common Options"),
+                               QLatin1String("Options"),
+                               true
+                              );
 
     // --------------------------------------------------------------------------------------
 
-    d->expanderBox->insertItem(Private::NewItems, new QLabel(i18n("<qt>No option<br/>"
-                               "<i>Note: only Albums Collection are processed by this tool.</i></qt>")),
-                               QIcon::fromTheme(QLatin1String("view-refresh")), i18n("Scan for new items"), QLatin1String("NewItems"), false);
+    d->expanderBox->insertItem(
+                               Private::NewItems,
+                               new QLabel(i18n("<qt>No option<br/>"
+                                               "<i>Note: only Albums Collection are processed by this tool.</i></qt>")),
+                               QIcon::fromTheme(QLatin1String("view-refresh")),
+                               i18n("Scan for new items"),
+                               QLatin1String("NewItems"),
+                               false
+                              );
+
     d->expanderBox->setCheckBoxVisible(Private::NewItems, true);
 
     // --------------------------------------------------------------------------------------
 
     d->vbox3                   = new DVBox;
-    new QLabel(i18n("<qt><i>Note: If activated, the Core DB is always cleaned. You can select additional databases for cleaning.<br/>"
-                    " If you select one of the options below, the process may take much time and can freeze digiKam temporarily<br/>"
-                    " in order to make sure that no database corruption occurs.</i></qt>"), d->vbox3);
+    new QLabel(i18n("<qt><i>Note: If activated, the core database is always cleaned. "
+                    "You can select additional databases for cleaning.<br/>"
+                    "If you select one of the options below, the process may take "
+                    "much time and can freeze digiKam temporarily "
+                    "in order to make sure that no database corruption occurs.</i></qt>"), d->vbox3);
     d->cleanThumbsDb           = new QCheckBox(i18n("Also clean up the thumbnail database."), d->vbox3);
     d->cleanFacesDb            = new QCheckBox(i18n("Also clean up the faces database."), d->vbox3);
     d->cleanSimilarityDb       = new QCheckBox(i18n("Also clean up the similarity database."), d->vbox3);
     d->shrinkDatabases         = new QCheckBox(i18n("Extended clean up and shrink all databases."), d->vbox3);
     d->shrinkDatabases->setToolTip(i18n("This option leads to the vacuuming (shrinking) of the databases. "
                                         "Vacuuming is supported both for SQLite and MySQL."));
-    d->expanderBox->insertItem(Private::DbCleanup, d->vbox3,
+
+    d->expanderBox->insertItem(
+                               Private::DbCleanup,
+                               d->vbox3,
                                QIcon::fromTheme(QLatin1String("run-build")),
-                               i18n("Perform database cleaning"), QLatin1String("DbCleanup"), false);
+                               i18n("Perform database cleaning"),
+                               QLatin1String("DbCleanup"),
+                               false
+                              );
+
     d->expanderBox->setCheckBoxVisible(Private::DbCleanup, true);
 
     // --------------------------------------------------------------------------------------
 
     d->scanThumbs              = new QCheckBox(i18n("Scan for changed or non-cataloged items (faster)"));
-    d->expanderBox->insertItem(Private::Thumbnails, d->scanThumbs, QIcon::fromTheme(QLatin1String("view-process-all")),
-                               i18n("Rebuild Thumbnails"), QLatin1String("Thumbnails"), false);
+
+    d->expanderBox->insertItem(
+                               Private::Thumbnails,
+                               d->scanThumbs,
+                               QIcon::fromTheme(QLatin1String("photo")),
+                               i18n("Rebuild Thumbnails"),
+                               QLatin1String("Thumbnails"),
+                               false
+                              );
+
     d->expanderBox->setCheckBoxVisible(Private::Thumbnails, true);
 
     // --------------------------------------------------------------------------------------
 
     d->scanFingerPrints        = new QCheckBox(i18n("Scan for changed or non-cataloged items (faster)"));
-    d->expanderBox->insertItem(Private::FingerPrints, d->scanFingerPrints, QIcon::fromTheme(QLatin1String("run-build")),
-                               i18n("Rebuild Finger-prints"), QLatin1String("Fingerprints"), false);
+
+    d->expanderBox->insertItem(
+                               Private::FingerPrints,
+                               d->scanFingerPrints,
+                               QIcon::fromTheme(QLatin1String("fingerprint")),
+                               i18n("Rebuild Finger-prints"),
+                               QLatin1String("Fingerprints"),
+                               false
+                              );
+
     d->expanderBox->setCheckBoxVisible(Private::FingerPrints, true);
 
     // --------------------------------------------------------------------------------------
@@ -121,9 +171,12 @@ MaintenanceDlg::MaintenanceDlg(QWidget* const parent)
     QWidget* const space4      = new QWidget(d->dupeRestrictionBox);
     d->dupeRestrictionBox->setStretchFactor(space4, 10);
     d->searchResultRestriction = new QComboBox(d->dupeRestrictionBox);
-    d->searchResultRestriction->addItem(i18n("No restriction"),                       HaarIface::DuplicatesSearchRestrictions::None);
-    d->searchResultRestriction->addItem(i18n("Restrict to album of reference image"), HaarIface::DuplicatesSearchRestrictions::SameAlbum);
-    d->searchResultRestriction->addItem(i18n("Exclude album of reference image"),     HaarIface::DuplicatesSearchRestrictions::DifferentAlbum);
+    d->searchResultRestriction->addItem(i18n("No restriction"),
+                                        HaarIface::DuplicatesSearchRestrictions::None);
+    d->searchResultRestriction->addItem(i18n("Restrict to album of reference image"),
+                                        HaarIface::DuplicatesSearchRestrictions::SameAlbum);
+    d->searchResultRestriction->addItem(i18n("Exclude album of reference image"),
+                                        HaarIface::DuplicatesSearchRestrictions::DifferentAlbum);
 
     // Load the last choice from application settings.
 
@@ -136,102 +189,92 @@ MaintenanceDlg::MaintenanceDlg(QWidget* const parent)
 
     d->searchResultRestriction->setCurrentIndex(d->searchResultRestriction->findData(restrictions));
 
-    d->expanderBox->insertItem(Private::Duplicates, d->duplicatesBox, QIcon::fromTheme(QLatin1String("tools-wizard")),
-                               i18n("Find Duplicate Items"), QLatin1String("Duplicates"), false);
+    d->expanderBox->insertItem(
+                               Private::Duplicates,
+                               d->duplicatesBox,
+                               QIcon::fromTheme(QLatin1String("tools-wizard")),
+                               i18n("Find Duplicate Items"),
+                               QLatin1String("Duplicates"),
+                               false
+                              );
+
     d->expanderBox->setCheckBoxVisible(Private::Duplicates, true);
 
     // --------------------------------------------------------------------------------------
 
     d->vbox4               = new DVBox;
-    DHBox* const hbox3     = new DHBox(d->vbox4);
-    new QLabel(i18n("Faces data management: "), hbox3);
-    QWidget* const space3  = new QWidget(hbox3);
-    hbox3->setStretchFactor(space3, 10);
-    d->faceScannedHandling = new QComboBox(hbox3);
-    d->faceScannedHandling->addItem(i18nc("@label:listbox", "Skip images already scanned"),           FaceScanSettings::Skip);
-    d->faceScannedHandling->addItem(i18nc("@label:listbox", "Scan again and merge results"),          FaceScanSettings::Merge);
-    d->faceScannedHandling->addItem(i18nc("@label:listbox", "Clear unconfirmed results and rescan"),  FaceScanSettings::Rescan);
-    d->faceScannedHandling->addItem(i18nc("@label:listbox", "Clear all previous results and rescan"), FaceScanSettings::ClearAll);
-
-    d->retrainAllFaces    = new QCheckBox(d->vbox4);
-    d->retrainAllFaces->setText(i18nc("@option:check", "Clear and rebuild all training data"));
+    d->retrainAllFaces     = new QCheckBox(d->vbox4);
+    d->retrainAllFaces->setText(i18nc("@option:check", "Rebuild all training data"));
     d->retrainAllFaces->setToolTip(i18nc("@info:tooltip",
-                                         "This will clear all training data for recognition "
-                                         "and rebuild it from all available faces."));
-    d->expanderBox->insertItem(Private::FaceManagement, d->vbox4, QIcon::fromTheme(QLatin1String("edit-image-face-detect")),
-                               i18n("Detect and recognize Faces"), QLatin1String("FaceManagement"), false);
+                                         "This will re-train the face recognizer with tagged faces in your library."));
+
+    d->resetFaceDb         = new QCheckBox(d->vbox4);
+    d->resetFaceDb->setText(i18nc("@option:check", "Reset and clear all faces and training"));
+    d->resetFaceDb->setToolTip(i18nc("@info:tooltip",
+                                         "This will clear all detected and tagged faces."));
+
+    d->clearRejectedFaces  = new QCheckBox(d->vbox4);
+    d->clearRejectedFaces->setText(i18nc("@option:check", "Clear rejected face matches"));
+    d->clearRejectedFaces->setToolTip(i18nc("@info:tooltip",
+                                         "This will delete all rejected face matches allowing the "
+                                         "face recognizer to present the suggested matches again."));
+
+    d->expanderBox->insertItem(
+                               Private::FaceManagement,
+                               d->vbox4,
+                               QIcon::fromTheme(QLatin1String("edit-image-face-detect")),
+                               i18n("Face engine management"),
+                               QLatin1String("FaceManagement"),
+                               false
+                              );
+
     d->expanderBox->setCheckBoxVisible(Private::FaceManagement, true);
 
+    // disable face management if the setting is not enabled
+
+    if (!SystemSettings(qApp->applicationName()).enableFaceEngine)
+    {
+        d->expanderBox->setItemExpanded(Private::FaceManagement, false);
+        d->expanderBox->setItemEnabled(Private::FaceManagement, false);
+    }
+
     // --------------------------------------------------------------------------------------
 
     d->vbox5               = new DVBox;
-    QLabel* const title    = new QLabel(d->vbox5);
-    title->setText(i18nc("@label",
-                        "<p><b>This tool allows to assign automatically tags to images by contents analysis using "
-                        "deep-learning neural network.</b></p>"
-                        "<p>The settings below determines the deep-learning model to use while parsing image "
-                        "contents to determine the subjects of the photography. The neural network used in background "
-                        "will generate automatically a serie of tags describing the contents and store the results in "
-                        "the database.</p>"));
-    title->setWordWrap(true);
+    d->autotagsWidget      = new AutotagsScanWidget(AutotagsScanWidget::Maintenance, d->vbox5);
+    d->expanderBox->insertItem(
+                               Private::AutotagsAssignment,
+                               d->vbox5,
+                               QIcon::fromTheme(QLatin1String("tag")),
+                               i18n("Auto-tags Assignment"),
+                               QLatin1String("AutotagsAssignment"),
+                               false
+                              );
 
-    DHBox* const hbox12    = new DHBox(d->vbox5);
-    new QLabel (i18n("Auto-tagging mode: "), hbox12);
-    QWidget* const space8  = new QWidget(hbox12);
-    hbox12->setStretchFactor(space8, 10);
-
-    d->autotaggingScanMode = new QComboBox(hbox12);
-    d->autotaggingScanMode->addItem(i18n("Clean all and re-assign"),  AutotagsAssignment::AllItems);
-    d->autotaggingScanMode->addItem(i18n("Scan non-assigned only"),   AutotagsAssignment::NonAssignedItems);
-    d->autotaggingScanMode->setToolTip(i18nc("@info:tooltip",
-        "<p><b>Clean all and re-assign</b>: clean all tags already assigned and re-scan all items from scratch.</p>"
-        "<p><b>Scan non-assigned only</b>: scan only the items with no assigned tag.</p>"));
-
-    DHBox* const hbox13    = new DHBox(d->vbox5);
-    new QLabel(i18n("Selection model: "), hbox13);
-    QWidget* const space9  = new QWidget(hbox13);
-    hbox13->setStretchFactor(space9, 10);
-
-    d->modelSelectionMode  = new QComboBox(hbox13);
-    d->modelSelectionMode->addItem(i18n("YOLOv5 Nano"),   DetectorModel::YOLOV5NANO);
-    d->modelSelectionMode->addItem(i18n("YOLOv5 XLarge"), DetectorModel::YOLOV5XLARGE);
-    d->modelSelectionMode->addItem(i18n("ResNet50"),      DetectorModel::RESNET50);
-    d->modelSelectionMode->setToolTip(i18nc("@info:tooltip",
-        "<p><b>YOLOv5 Nano</b>: this model is a neural network which offers exceptional speed and efficiency. It enables you to swiftly "
-        "evaluate the integration of smaller-scale object detection scenarios. It's designed for objects detections, capable of recognizing "
-        "and extracting the location of objects within an image. The limitation on the number of recognizable objects is set to 80.</p>"
-        "<p><b>YOLOv5 XLarge</b>: as the previous one, this model is a neural network dedicated for more complex object detection requirements and "
-        "showcases remarkable capabilities. Despite the additional complexity introducing more time-latency and "
-        "computer resources, it must be used for larger-scale object detection scenarios as it provides more accurate predictions at the expense of speed.</p>"
-        "<p><b>ResNet50</b>: this model is a specific type of convolutional neural network formed by stacking residual blocks "
-        "commonly used to power computer vision applications as object detections. This king of design allows the training of very deep networks without "
-        "encountering the vanishing gradient problem. Unlike YOLO, ResNet50 is primarily focused on image classification and does not provide object localization. "
-        "It can recognize objects from a vast set of more than 1,000 classes, covering a wide range of objects, animals, and scenes.</p>"));
-
-    d->trSelectorList      = new LocalizeSelectorList(d->vbox5);
-    d->trSelectorList->setTitle(i18nc("@label", "Translate Tags to:"));
-
-    d->expanderBox->insertItem(Private::AutotagsAssignment, d->vbox5,
-                               QIcon::fromTheme(QLatin1String("tag")), i18n("Auto-tags Assignment"),
-                               QLatin1String("AutotagsAssignment"), false);
     d->expanderBox->setCheckBoxVisible(Private::AutotagsAssignment, true);
 
+    // disable auto-tags assignment if the setting is not enabled
+
+    if (!SystemSettings(qApp->applicationName()).enableAutoTags)
+    {
+        d->expanderBox->setItemExpanded(Private::AutotagsAssignment, false);    
+        d->expanderBox->setItemEnabled(Private::AutotagsAssignment, false);
+    }
+
     // --------------------------------------------------------------------------------------
 
     d->vbox               = new DVBox;
-    DHBox* const hbox11   = new DHBox(d->vbox);
-    new QLabel(i18n("Scan Mode: "), hbox11);
-    QWidget* const space7 = new QWidget(hbox11);
-    hbox11->setStretchFactor(space7, 10);
+    d->qualityWidget      = new ImageQualityWidget(ImageQualityWidget::Maintenance, d->vbox);
 
-    d->qualityScanMode    = new QComboBox(hbox11);
-    d->qualityScanMode->addItem(i18n("Clean all and re-scan"),  ImageQualitySorter::AllItems);
-    d->qualityScanMode->addItem(i18n("Scan non-assigned only"), ImageQualitySorter::NonAssignedItems);
+    d->expanderBox->insertItem(
+                               Private::ImageQualitySorter,
+                               d->vbox,
+                               QIcon::fromTheme(QLatin1String("flag-green")),
+                               i18n("Image Quality Scanner"),
+                               QLatin1String("ImageQualitySorter"),
+                               false
+                              );
 
-    d->qualitySelector    = new ImageQualityConfSelector(d->vbox);
-
-    d->expanderBox->insertItem(Private::ImageQualitySorter, d->vbox, QIcon::fromTheme(QLatin1String("flag-green")),
-                               i18n("Image Quality Sorter"), QLatin1String("ImageQualitySorter"), false);
     d->expanderBox->setCheckBoxVisible(Private::ImageQualitySorter, true);
 
     // --------------------------------------------------------------------------------------
@@ -242,16 +285,26 @@ MaintenanceDlg::MaintenanceDlg(QWidget* const parent)
     QWidget* const space5 = new QWidget(hbox21);
     hbox21->setStretchFactor(space5, 10);
     d->syncDirection      = new QComboBox(hbox21);
-    d->syncDirection->addItem(i18n("From database to image metadata"), MetadataSynchronizer::WriteFromDatabaseToFile);
-    d->syncDirection->addItem(i18n("From image metadata to database"), MetadataSynchronizer::ReadFromFileToDatabase);
+    d->syncDirection->addItem(i18n("From database to image metadata"),
+                              MetadataSynchronizer::WriteFromDatabaseToFile);
+    d->syncDirection->addItem(i18n("From image metadata to database"),
+                              MetadataSynchronizer::ReadFromFileToDatabase);
 
     DHBox* const hbox22   = new DHBox(d->vbox2);
     new QLabel(i18n("Check metadata setup panel for details: "), hbox22);
     QWidget* const space6 = new QWidget(hbox22);
     hbox22->setStretchFactor(space6, 10);
     d->metadataSetup      = new QPushButton(i18n("Settings..."), hbox22);
-    d->expanderBox->insertItem(Private::MetadataSync, d->vbox2, QIcon::fromTheme(QLatin1String("run-build-file")),
-                               i18n("Sync Metadata and Database"), QLatin1String("MetadataSync"), false);
+
+    d->expanderBox->insertItem(
+                               Private::MetadataSync,
+                               d->vbox2,
+                               QIcon::fromTheme(QLatin1String("run-build-file")),
+                               i18n("Sync Metadata and Database"),
+                               QLatin1String("MetadataSync"),
+                               false
+                              );
+
     d->expanderBox->setCheckBoxVisible(Private::MetadataSync, true);
 
     d->expanderBox->insertStretch(Private::Stretch);
@@ -291,13 +344,30 @@ MaintenanceDlg::MaintenanceDlg(QWidget* const parent)
     connect(d->metadataSetup, SIGNAL(clicked()),
             this, SLOT(slotMetadataSetup()));
 
-    connect(d->qualitySelector, SIGNAL(signalQualitySetup()),
-            this, SLOT(slotQualitySetup()));
-
-    connect(d->retrainAllFaces, &QCheckBox::toggled,
-            this, [hbox3](bool on)
+    connect(d->resetFaceDb, &QCheckBox::toggled,
+            this, [this] (bool on)
         {
-            hbox3->setEnabled(!on);
+            if (on)
+            {
+                int mbResult = QMessageBox(
+                                           QMessageBox::Warning,
+                                           i18nc("@title: window reset face database", "Warning"),
+                                           i18n("Are you sure you want to delete all confirmed, "
+                                                "unconfirmed, and unknown faces? "
+                                                "You’ll need to rescan images and start tagging "
+                                                "unknown faces again before any faces can be recognized."),
+                                           QMessageBox::Ok | QMessageBox::Cancel,
+                                           this
+                                           ).exec();
+
+                if (QMessageBox::Cancel == mbResult)
+                {
+                    d->resetFaceDb->setChecked(false);
+                }
+            }
+
+            d->retrainAllFaces->setEnabled(!(Qt::Checked == d->resetFaceDb->checkState()));
+            d->clearRejectedFaces->setEnabled(!(Qt::Checked == d->resetFaceDb->checkState()));
         }
     );
 
@@ -381,16 +451,23 @@ void MaintenanceDlg::slotMetadataSetup()
     Setup::execSinglePage(this, Setup::MetadataPage);
 }
 
-void MaintenanceDlg::slotQualitySetup()
-{
-    Setup::execSinglePage(this, Setup::ImageQualityPage);
-}
-
 void MaintenanceDlg::slotHelp()
 {
     openOnlineDocumentation(QLatin1String("maintenance_tools"));
 }
 
+void MaintenanceDlg::showEvent(QShowEvent* e)
+{
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup group        = config->group(d->configGroupName);
+
+    DXmlGuiWindow::setGoodDefaultWindowSize(windowHandle());
+    DXmlGuiWindow::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size());
+
+    QDialog::showEvent(e);
+}
+
 } // namespace Digikam
 
 #include "moc_maintenancedlg.cpp"
