@@ -6,18 +6,9 @@
  * Date        : 2008-11-21
  * Description : Batch Queue Manager GUI
  *
- * Copyright (C) 2008-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -50,6 +41,14 @@ QueueMgrWindow::QueueMgrWindow()
     setConfigGroupName(QLatin1String("Batch Queue Manager Settings"));
     setXMLFile(QLatin1String("queuemgrwindowui5.rc"));
 
+#if (KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 88, 0))
+
+    setStateConfigGroup(configGroupName());
+
+#endif
+
+    setCaption(i18n("Batch Queue Manager"));
+
     qRegisterMetaType<BatchToolSettings>("BatchToolSettings");
     qRegisterMetaType<BatchToolSet>("BatchToolSet");
 
@@ -58,9 +57,6 @@ QueueMgrWindow::QueueMgrWindow()
     WorkflowManager::instance();             // Create first instance here
     d->thread  = new ActionThread(this);
 
-    setWindowFlags(Qt::Window);
-    setCaption(i18n("Batch Queue Manager"));
-
     // We don't want to be deleted on close
 
     setAttribute(Qt::WA_DeleteOnClose, false);
@@ -80,8 +76,11 @@ QueueMgrWindow::QueueMgrWindow()
 
     readSettings();
     applySettings();
+
     setAutoSaveSettings(configGroupName(), true);
 
+    showMenuBarAction()->setChecked(!menuBar()->isHidden());  // NOTE: workaround for bug #171080
+
     populateToolsList();
     slotQueueContentsChanged();
 }
@@ -267,6 +266,9 @@ void QueueMgrWindow::setupConnections()
 
     connect(d->toolsView, SIGNAL(signalAssignQueueSettings(QString)),
             this, SLOT(slotAssignQueueSettings(QString)));
+
+    connect(d->toolsView, SIGNAL(signalUpdateQueueSettings(QString)),
+            this, SLOT(slotUpdateQueueSettings(QString)));
 }
 
 void QueueMgrWindow::setupActions()
@@ -280,20 +282,20 @@ void QueueMgrWindow::setupActions()
     d->runAction->setEnabled(false);
     connect(d->runAction, SIGNAL(triggered()), this, SLOT(slotRun()));
     ac->addAction(QLatin1String("queuemgr_run"), d->runAction);
-    ac->setDefaultShortcut(d->runAction, Qt::CTRL + Qt::Key_P);
+    ac->setDefaultShortcut(d->runAction, Qt::CTRL | Qt::Key_P);
 
     d->runAllAction = new QAction(QIcon::fromTheme(QLatin1String("media-playback-start")),
                                i18n("Run all"), this);
     d->runAllAction->setEnabled(false);
     connect(d->runAllAction, SIGNAL(triggered()), this, SLOT(slotRunAll()));
     ac->addAction(QLatin1String("queuemgr_run_all"), d->runAllAction);
-    ac->setDefaultShortcut(d->runAllAction, Qt::CTRL + Qt::ALT + Qt::Key_P);
+    ac->setDefaultShortcut(d->runAllAction, Qt::CTRL | Qt::ALT | Qt::Key_P);
 
     d->stopAction = new QAction(QIcon::fromTheme(QLatin1String("media-playback-stop")), i18n("Stop"), this);
     d->stopAction->setEnabled(false);
     connect(d->stopAction, SIGNAL(triggered()), this, SLOT(slotStop()));
     ac->addAction(QLatin1String("queuemgr_stop"), d->stopAction);
-    ac->setDefaultShortcut(d->stopAction, Qt::CTRL + Qt::Key_S);
+    ac->setDefaultShortcut(d->stopAction, Qt::CTRL | Qt::Key_S);
 
     d->newQueueAction = new QAction(QIcon::fromTheme(QLatin1String("list-add")), i18n("New Queue"), this);
     connect(d->newQueueAction, SIGNAL(triggered()), d->queuePool, SLOT(slotAddQueue()));
@@ -313,7 +315,7 @@ void QueueMgrWindow::setupActions()
     d->removeItemsSelAction->setEnabled(false);
     connect(d->removeItemsSelAction, SIGNAL(triggered()), d->queuePool, SLOT(slotRemoveSelectedItems()));
     ac->addAction(QLatin1String("queuemgr_removeitemssel"), d->removeItemsSelAction);
-    ac->setDefaultShortcut(d->removeItemsSelAction, Qt::CTRL + Qt::Key_K);
+    ac->setDefaultShortcut(d->removeItemsSelAction, Qt::CTRL | Qt::Key_K);
 
     d->removeItemsDoneAction = new QAction(i18n("Remove processed items"), this);
     d->removeItemsDoneAction->setEnabled(false);
@@ -324,9 +326,9 @@ void QueueMgrWindow::setupActions()
     d->clearQueueAction->setEnabled(false);
     connect(d->clearQueueAction, SIGNAL(triggered()), d->queuePool, SLOT(slotClearList()));
     ac->addAction(QLatin1String("queuemgr_clearlist"), d->clearQueueAction);
-    ac->setDefaultShortcut(d->clearQueueAction, Qt::CTRL + Qt::SHIFT + Qt::Key_K);
+    ac->setDefaultShortcut(d->clearQueueAction, Qt::CTRL | Qt::SHIFT | Qt::Key_K);
 
-    QAction* const close = buildStdAction(StdCloseAction, this, SLOT(close()), this);
+    QAction* const close = buildStdAction(StdCloseAction, this, SLOT(slotClose()), this);
     ac->addAction(QLatin1String("queuemgr_close"), close);
 
     // -- 'Tools' menu actions -----------------------------------------------------
@@ -357,7 +359,7 @@ void QueueMgrWindow::setupActions()
 
     // Standard 'Help' menu actions
 
-    createHelpActions();
+    createHelpActions(QLatin1String("batch_queue"));
 
     // Provides a menu entry that allows showing/hiding the toolbar(s)
 
@@ -375,8 +377,6 @@ void QueueMgrWindow::setupActions()
 
     createGUI(xmlFile());
     cleanupActions();
-
-    showMenuBarAction()->setChecked(!menuBar()->isHidden());  // NOTE: workaround for bug #171080
 }
 
 void QueueMgrWindow::refreshView()
@@ -437,12 +437,16 @@ void QueueMgrWindow::refreshStatusBar()
     switch (pendingItems)
     {
         case 0:
+        {
             message.append(i18n("No items"));
             break;
+        }
 
         default:
+        {
             message.append(i18np("1 item", "%1 items", pendingItems));
             break;
+        }
     }
 
     message.append(QLatin1String(" / "));
@@ -450,12 +454,16 @@ void QueueMgrWindow::refreshStatusBar()
     switch (tasks)
     {
         case 0:
+        {
             message.append(i18n("No tasks"));
             break;
+        }
 
         default:
+        {
             message.append(i18np("1 task", "%1 tasks", tasks));
             break;
+        }
     }
 
     message.append(QLatin1String(" - ") + i18nc("#info: total number of items to process", "Total: "));
@@ -463,12 +471,16 @@ void QueueMgrWindow::refreshStatusBar()
     switch (totalItems)
     {
         case 0:
+        {
             message.append(i18n("No items"));
             break;
+        }
 
         default:
+        {
             message.append(i18np("1 item", "%1 items", totalItems));
             break;
+        }
     }
 
     message.append(QLatin1String(" / "));
@@ -476,12 +488,16 @@ void QueueMgrWindow::refreshStatusBar()
     switch (totalTasks)
     {
         case 0:
+        {
             message.append(i18n("No tasks"));
             break;
+        }
 
         default:
+        {
             message.append(i18np("1 task", "%1 tasks", totalTasks));
             break;
+        }
     }
 
     d->statusLabel->setText(message);
@@ -526,7 +542,7 @@ bool QueueMgrWindow::queryClose()
 {
     if (isBusy())
     {
-        int result = QMessageBox::warning(this, i18n("Processing under progress"),
+        int result = QMessageBox::warning(this, i18nc("@title:window", "Processing Under Progress"),
                                           i18n("Batch Queue Manager is running. Do you want to cancel current job?"),
                                           QMessageBox::Yes | QMessageBox::No);
 
@@ -612,7 +628,7 @@ void QueueMgrWindow::populateToolsList()
 {
     BatchToolsList list = BatchToolsFactory::instance()->toolsList();
 
-    foreach (BatchTool* const tool, list)
+    for (BatchTool* const tool : std::as_const(list))
     {
         d->toolsView->addTool(tool);
     }
@@ -720,7 +736,8 @@ void QueueMgrWindow::processOneQueue()
     d->assignedList->reset();
 
     d->queuePool->setCurrentIndex(d->currentQueueToProcess);
-    QueuePoolItemsList itemsList = d->queuePool->queueItemsList(d->currentQueueToProcess);
+    QueuePoolItemsList itemsList = d->queuePool->itemsList(d->currentQueueToProcess,
+                                                           QueueListView::Pending);
     QueueSettings settings       = d->queuePool->currentQueue()->settings();
 
     if (!checkTargetAlbum(d->currentQueueToProcess))
@@ -731,7 +748,7 @@ void QueueMgrWindow::processOneQueue()
 
     QList<AssignedBatchTools> tools4Items;
 
-    foreach (const ItemInfoSet& item, itemsList)
+    for (const ItemInfoSet& item : std::as_const(itemsList))
     {
         AssignedBatchTools one         = d->queuePool->currentQueue()->assignedTools();
         one.m_itemUrl                  = item.info.fileUrl();
@@ -779,7 +796,7 @@ void QueueMgrWindow::busy(bool busy)
     d->busy ? d->queuePool->setCursor(Qt::WaitCursor) : d->queuePool->unsetCursor();
     d->busy ? m_animLogo->start() : m_animLogo->stop();
 
-    emit signalBqmIsBusy(d->busy);
+    Q_EMIT signalBqmIsBusy(d->busy);
 }
 
 void QueueMgrWindow::slotAssignedToolsChanged(const AssignedBatchTools& tools)
@@ -844,7 +861,7 @@ bool QueueMgrWindow::checkTargetAlbum(int queueId)
 
         if (processedItemsAlbumUrl.isEmpty())
         {
-            QMessageBox::critical(this, i18n("Processed items album settings"),
+            QMessageBox::critical(this, i18nc("@title:window", "Processed Items Album Settings"),
                                   i18n("Album to host processed items from queue \"%1\" is not set. "
                                        "Please select one from Queue Settings panel.", queueName));
             return false;
@@ -854,7 +871,7 @@ bool QueueMgrWindow::checkTargetAlbum(int queueId)
 
         if (!dir.exists() || !dir.isWritable())
         {
-            QMessageBox::critical(this, i18n("Processed items album settings"),
+            QMessageBox::critical(this, i18nc("@title:window", "Processed Items Album Settings"),
                                   i18n("Album to host processed items from queue \"%1\" "
                                        "is not available or not writable. "
                                        "Please set another one from Queue Settings panel.", queueName));
@@ -868,7 +885,8 @@ bool QueueMgrWindow::checkTargetAlbum(int queueId)
 void QueueMgrWindow::moveEvent(QMoveEvent* e)
 {
     Q_UNUSED(e)
-    emit signalWindowHasMoved();
+
+    Q_EMIT signalWindowHasMoved();
 }
 
 void QueueMgrWindow::slotHistoryEntryClicked(int queueId, qlonglong itemId)
@@ -1036,6 +1054,26 @@ void QueueMgrWindow::slotAssignQueueSettings(const QString& title)
     }
 }
 
+void QueueMgrWindow::slotUpdateQueueSettings(const QString& title)
+{
+    if (!title.isEmpty())
+    {
+        QueueListView* const queue = d->queuePool->currentQueue();
+
+        if (queue)
+        {
+            WorkflowManager* const mngr = WorkflowManager::instance();
+            Workflow wfOld              = mngr->findByTitle(title);
+            Workflow wfNew              = wfOld;
+            mngr->remove(wfOld);
+            wfNew.qSettings             = queue->settings();
+            wfNew.aTools                = queue->assignedTools().m_toolsList;
+            mngr->insert(wfNew);
+            mngr->save();
+        }
+    }
+}
+
 void QueueMgrWindow::slotSaveWorkflow()
 {
     if (d->queuePool->saveWorkflow())
@@ -1051,4 +1089,18 @@ void QueueMgrWindow::customizedFullScreenMode(bool set)
     showMenuBarAction()->setEnabled(!set);
 }
 
+DInfoInterface* QueueMgrWindow::infoIface(DPluginAction* const)
+{
+    // Reimplemented in BatchToolsFactory
+
+    return nullptr;
+}
+
+QueuePool* QueueMgrWindow::queuePool() const
+{
+    return d->queuePool;
+}
+
 } // namespace Digikam
+
+#include "moc_queuemgrwindow.cpp"
