@@ -7,7 +7,7 @@
  * Description : User interface for searches
  *
  * SPDX-FileCopyrightText: 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -19,19 +19,7 @@ namespace Digikam
 {
 
 SearchFieldChoice::SearchFieldChoice(QObject* const parent)
-    : SearchField(parent),
-      m_comboBox (nullptr),
-
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
-
-      m_type     (QMetaType::UnknownType)
-
-#else
-
-      m_type     (QVariant::Invalid)
-
-#endif
-
+    : SearchField(parent)
 {
     m_model   = new ChoiceSearchModel(this);
     m_anyText = i18nc("@option: default kind of search options combined", "Any");
@@ -128,7 +116,6 @@ void SearchFieldChoice::updateComboText()
 void SearchFieldChoice::read(SearchXmlCachingReader& reader)
 {
     SearchXml::Relation relation = reader.fieldRelation();
-    QList<int> values;
 
     if (relation == SearchXml::OneOf)
     {
