@@ -6,14 +6,13 @@
  * Date        : 2004-08-03
  * Description : setup Image Editor interface.
  *
- * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SETUP_EDITOR_IFACE_H
-#define DIGIKAM_SETUP_EDITOR_IFACE_H
+#pragma once
 
 // Qt includes
 
@@ -51,9 +50,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_SETUP_EDITOR_IFACE_H
