@@ -51,50 +51,34 @@ class Q_DECL_HIDDEN AdvancedMetadataTab::Private
 {
 public:
 
-    explicit Private()
-      : metadataType    (nullptr),
-        operationType   (nullptr),
-        addButton       (nullptr),
-        editButton      (nullptr),
-        deleteButton    (nullptr),
-        moveUpButton    (nullptr),
-        moveDownButton  (nullptr),
-        revertChanges   (nullptr),
-        saveProfile     (nullptr),
-        loadProfile     (nullptr),
-        resetButton     (nullptr),
-        unifyReadWrite  (nullptr),
-        readingAllTags  (nullptr),
-        namespaceView   (nullptr),
-        metadataTypeSize(0),
-        changed         (false)
-    {
-    }
+    Private() = default;
 
-    QComboBox*                  metadataType;
-    QComboBox*                  operationType;
-    QPushButton*                addButton;
-    QPushButton*                editButton;
-    QPushButton*                deleteButton;
-    QPushButton*                moveUpButton;
-    QPushButton*                moveDownButton;
-    QPushButton*                revertChanges;
-    QPushButton*                saveProfile;
-    QPushButton*                loadProfile;
-    QPushButton*                resetButton;
-    QCheckBox*                  unifyReadWrite;
-    QCheckBox*                  readingAllTags;
+public:
+
+    QComboBox*                  metadataType        = nullptr;
+    QComboBox*                  operationType       = nullptr;
+    QPushButton*                addButton           = nullptr;
+    QPushButton*                editButton          = nullptr;
+    QPushButton*                deleteButton        = nullptr;
+    QPushButton*                moveUpButton        = nullptr;
+    QPushButton*                moveDownButton      = nullptr;
+    QPushButton*                revertChanges       = nullptr;
+    QPushButton*                saveProfile         = nullptr;
+    QPushButton*                loadProfile         = nullptr;
+    QPushButton*                resetButton         = nullptr;
+    QCheckBox*                  unifyReadWrite      = nullptr;
+    QCheckBox*                  readingAllTags      = nullptr;
     QList<QStandardItemModel*>  models;
-    NamespaceListView*          namespaceView;
+    NamespaceListView*          namespaceView       = nullptr;
     DMetadataSettingsContainer  container;
-    int                         metadataTypeSize;
+    int                         metadataTypeSize    = 0;
 
-    bool                        changed;
+    bool                        changed             = false;
 };
 
 AdvancedMetadataTab::AdvancedMetadataTab(QWidget* const parent)
     : QWidget(parent),
-      d      (new Private())
+      d      (new Private)
 {
     // ---------- Advanced Configuration Panel -----------------------------
 
@@ -191,7 +175,7 @@ void AdvancedMetadataTab::slotLoadProfile()
     DMetadataSettingsContainer container;
     container.readFromConfig(group2);
 
-    if (container.mappingKeys().size() != 5)
+    if (container.mappingKeys().size() != 6)
     {
         return;
     }
@@ -261,6 +245,10 @@ void AdvancedMetadataTab::slotAddNewNamespace()
     {
         entry.nsType = NamespaceEntry::COMMENT;
     }
+    else if (d->metadataType->currentData().toString() == NamespaceEntry::DM_PICKLABEL_CONTAINER())
+    {
+        entry.nsType = NamespaceEntry::PICKLABEL;
+    }
     else if (d->metadataType->currentData().toString() == NamespaceEntry::DM_COLORLABEL_CONTAINER())
     {
         entry.nsType = NamespaceEntry::COLORLABEL;
@@ -382,7 +370,7 @@ void AdvancedMetadataTab::setModelData(QStandardItemModel* const model,
 {
     QStandardItem* const root = model->invisibleRootItem();
 
-    for (NamespaceEntry e : container)
+    for (const NamespaceEntry& e : container)
     {
         QStandardItem* const item = new QStandardItem(e.namespaceName);
 
@@ -560,7 +548,7 @@ void AdvancedMetadataTab::setModels()
 
     QList<QString> keys = d->container.mappingKeys();
 
-    Q_FOREACH (const QString& str, keys)
+    for (const QString& str : std::as_const(keys))
     {
         d->metadataType->addItem(d->container.translateMappingKey(str), str);
     }
@@ -581,14 +569,14 @@ void AdvancedMetadataTab::setModels()
 
     int index = 0;
 
-    Q_FOREACH (const QString& str, keys)
+    for (const QString& str : std::as_const(keys))
     {
-        setModelData(d->models.at(index++), d->container.getReadMapping(str));
+        setModelData(d->models.at(index++), d->container.getReadMapping(str));      // krazy:exclude=postfixop
     }
 
-    Q_FOREACH (const QString& str, keys)
+    for (const QString& str : std::as_const(keys))
     {
-        setModelData(d->models.at(index++), d->container.getWriteMapping(str));
+        setModelData(d->models.at(index++), d->container.getWriteMapping(str));     // krazy:exclude=postfixop
     }
 
     d->metadataType->setCurrentIndex(0);
@@ -602,13 +590,13 @@ void AdvancedMetadataTab::updateContainer()
     QList<QString> keys = d->container.mappingKeys();
     int index           = 0;
 
-    Q_FOREACH (const QString& str, keys)
+    for (const QString& str : std::as_const(keys))
     {
         d->container.getReadMapping(str).clear();
         saveModelData(d->models.at(index++), d->container.getReadMapping(str));
     }
 
-    Q_FOREACH (const QString& str, keys)
+    for (const QString& str : std::as_const(keys))
     {
         d->container.getWriteMapping(str).clear();
         saveModelData(d->models.at(index++), d->container.getWriteMapping(str));
