@@ -7,7 +7,7 @@
  * Description : Color management setup tab.
  *
  * SPDX-FileCopyrightText: 2005-2007 by F.J. Cruz <fj dot cruz at supercable dot es>
- * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -63,104 +63,65 @@ class Q_DECL_HIDDEN SetupICC::Private
 {
 public:
 
-    explicit Private()
-      : iccFolderLabel          (nullptr),
-        enableColorManagement   (nullptr),
-        defaultSRGBConvert      (nullptr),
-        bpcAlgorithm            (nullptr),
-        managedView             (nullptr),
-        managedPreviews         (nullptr),
-        defaultAskMismatch      (nullptr),
-        defaultConvertMismatch  (nullptr),
-        defaultAskMissing       (nullptr),
-        defaultSRGBMissing      (nullptr),
-        defaultWSMissing        (nullptr),
-        defaultInputMissing     (nullptr),
-        defaultAskRaw           (nullptr),
-        defaultInputRaw         (nullptr),
-        defaultGuessRaw         (nullptr),
-        infoWorkProfiles        (nullptr),
-        infoMonitorProfiles     (nullptr),
-        infoInProfiles          (nullptr),
-        infoProofProfiles       (nullptr),
-        workspaceGB             (nullptr),
-        mismatchGB              (nullptr),
-        missingGB               (nullptr),
-        rawGB                   (nullptr),
-        inputGB                 (nullptr),
-        viewGB                  (nullptr),
-        proofGB                 (nullptr),
-        iccFolderGB             (nullptr),
-        advancedSettingsGB      (nullptr),
-        defaultPathKU           (nullptr),
-        renderingIntentKC       (nullptr),
-        behaviorPanel           (nullptr),
-        profilesPanel           (nullptr),
-        advancedPanel           (nullptr),
-        tab                     (nullptr),
-        dlgBtnBox               (nullptr),
-        inProfilesKC            (nullptr),
-        workProfilesKC          (nullptr),
-        proofProfilesKC         (nullptr),
-        monitorProfilesKC       (nullptr)
-    {
-    }
+    Private() = default;
 
-    QLabel*                     iccFolderLabel;
+public:
 
-    QCheckBox*                  enableColorManagement;
-    QCheckBox*                  defaultSRGBConvert;
-    QCheckBox*                  bpcAlgorithm;
-    QCheckBox*                  managedView;
-    QCheckBox*                  managedPreviews;
+    QLabel*                     iccFolderLabel          = nullptr;
 
-    QRadioButton*               defaultAskMismatch;
-    QRadioButton*               defaultConvertMismatch;
-    QRadioButton*               defaultAskMissing;
-    QRadioButton*               defaultSRGBMissing;
-    QRadioButton*               defaultWSMissing;
-    QRadioButton*               defaultInputMissing;
-    QRadioButton*               defaultAskRaw;
-    QRadioButton*               defaultInputRaw;
-    QRadioButton*               defaultGuessRaw;
+    QCheckBox*                  enableColorManagement   = nullptr;
+    QCheckBox*                  defaultSRGBConvert      = nullptr;
+    QCheckBox*                  bpcAlgorithm            = nullptr;
+    QCheckBox*                  managedView             = nullptr;
+    QCheckBox*                  managedPreviews         = nullptr;
 
-    QPushButton*                infoWorkProfiles;
-    QPushButton*                infoMonitorProfiles;
-    QPushButton*                infoInProfiles;
-    QPushButton*                infoProofProfiles;
+    QRadioButton*               defaultAskMismatch      = nullptr;
+    QRadioButton*               defaultConvertMismatch  = nullptr;
+    QRadioButton*               defaultAskMissing       = nullptr;
+    QRadioButton*               defaultSRGBMissing      = nullptr;
+    QRadioButton*               defaultWSMissing        = nullptr;
+    QRadioButton*               defaultInputMissing     = nullptr;
+    QRadioButton*               defaultAskRaw           = nullptr;
+    QRadioButton*               defaultInputRaw         = nullptr;
+    QRadioButton*               defaultGuessRaw         = nullptr;
 
-    QGroupBox*                  workspaceGB;
-    QGroupBox*                  mismatchGB;
-    QGroupBox*                  missingGB;
-    QGroupBox*                  rawGB;
-    QGroupBox*                  inputGB;
-    QGroupBox*                  viewGB;
-    QGroupBox*                  proofGB;
-    QGroupBox*                  iccFolderGB;
-    QGroupBox*                  advancedSettingsGB;
+    QPushButton*                infoWorkProfiles        = nullptr;
+    QPushButton*                infoMonitorProfiles     = nullptr;
+    QPushButton*                infoInProfiles          = nullptr;
+    QPushButton*                infoProofProfiles       = nullptr;
 
-    DFileSelector*              defaultPathKU;
+    QGroupBox*                  workspaceGB             = nullptr;
+    QGroupBox*                  mismatchGB              = nullptr;
+    QGroupBox*                  missingGB               = nullptr;
+    QGroupBox*                  rawGB                   = nullptr;
+    QGroupBox*                  inputGB                 = nullptr;
+    QGroupBox*                  viewGB                  = nullptr;
+    QGroupBox*                  proofGB                 = nullptr;
+    QGroupBox*                  iccFolderGB             = nullptr;
+    QGroupBox*                  advancedSettingsGB      = nullptr;
 
-    IccRenderingIntentComboBox* renderingIntentKC;
+    DFileSelector*              defaultPathKU           = nullptr;
 
-    QWidget*                    behaviorPanel;
-    QWidget*                    profilesPanel;
-    QWidget*                    advancedPanel;
-    QTabWidget*                 tab;
-    QDialogButtonBox*           dlgBtnBox;
+    IccRenderingIntentComboBox* renderingIntentKC       = nullptr;
 
-    IccProfilesComboBox*        inProfilesKC;
-    IccProfilesComboBox*        workProfilesKC;
-    IccProfilesComboBox*        proofProfilesKC;
-    IccProfilesComboBox*        monitorProfilesKC;
+    QWidget*                    behaviorPanel           = nullptr;
+    QWidget*                    profilesPanel           = nullptr;
+    QWidget*                    advancedPanel           = nullptr;
+    QTabWidget*                 tab                     = nullptr;
+    QDialogButtonBox*           dlgBtnBox               = nullptr;
+
+    IccProfilesComboBox*        inProfilesKC            = nullptr;
+    IccProfilesComboBox*        workProfilesKC          = nullptr;
+    IccProfilesComboBox*        proofProfilesKC         = nullptr;
+    IccProfilesComboBox*        monitorProfilesKC       = nullptr;
 };
 
 SetupICC::SetupICC(QDialogButtonBox* const dlgBtnBox, QWidget* const parent)
     : QScrollArea(parent),
       d          (new Private)
 {
-    const int spacing              = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                                          QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing              = layoutSpacing();
+
     d->dlgBtnBox                   = dlgBtnBox;
     d->tab                         = new QTabWidget(viewport());
     setWidget(d->tab);
@@ -181,7 +142,7 @@ SetupICC::SetupICC(QDialogButtonBox* const dlgBtnBox, QWidget* const parent)
                                                 "disabled</li></ul>"));
 
     DActiveLabel* const lcmsLogoLabel = new DActiveLabel(QUrl(QLatin1String("https://www.littlecms.com")),
-                                                         QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("digikam/data/logo-lcms.png")),
+                                                         QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("digikam/data/logo-lcms.webp")),
                                                          colorPolicy);
     lcmsLogoLabel->setToolTip(i18n("Visit Little CMS project website"));
 
@@ -246,7 +207,7 @@ SetupICC::SetupICC(QDialogButtonBox* const dlgBtnBox, QWidget* const parent)
 
     // --------------------------------------------------------
 
-    d->missingGB                    = new QGroupBox;//(i18n("Missing Profile Behavior"));
+    d->missingGB                    = new QGroupBox;        // Missing Profile Behavior
     QVBoxLayout* const vlayMissing  = new QVBoxLayout(d->missingGB);
 
     QLabel* const  missingIcon      = new QLabel;
@@ -266,13 +227,13 @@ SetupICC::SetupICC(QDialogButtonBox* const dlgBtnBox, QWidget* const parent)
     d->defaultSRGBMissing = new QRadioButton(i18n("Assume it is using the sRGB color space (Internet standard)"));
 
     /**
-     * @todo d->defaultSRGBMissing->setWhatsThis( i18n("<p></p>"));
+     * @todo d->defaultSRGBMissing->setWhatsThis(i18n("<p></p>"));
      */
 
     d->defaultSRGBConvert = new QCheckBox(i18n("and convert it to the working color space"));
 
     /**
-     * @todo d->defaultSRGBConvert->setWhatsThis( i18n("<p></p>"));
+     * @todo d->defaultSRGBConvert->setWhatsThis(i18n("<p></p>"));
      */
 
     d->defaultSRGBConvert->setChecked(true);
@@ -285,13 +246,13 @@ SetupICC::SetupICC(QDialogButtonBox* const dlgBtnBox, QWidget* const parent)
     d->defaultWSMissing         = new QRadioButton(i18n("Assume it is using the working color space"));
 
     /**
-     * @todo d->defaultWSMissing->setWhatsThis( i18n("<p></p>"));
+     * @todo d->defaultWSMissing->setWhatsThis(i18n("<p></p>"));
      */
 
     d->defaultInputMissing      = new QRadioButton(i18n("Convert it from default input color space to working space"));
 
     /**
-     * @todo d->defaultWSMissing->setWhatsThis( i18n("<p></p>"));
+     * @todo d->defaultWSMissing->setWhatsThis(i18n("<p></p>"));
      */
 
     vlayMissing->addLayout(hboxMP);
@@ -302,7 +263,7 @@ SetupICC::SetupICC(QDialogButtonBox* const dlgBtnBox, QWidget* const parent)
 
     // --------------------------------------------------------
 
-    d->rawGB                       = new QGroupBox;//(i18n("Raw File Behavior"));
+    d->rawGB                       = new QGroupBox;         // Raw File Behavior
     QVBoxLayout* const vlayRaw     = new QVBoxLayout(d->rawGB);
 
     QLabel* const rawBehaviorIcon  = new QLabel;
@@ -317,19 +278,19 @@ SetupICC::SetupICC(QDialogButtonBox* const dlgBtnBox, QWidget* const parent)
     d->defaultAskRaw   = new QRadioButton(i18n("Ask for the input profile"));
 
     /**
-     * @todo d->defaultAskRaw->setWhatsThis( i18n("<p></p>"));
+     * @todo d->defaultAskRaw->setWhatsThis(i18n("<p></p>"));
      */
 
     d->defaultGuessRaw = new QRadioButton(i18n("Automatic color correction"));
 
     /**
-     * @todo d->defaultGuessRaw->setWhatsThis( i18n("<p></p>"));
+     * @todo d->defaultGuessRaw->setWhatsThis(i18n("<p></p>"));
      */
 
     d->defaultInputRaw = new QRadioButton(i18n("Convert it from the default input profile"));
 
     /**
-     * @todo d->defaultSRGBMissing->setWhatsThis( i18n("<p></p>"));
+     * @todo d->defaultSRGBMissing->setWhatsThis(i18n("<p></p>"));
      */
 
     d->defaultGuessRaw->setChecked(true);
@@ -339,7 +300,6 @@ SetupICC::SetupICC(QDialogButtonBox* const dlgBtnBox, QWidget* const parent)
     vlayRaw->addWidget(d->defaultGuessRaw);
     vlayRaw->addWidget(d->defaultInputRaw);
 
-
     mainLayout->addWidget(colorPolicy);
     mainLayout->addWidget(d->workspaceGB);
     mainLayout->addWidget(d->mismatchGB);
@@ -358,16 +318,16 @@ SetupICC::SetupICC(QDialogButtonBox* const dlgBtnBox, QWidget* const parent)
     monitorIcon->setPixmap(QIcon::fromTheme(QLatin1String("video-display")).pixmap(32));
     QLabel* const monitorProfiles  = new QLabel(i18n("Monitor profile:"));
 
-    d->monitorProfilesKC     = new IccProfilesComboBox;
+    d->monitorProfilesKC           = new IccProfilesComboBox;
     monitorProfiles->setBuddy(d->monitorProfilesKC);
     d->monitorProfilesKC->setWhatsThis(i18n("<p>Select the color profile for your monitor here.</p>"));
 
-    d->infoMonitorProfiles   = new QPushButton;
+    d->infoMonitorProfiles         = new QPushButton;
     d->infoMonitorProfiles->setIcon(QIcon::fromTheme(QLatin1String("dialog-information")));
     d->infoMonitorProfiles->setWhatsThis(i18n("<p>You can use this button to get more detailed "
                                               "information about the selected monitor profile.</p>"));
 
-    d->managedView           = new QCheckBox;
+    d->managedView                 = new QCheckBox;
     d->managedView->setText(i18n("Use color managed view in editor"));
     d->managedView->setWhatsThis(i18n("<p>Turn on this option if "
                                       "you want to use your <b>Monitor Color Profile</b> to show your pictures in "
@@ -375,11 +335,11 @@ SetupICC::SetupICC(QDialogButtonBox* const dlgBtnBox, QWidget* const parent)
                                       "You can at any time toggle this option from the Editor window. "
                                       "<i>Warning</i>: This can slow down rendering of the image, depending on the speed of your computer.</p>"));
 
-    d->managedPreviews       = new QCheckBox;
+    d->managedPreviews             = new QCheckBox;
     d->managedPreviews->setText(i18n("Use color managed view for previews and thumbnails"));
 
     /**
-     * @todo d->managedPreview->setWhatsThis( i18n("") );
+     * @todo d->managedPreview->setWhatsThis(i18n(""));
      */
 
     gridView->addWidget(monitorIcon,            0, 0);
