@@ -6,14 +6,13 @@
  * Date        : 2006-07-09
  * Description : item tool tip configuration setup tab
  *
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SETUP_TOOLTIP_H
-#define DIGIKAM_SETUP_TOOLTIP_H
+#pragma once
 
 // Qt includes
 
@@ -61,9 +60,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_SETUP_TOOLTIP_H
