@@ -3,7 +3,7 @@
 # Script to install extra libs dependency pass as name as first argument (ex: "kimageformats")
 # This script must be run as sudo
 #
-# SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2025 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
 # SPDX-License-Identifier: BSD-3-Clause
 #
@@ -44,8 +44,7 @@ cmake $ORIG_WD/../3rdparty \
       -DEXTERNALS_DOWNLOAD_DIR=$DOWNLOAD_DIR \
       -DKA_VERSION=$DK_KA_VERSION \
       -DKDE_VERSION=$DK_KDE_VERSION \
-      -DENABLE_QTVERSION=$DK_QTVERSION \
-      -DENABLE_QTWEBENGINE=$DK_QTWEBENGINE
+      -DENABLE_QTVERSION=$DK_QTVERSION
 
 cmake --build . --config RelWithDebInfo --target ext_$1 -- -j$CPU_CORES
 
