@@ -8,18 +8,9 @@
 # Date:        2016-08-15
 # Description: Script to find no really internationlized source code.
 #
-# Copyright (C) 2016-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+# Copyright (C) 2016-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
 #
-# This program is free software; you can redistribute it
-# and/or modify it under the terms of the GNU General
-# Public License as published by the Free Software Foundation;
-# either version 2, or (at your option)
-# any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# SPDX-License-Identifier: BSD-3-Clause
 #
 # ============================================================
 
@@ -42,7 +33,7 @@ for i in `find \( -name '*.cpp' -o -name '*.h' \)` ; do
 
          # file name is printed only if "string A" is present and "string B" is absent
 
-         echo "$i\n"
+         echo "$i"
 
       fi
 
